@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail.com>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -77,7 +77,6 @@ protected:
 
 private:
 	QPixmap m_bg;
-	ledCheckBox * m_bypass;
 	QMdiSubWindow * m_subWindow;
 	ControllerDialog * m_controllerDlg;
 	bool m_show;
