@@ -1,9 +1,9 @@
 /*
  * RemotePlugin.h - base class providing RPC like mechanisms
  *
- * Copyright (c) 2008-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2008-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -26,7 +26,8 @@
 #define _REMOTE_PLUGIN_H
 
 #include "export.h"
-#include "midi.h"
+#include "MidiEvent.h"
+#include "VstSyncData.h"
 
 #include <vector>
 #include <cstdio>
@@ -51,7 +52,7 @@
 #include <process.h>
 #endif
 
-#include <Qt/qglobal.h>
+#include <QtCore/QtGlobal>
 
 #if QT_VERSION >= 0x040400
 #include <QtCore/QSystemSemaphore>
@@ -74,7 +75,7 @@
 
 #ifdef USE_QT_SHMEM
 
-#include <Qt/qglobal.h>
+#include <QtCore/QtGlobal>
 
 #if QT_VERSION >= 0x040400
 #include <QtCore/QSharedMemory>
@@ -473,7 +474,6 @@ private:
 #else
 	int m_shmID;
 #endif
-	size_t m_shmSize;
 	shmData * m_data;
 #ifdef USE_QT_SEMAPHORES
 	QSystemSemaphore m_dataSem;
@@ -723,7 +723,7 @@ public:
 
 	bool process( const sampleFrame * _in_buf, sampleFrame * _out_buf );
 
-	void processMidiEvent( const midiEvent &, const f_cnt_t _offset );
+	void processMidiEvent( const MidiEvent&, const f_cnt_t _offset );
 
 	void updateSampleRate( sample_rate_t _sr )
 	{
@@ -779,7 +779,6 @@ private:
 	void resizeSharedProcessingMemory();
 
 
-	bool m_initialized;
 	bool m_failed;
 
 	QProcess m_process;
@@ -811,14 +810,15 @@ class RemotePluginClient : public RemotePluginBase
 public:
 	RemotePluginClient( key_t _shm_in, key_t _shm_out );
 	virtual ~RemotePluginClient();
-
+#ifdef USE_QT_SHMEM
+	VstSyncData * getQtVSTshm();
+#endif
 	virtual bool processMessage( const message & _m );
 
 	virtual void process( const sampleFrame * _in_buf,
 					sampleFrame * _out_buf ) = 0;
 
-	virtual void processMidiEvent( const midiEvent &,
-						const f_cnt_t /* _offset */ )
+	virtual void processMidiEvent( const MidiEvent&, const f_cnt_t /* _offset */ )
 	{
 	}
 
@@ -879,7 +879,9 @@ private:
 
 #ifdef USE_QT_SHMEM
 	QSharedMemory m_shmObj;
+	QSharedMemory m_shmQtID;
 #endif
+	VstSyncData * m_vstSyncData;
 	float * m_shm;
 
 	int m_inputCount;
@@ -1007,13 +1009,60 @@ RemotePluginClient::RemotePluginClient( key_t _shm_in, key_t _shm_out ) :
 	RemotePluginBase( new shmFifo( _shm_in ), new shmFifo( _shm_out ) ),
 #ifdef USE_QT_SHMEM
 	m_shmObj(),
+	m_shmQtID( "/usr/bin/lmms" ),
 #endif
+	m_vstSyncData( NULL ),
 	m_shm( NULL ),
 	m_inputCount( 0 ),
 	m_outputCount( 0 ),
 	m_sampleRate( 44100 ),
 	m_bufferSize( 0 )
 {
+#ifdef USE_QT_SHMEM
+	if( m_shmQtID.attach( QSharedMemory::ReadOnly ) )
+	{
+		m_vstSyncData = (VstSyncData *) m_shmQtID.data();
+		m_bufferSize = m_vstSyncData->m_bufferSize;
+		m_sampleRate = m_vstSyncData->m_sampleRate;
+		return;
+	}
+#else
+	key_t key;
+	int m_shmID;
+
+	if( ( key = ftok( VST_SNC_SHM_KEY_FILE, 'R' ) ) == -1 )
+	{
+		perror( "RemotePluginClient::ftok" );
+	}
+	else
+	{	// connect to shared memory segment
+		if( ( m_shmID = shmget( key, 0, 0 ) ) == -1 )
+		{
+			perror( "RemotePluginClient::shmget" );
+		}
+		else
+		{	// attach segment
+			m_vstSyncData = (VstSyncData *)shmat(m_shmID, 0, 0);
+			if( m_vstSyncData == (VstSyncData *)( -1 ) )
+			{
+				perror( "RemotePluginClient::shmat" );
+			}
+			else
+			{
+				m_bufferSize = m_vstSyncData->m_bufferSize;
+				m_sampleRate = m_vstSyncData->m_sampleRate;
+
+				// detach segment
+				if( shmdt(m_vstSyncData) == -1 )
+				{
+					perror("RemotePluginClient::shmdt");
+				}
+				return;
+			}
+		}
+	}
+#endif
+	// if attaching shared memory fails
 	sendMessage( IdSampleRateInformation );
 	sendMessage( IdBufferSizeInformation );
 }
@@ -1023,6 +1072,9 @@ RemotePluginClient::RemotePluginClient( key_t _shm_in, key_t _shm_out ) :
 
 RemotePluginClient::~RemotePluginClient()
 {
+#ifdef USE_QT_SHMEM
+	m_shmQtID.detach();
+#endif
 	sendMessage( IdQuit );
 
 #ifndef USE_QT_SHMEM
@@ -1032,6 +1084,14 @@ RemotePluginClient::~RemotePluginClient()
 
 
 
+#ifdef USE_QT_SHMEM
+VstSyncData * RemotePluginClient::getQtVSTshm()
+{
+	return m_vstSyncData;
+}
+#endif
+
+
 
 bool RemotePluginClient::processMessage( const message & _m )
 {
@@ -1057,7 +1117,7 @@ bool RemotePluginClient::processMessage( const message & _m )
 
 		case IdMidiEvent:
 			processMidiEvent(
-				midiEvent( static_cast<MidiEventTypes>(
+				MidiEvent( static_cast<MidiEventTypes>(
 							_m.getInt( 0 ) ),
 						_m.getInt( 1 ),
 						_m.getInt( 2 ),
