@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2008 Javier Serrano Polo <jasp00/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,18 +28,18 @@
 
 #include <QtGui/QSlider>
 
-#include "automatable_model_view.h"
+#include "AutomatableModelView.h"
 
 
 
-class automatableSlider : public QSlider, public intModelView
+class automatableSlider : public QSlider, public IntModelView
 {
 	Q_OBJECT
 public:
 	automatableSlider( QWidget * _parent, const QString & _name = QString::null );
 	virtual ~automatableSlider();
 
-	bool showStatus( void )
+	bool showStatus()
 	{
 		return( m_showStatus );
 	}
@@ -56,7 +56,7 @@ protected:
 	virtual void mouseReleaseEvent( QMouseEvent * _me );
 	virtual void wheelEvent( QWheelEvent * _me );
 
-	virtual void modelChanged( void );
+	virtual void modelChanged();
 
 
 private:
@@ -66,12 +66,12 @@ private:
 private slots:
 	void changeValue( int _value );
 	void moveSlider( int _value );
-	void updateSlider( void );
+	void updateSlider();
 
 } ;
 
 
-typedef intModel sliderModel;
+typedef IntModel sliderModel;
 
 
 #endif
