@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ const QString LOCALE_PATH = "locale/";
 class EXPORT configManager
 {
 public:
-	static inline configManager * inst( void )
+	static inline configManager * inst()
 	{
 		if( s_instanceOfMe == NULL )
 		{
@@ -59,106 +59,106 @@ public:
 		return( s_instanceOfMe );
 	}
 
-	const QString & dataDir( void ) const
+	const QString & dataDir() const
 	{
 		return( m_dataDir );
 	}
 
-	const QString & workingDir( void ) const
+	const QString & workingDir() const
 	{
 		return( m_workingDir );
 	}
 
-	QString userProjectsDir( void ) const
+	QString userProjectsDir() const
 	{
 		return( workingDir() + PROJECTS_PATH );
 	}
 
-	QString userPresetsDir( void ) const
+	QString userPresetsDir() const
 	{
 		return( workingDir() + PRESETS_PATH );
 	}
 
-	QString userSamplesDir( void ) const
+	QString userSamplesDir() const
 	{
 		return( workingDir() + SAMPLES_PATH );
 	}
 
-	QString factoryProjectsDir( void ) const
+	QString factoryProjectsDir() const
 	{
 		return( dataDir() + PROJECTS_PATH );
 	}
 
-	QString factoryPresetsDir( void ) const
+	QString factoryPresetsDir() const
 	{
 		return( dataDir() + PRESETS_PATH );
 	}
 
-	QString factorySamplesDir( void ) const
+	QString factorySamplesDir() const
 	{
 		return( dataDir() + SAMPLES_PATH );
 	}
 
-	QString defaultArtworkDir( void ) const
+	QString defaultArtworkDir() const
 	{
 		return( m_dataDir + DEFAULT_THEME_PATH );
 	}
 
-	QString artworkDir( void ) const
+	QString artworkDir() const
 	{
 		return( m_artworkDir );
 	}
 
-	QString trackIconsDir( void ) const
+	QString trackIconsDir() const
 	{
 		return( m_dataDir + TRACK_ICON_PATH );
 	}
 
-	QString localeDir( void ) const
+	QString localeDir() const
 	{
 		return( m_dataDir + LOCALE_PATH );
 	}
 
-	const QString & pluginDir( void ) const
+	const QString & pluginDir() const
 	{
 		return( m_pluginDir );
 	}
 
-	const QString & vstDir( void ) const
+	const QString & vstDir() const
 	{
 		return( m_vstDir );
 	}
 
-	const QString & flDir( void ) const
+	const QString & flDir() const
 	{
 		return( m_flDir );
 	}
 
-	const QString & ladspaDir( void ) const
+	const QString & ladspaDir() const
 	{
 		return( m_ladDir );
 	}
 
 #ifdef LMMS_HAVE_STK
-	const QString & stkDir( void ) const
+	const QString & stkDir() const
 	{
 		return( m_stkDir );
 	}
 #endif
 
 #ifdef LMMS_HAVE_FLUIDSYNTH
-	const QString & defaultSoundfont( void ) const
+	const QString & defaultSoundfont() const
 	{
 		return( m_defaultSoundfont );
 	}
 #endif
 
-	const QString & backgroundArtwork( void ) const
+	const QString & backgroundArtwork() const
 	{
 		return( m_backgroundArtwork );
 	}
 
-	inline const QStringList & recentlyOpenedProjects( void ) const
+	inline const QStringList & recentlyOpenedProjects() const
 	{
 		return( m_recentlyOpenedProjects );
 	}
@@ -170,8 +170,8 @@ public:
 	void setValue( const QString & _class, const QString & _attribute,
 						const QString & _value );
 
-	void loadConfigFile( void );
-	void saveConfigFile( void );
+	void loadConfigFile();
+	void saveConfigFile();
 
 
 	void setWorkingDir( const QString & _wd );
@@ -187,7 +187,7 @@ public:
 private:
 	static configManager * s_instanceOfMe;
 
-	configManager( void );
+	configManager();
 	configManager( const configManager & _c );
 	~configManager();
 
