@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006 Danny McRae <khjklujn/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -17,17 +17,23 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
-#ifndef _LMMS_CONSTANTS_H
-#define _LMMS_CONSTANTS_H
+#ifndef LMMS_CONSTANTS_H
+#define LMMS_CONSTANTS_H
+
+const double D_PI = 3.14159265358979323846;
+const double D_2PI = D_PI * 2.0;
+const double D_PI_2 = D_PI * 0.5;
+const double D_E = 2.71828182845904523536; 
+
+const float F_PI = (float) D_PI;
+const float F_2PI = (float) D_2PI;
+const float F_PI_2 = (float) D_PI_2;
+const float F_E = (float) D_E;
 
-const float F_PI = 3.141593f;
-const float F_2PI = 6.283185f;
-const float F_PI_2 = 1.570796f;
 
 #endif
-
