@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -27,18 +27,8 @@
 #ifndef _RENAME_DIALOG_H
 #define _RENAME_DIALOG_H
 
-#include "qt3support.h"
-
-#ifdef QT4
-
 #include <QtGui/QDialog>
 
-#else
-
-#include <qdialog.h>
-
-#endif
-
 
 class QLineEdit;
 
