@@ -2,9 +2,9 @@
  * track.h - declaration of classes concerning tracks -> necessary for all
  *           track-like objects (beat/bassline, sample-track...)
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -23,15 +23,16 @@
  *
  */
 
-#ifndef _TRACK_H
-#define _TRACK_H
+#ifndef TRACK_H
+#define TRACK_H
 
 #include <QtCore/QVector>
 #include <QtCore/QList>
 #include <QtGui/QWidget>
+#include <QColor>
 
 #include "lmms_basics.h"
-#include "midi_time.h"
+#include "MidiTime.h"
 #include "rubberband.h"
 #include "JournallingObject.h"
 #include "AutomatableModel.h"
@@ -45,8 +46,8 @@ class pixmapButton;
 class textFloat;
 class track;
 class trackContentObjectView;
-class trackContainer;
-class trackContainerView;
+class TrackContainer;
+class TrackContainerView;
 class trackContentWidget;
 class trackView;
 
@@ -64,16 +65,17 @@ const int TRACK_OP_WIDTH_COMPACT = 60;
  * Tracks can be resized by shift-dragging anywhere inside the track
  * display.  This sets the minimum size in pixels for a track.
  */
-const Uint16 MINIMAL_TRACK_HEIGHT = 8;
-const Uint16 DEFAULT_TRACK_HEIGHT = 32;
+const int MINIMAL_TRACK_HEIGHT = 8;
+const int DEFAULT_TRACK_HEIGHT = 32;
 
-const int TCO_BORDER_WIDTH = 1;
+const int TCO_BORDER_WIDTH = 2;
 
 
 class trackContentObject : public Model, public JournallingObject
 {
 	Q_OBJECT
 	mapPropertyFromModel(bool,isMuted,setMuted,m_mutedModel);
+	mapPropertyFromModel(bool,isSolo,setSolo,m_soloModel);
 public:
 	trackContentObject( track * _track );
 	virtual ~trackContentObject();
@@ -100,24 +102,24 @@ public:
 	}
 
 
-	inline const midiTime & startPosition() const
+	inline const MidiTime & startPosition() const
 	{
 		return m_startPosition;
 	}
 
-	inline midiTime endPosition() const
+	inline MidiTime endPosition() const
 	{
 		const int sp = m_startPosition;
 		return sp + m_length;
 	}
 
-	inline const midiTime & length() const
+	inline const MidiTime & length() const
 	{
 		return m_length;
 	}
 
-	virtual void movePosition( const midiTime & _pos );
-	virtual void changeLength( const midiTime & _length );
+	virtual void movePosition( const MidiTime & _pos );
+	virtual void changeLength( const MidiTime & _length );
 
 	virtual trackContentObjectView * createView( trackView * _tv ) = 0;
 
@@ -128,11 +130,6 @@ public slots:
 	void toggleMute();
 
 
-protected:
-	virtual void undoStep( JournalEntry & _je );
-	virtual void redoStep( JournalEntry & _je );
-
-
 signals:
 	void lengthChanged();
 	void positionChanged();
@@ -150,10 +147,11 @@ private:
 	track * m_track;
 	QString m_name;
 
-	midiTime m_startPosition;
-	midiTime m_length;
+	MidiTime m_startPosition;
+	MidiTime m_length;
 
 	BoolModel m_mutedModel;
+	BoolModel m_soloModel;
 
 
 	friend class trackContentObjectView;
@@ -165,6 +163,11 @@ private:
 class trackContentObjectView : public selectableObject, public ModelView
 {
 	Q_OBJECT
+
+// theming qproperties
+	Q_PROPERTY( QColor fgColor READ fgColor WRITE setFgColor )
+	Q_PROPERTY( QColor textColor READ textColor WRITE setTextColor )
+
 public:
 	trackContentObjectView( trackContentObject * _tco, trackView * _tv );
 	virtual ~trackContentObjectView();
@@ -175,7 +178,11 @@ public:
 	{
 		return m_tco;
 	}
-
+// qproperty access func
+	QColor fgColor() const;
+	QColor textColor() const;
+	void setFgColor( const QColor & _c );
+	void setTextColor( const QColor & _c );
 
 public slots:
 	virtual bool close();
@@ -224,12 +231,15 @@ private:
 	trackView * m_trackView;
 	Actions m_action;
 	bool m_autoResize;
-	Sint16 m_initialMouseX;
+	int m_initialMouseX;
 
 	textFloat * m_hint;
 
-	midiTime m_oldTime;// used for undo/redo while mouse-button is pressed
+	MidiTime m_oldTime;// used for undo/redo while mouse-button is pressed
 
+// qproperty fields
+	QColor m_fgColor;
+	QColor m_textColor;
 } ;
 
 
@@ -239,6 +249,11 @@ private:
 class trackContentWidget : public QWidget, public JournallingObject
 {
 	Q_OBJECT
+
+	// qproperties for track background gradients
+	Q_PROPERTY( QBrush darkerColor READ darkerColor WRITE setDarkerColor )
+	Q_PROPERTY( QBrush lighterColor READ lighterColor WRITE setLighterColor )
+
 public:
 	trackContentWidget( trackView * _parent );
 	virtual ~trackContentWidget();
@@ -256,11 +271,19 @@ public:
 		}
 	}
 
-	midiTime endPosition( const midiTime & _pos_start );
+	MidiTime endPosition( const MidiTime & _pos_start );
+
+	// qproperty access methods
+
+	QBrush darkerColor() const;
+	QBrush lighterColor() const;
+
+	void setDarkerColor( const QBrush & _c );
+	void setLighterColor( const QBrush & _c );
 
 public slots:
 	void update();
-	void changePosition( const midiTime & _new_pos = midiTime( -1 ) );
+	void changePosition( const MidiTime & _new_pos = MidiTime( -1 ) );
 
 
 protected:
@@ -275,29 +298,32 @@ protected:
 		return "trackcontentwidget";
 	}
 
-	virtual void undoStep( JournalEntry & _je );
-	virtual void redoStep( JournalEntry & _je );
+	virtual void saveSettings( QDomDocument& doc, QDomElement& element )
+	{
+		Q_UNUSED(doc)
+		Q_UNUSED(element)
+	}
+
+	virtual void loadSettings( const QDomElement& element )
+	{
+		Q_UNUSED(element)
+	}
 
 
 private:
-	enum Actions
-	{
-		AddTrackContentObject,
-		RemoveTrackContentObject
-	} ;
-
 	track * getTrack();
-	midiTime getPosition( int _mouse_x );
+	MidiTime getPosition( int _mouse_x );
 
 	trackView * m_trackView;
 
 	typedef QVector<trackContentObjectView *> tcoViewVector;
 	tcoViewVector m_tcoViews;
 
-	int m_pixelsPerTact;
-
 	QPixmap m_background;
 
+	// qproperty fields
+	QBrush m_darkerColor;
+	QBrush m_lighterColor;
 } ;
 
 
@@ -321,7 +347,9 @@ private slots:
 	void cloneTrack();
 	void removeTrack();
 	void updateMenu();
-
+	void recordingOn();
+	void recordingOff();
+	void clearTrack();
 
 private:
 	static QPixmap * s_grip;
@@ -349,6 +377,7 @@ class EXPORT track : public Model, public JournallingObject
 {
 	Q_OBJECT
 	mapPropertyFromModel(bool,isMuted,setMuted,m_mutedModel);
+	mapPropertyFromModel(bool,isSolo,setSolo,m_soloModel);
 public:
 	typedef QVector<trackContentObject *> tcoVector;
 
@@ -364,12 +393,12 @@ public:
 		NumTrackTypes
 	} ;
 
-	track( TrackTypes _type, trackContainer * _tc );
+	track( TrackTypes _type, TrackContainer * _tc );
 	virtual ~track();
 
-	static track * create( TrackTypes _tt, trackContainer * _tc );
+	static track * create( TrackTypes _tt, TrackContainer * _tc );
 	static track * create( const QDomElement & _this,
-							trackContainer * _tc );
+							TrackContainer * _tc );
 	void clone();
 
 
@@ -379,13 +408,12 @@ public:
 		return m_type;
 	}
 
-	virtual bool play( const midiTime & _start, const fpp_t _frames,
-				const f_cnt_t _frame_base,
-						Sint16 _tco_num = -1 ) = 0;
+	virtual bool play( const MidiTime & _start, const fpp_t _frames,
+						const f_cnt_t _frame_base, int _tco_num = -1 ) = 0;
 
 
-	virtual trackView * createView( trackContainerView * _view ) = 0;
-	virtual trackContentObject * createTCO( const midiTime & _pos ) = 0;
+	virtual trackView * createView( TrackContainerView * _view ) = 0;
+	virtual trackContentObject * createTCO( const MidiTime & _pos ) = 0;
 
 	virtual void saveTrackSpecificSettings( QDomDocument & _doc,
 						QDomElement & _parent ) = 0;
@@ -404,6 +432,7 @@ public:
 	trackContentObject * addTCO( trackContentObject * _tco );
 	void removeTCO( trackContentObject * _tco );
 	// -------------------------------------------------------
+	void deleteTCOs();
 
 	int numOfTCOs();
 	trackContentObject * getTCO( int _tco_num );
@@ -413,20 +442,20 @@ public:
 	{
 		return( m_trackContentObjects );
 	}
-	void getTCOsInRange( tcoVector & _tco_v, const midiTime & _start,
-							const midiTime & _end );
+	void getTCOsInRange( tcoVector & _tco_v, const MidiTime & _start,
+							const MidiTime & _end );
 	void swapPositionOfTCOs( int _tco_num1, int _tco_num2 );
 
 
-	void insertTact( const midiTime & _pos );
-	void removeTact( const midiTime & _pos );
+	void insertTact( const MidiTime & _pos );
+	void removeTact( const MidiTime & _pos );
 
 	tact_t length() const;
 
 
-	inline trackContainer * getTrackContainer() const
+	inline TrackContainer* trackContainer() const
 	{
-		return( m_trackContainer );
+		return m_trackContainer;
 	}
 
 	// name-stuff
@@ -461,7 +490,7 @@ public slots:
 
 
 private:
-	trackContainer * m_trackContainer;
+	TrackContainer* m_trackContainer;
 	TrackTypes m_type;
 	QString m_name;
 	int m_height;
@@ -492,7 +521,7 @@ class trackView : public QWidget, public ModelView, public JournallingObject
 {
 	Q_OBJECT
 public:
-	trackView( track * _track, trackContainerView * _tcv );
+	trackView( track * _track, TrackContainerView* tcv );
 	virtual ~trackView();
 
 	inline const track * getTrack() const
@@ -505,9 +534,9 @@ public:
 		return( m_track );
 	}
 
-	inline trackContainerView * getTrackContainerView()
+	inline TrackContainerView* trackContainerView()
 	{
-		return( m_trackContainerView );
+		return m_trackContainerView;
 	}
 
 	inline trackOperationsWidget * getTrackOperationsWidget()
@@ -539,8 +568,17 @@ public slots:
 
 protected:
 	virtual void modelChanged();
-	virtual void undoStep( JournalEntry & _je );
-	virtual void redoStep( JournalEntry & _je );
+
+	virtual void saveSettings( QDomDocument& doc, QDomElement& element )
+	{
+		Q_UNUSED(doc)
+		Q_UNUSED(element)
+	}
+
+	virtual void loadSettings( const QDomElement& element )
+	{
+		Q_UNUSED(element)
+	}
 
 	virtual QString nodeName() const
 	{
@@ -566,7 +604,7 @@ private:
 	} ;
 
 	track * m_track;
-	trackContainerView * m_trackContainerView;
+	TrackContainerView * m_trackContainerView;
 
 	trackOperationsWidget m_trackOperationsWidget;
 	trackSettingsWidget m_trackSettingsWidget;
