@@ -2,9 +2,9 @@
  * volume.h - declaration of some constants and types, concerning the volume
  *            of a note
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,25 +29,15 @@
 #include "lmmsconfig.h"
 
 #include "lmms_basics.h"
+#include "Midi.h"
 
-const volume MinVolume = 0;
-const volume MaxVolume = 200;
-const volume DefaultVolume = 100;
+const volume_t MinVolume = 0;
+const volume_t MaxVolume = 200;
+const volume_t DefaultVolume = 100;
 
 typedef struct
 {
 	float vol[2];
 } stereoVolumeVector;
 
-
-typedef struct
-{
-#ifndef LMMS_DISABLE_SURROUND
-	float vol[4];
-#else
-	float vol[2];
-#endif
-} surroundVolumeVector;
-
-
 #endif
