@@ -2,9 +2,9 @@
  * audio_file_processor.h - declaration of class audioFileProcessor
  *                          (instrument-plugin for using audio-files)
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,17 +24,18 @@
  */
 
 
-#ifndef _AUDIO_FILE_PROCESSOR_H
-#define _AUDIO_FILE_PROCESSOR_H
+#ifndef AUDIO_FILE_PROCESSOR_H
+#define AUDIO_FILE_PROCESSOR_H
 
 #include <QtGui/QPixmap>
 
 #include "Instrument.h"
 #include "InstrumentView.h"
-#include "sample_buffer.h"
+#include "SampleBuffer.h"
 #include "knob.h"
 #include "pixmap_button.h"
-
+#include "automatable_button.h"
+#include "combobox.h"
 
 
 class audioFileProcessor : public Instrument
@@ -44,9 +45,9 @@ public:
 	audioFileProcessor( InstrumentTrack * _instrument_track );
 	virtual ~audioFileProcessor();
 
-	virtual void playNote( notePlayHandle * _n, 
+	virtual void playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer );
-	virtual void deleteNotePluginData( notePlayHandle * _n );
+	virtual void deleteNotePluginData( NotePlayHandle * _n );
 
 	virtual void saveSettings( QDomDocument & _doc,
 						QDomElement & _parent );
@@ -56,11 +57,11 @@ public:
 
 	virtual QString nodeName() const;
 
-	virtual Uint32 getBeatLen( notePlayHandle * _n ) const;
+	virtual int getBeatLen( NotePlayHandle * _n ) const;
 
 	virtual f_cnt_t desiredReleaseFrames() const
 	{
-		return( 128 );
+		return 128;
 	}
 
 	virtual PluginView * instantiateView( QWidget * _parent );
@@ -74,23 +75,32 @@ private slots:
 	void reverseModelChanged();
 	void ampModelChanged();
 	void loopPointChanged();
+	void startPointChanged();
+	void endPointChanged();
+	void pointChanged();
+	void stutterModelChanged();
 
 
 signals:
-	void isPlaying( f_cnt_t _frames_played );
+	void isPlaying( f_cnt_t _current_frame );
 
 
 private:
-	typedef sampleBuffer::handleState handleState;
+	typedef SampleBuffer::handleState handleState;
+
+	SampleBuffer m_sampleBuffer;
 
-	sampleBuffer m_sampleBuffer;
-	
 	FloatModel m_ampModel;
 	FloatModel m_startPointModel;
 	FloatModel m_endPointModel;
+	FloatModel m_loopPointModel;
 	BoolModel m_reverseModel;
-	BoolModel m_loopModel;
+	IntModel m_loopModel;
+	BoolModel m_stutterModel;
+	ComboBoxModel m_interpolationModel;
 
+	f_cnt_t m_nextPlayStartPoint;
+	bool m_nextPlayBackwards;
 
 	friend class AudioFileProcessorView;
 
@@ -108,7 +118,7 @@ public:
 	AudioFileProcessorView( Instrument * _instrument, QWidget * _parent );
 	virtual ~AudioFileProcessorView();
 
-
+	void newWaveView();
 protected slots:
 	void sampleUpdated();
 	void openAudioFile();
@@ -129,9 +139,13 @@ private:
 	knob * m_ampKnob;
 	knob * m_startKnob;
 	knob * m_endKnob;
+	knob * m_loopKnob;
+
 	pixmapButton * m_openAudioFileButton;
 	pixmapButton * m_reverseButton;
-	pixmapButton * m_loopButton;
+	automatableButtonGroup * m_loopGroup;
+	pixmapButton * m_stutterButton;
+	comboBox * m_interpBox;
 
 } ;
 
@@ -155,6 +169,7 @@ public:
 	{
 		start,
 		end,
+		loop
 	} ;
 
 	class knob : public ::knob
@@ -165,7 +180,7 @@ public:
 
 	public:
 		knob( QWidget * _parent ) :
-			::knob( knobStyled, _parent ),
+			::knob( knobBright_26, _parent ),
 			m_waveView( 0 ),
 			m_relatedKnob( 0 )
 		{
@@ -207,7 +222,7 @@ public slots:
 		QWidget::update();
 	}
 
-	void isPlaying( f_cnt_t _frames_played );
+	void isPlaying( f_cnt_t _current_frame );
 
 
 private:
@@ -218,28 +233,32 @@ private:
 		wave,
 		sample_start,
 		sample_end,
+		sample_loop
 	} ;
 
-	sampleBuffer & m_sampleBuffer;
+	SampleBuffer& m_sampleBuffer;
 	QPixmap m_graph;
 	f_cnt_t m_from;
 	f_cnt_t m_to;
 	f_cnt_t m_last_from;
 	f_cnt_t m_last_to;
+	float m_last_amp;
 	knob * m_startKnob;
 	knob * m_endKnob;
+	knob * m_loopKnob;
 	f_cnt_t m_startFrameX;
 	f_cnt_t m_endFrameX;
+	f_cnt_t m_loopFrameX;
 	bool m_isDragging;
 	QPoint m_draggingLastPoint;
 	draggingType m_draggingType;
 	bool m_reversed;
 	f_cnt_t m_framesPlayed;
-
+	bool m_animation;
 
 public:
-	AudioFileProcessorWaveView( QWidget * _parent, int _w, int _h, sampleBuffer & _buf );
-	void setKnobs( knob * _start, knob * _end );
+	AudioFileProcessorWaveView( QWidget * _parent, int _w, int _h, SampleBuffer& buf );
+	void setKnobs( knob * _start, knob * _end, knob * _loop );
 
 
 private:
@@ -259,7 +278,7 @@ private:
 
 	static bool isCloseTo( int _a, int _b )
 	{
-		return qAbs( _a - _b ) < 3;
+		return qAbs( _a - _b ) < 4;
 	}
 
 } ;
