@@ -71,7 +71,7 @@
 
 #include "defs.h"
 #include "parse.h"
-#include "malloc.h"
+#include "ur_malloc.h"
 #include "main.h"
 #include "error.h"
 #include "word.h"
