@@ -1,14 +1,14 @@
 /*
- * lb302.cpp - implementation of class lb302 which is a bass synth attempting 
+ * lb302.cpp - implementation of class lb302 which is a bass synth attempting
  *             to emulate the Roland TB303 bass synth
  *
  * Copyright (c) 2006-2008 Paul Giblock <pgib/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * lb302FilterIIR2 is based on the gsyn filter code by Andy Sloane.
- * 
- * lb302Filter3Pole is based on the TB303 instrument written by 
+ *
+ * lb302Filter3Pole is based on the TB303 instrument written by
  *   Josep M Comajuncosas for the CSounds library
  *
  * This program is free software; you can redistribute it and/or
@@ -34,26 +34,26 @@
 #include "InstrumentPlayHandle.h"
 #include "InstrumentTrack.h"
 #include "knob.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "Oscillator.h"
 #include "pixmap_button.h"
 #include "templates.h"
 #include "tooltip.h"
+#include "BandLimitedWave.h"
 
 #include "embed.cpp"
 #include "moc_lb302.cxx"
 
-
 // Envelope Recalculation period
 #define ENVINC 64
 
 //
 // New config
 //
-#define LB_24_IGNORE_ENVELOPE   
-#define LB_FILTERED 
+#define LB_24_IGNORE_ENVELOPE
+#define LB_FILTERED
 //#define LB_DECAY
-//#define LB_24_RES_TRICK         
+//#define LB_24_RES_TRICK
 
 #define LB_DIST_RATIO    4.0
 #define LB_24_VOL_ADJUST 3.0
@@ -70,7 +70,7 @@
 //
 
 
-//#define engine::getMixer()->processingSampleRate() 44100.0f
+//#define engine::mixer()->processingSampleRate() 44100.0f
 
 
 extern "C"
@@ -109,8 +109,8 @@ void lb302Filter::recalc()
 {
 	vcf_e1 = exp(6.109 + 1.5876*(fs->envmod) + 2.1553*(fs->cutoff) - 1.2*(1.0-(fs->reso)));
 	vcf_e0 = exp(5.613 - 0.8*(fs->envmod) + 2.1553*(fs->cutoff) - 0.7696*(1.0-(fs->reso)));
-	vcf_e0*=M_PI/engine::getMixer()->processingSampleRate();
-	vcf_e1*=M_PI/engine::getMixer()->processingSampleRate();
+	vcf_e0*=M_PI/engine::mixer()->processingSampleRate();
+	vcf_e1*=M_PI/engine::mixer()->processingSampleRate();
 	vcf_e1 -= vcf_e0;
 
 	vcf_rescoeff = exp(-1.20 + 3.455*(fs->reso));
@@ -143,8 +143,8 @@ lb302FilterIIR2::lb302FilterIIR2(lb302FilterKnobState* p_fs) :
 	vcf_c(1)
 {
 
-	m_dist = new effectLib::distortion( 1.0, 1.0f);
-	
+	m_dist = new DspEffectLibrary::Distortion( 1.0, 1.0f);
+
 };
 
 
@@ -184,7 +184,7 @@ float lb302FilterIIR2::process(const float& samp)
 	vcf_d2 = vcf_d1;
 	vcf_d1 = ret;
 
-	if(fs->dist > 0) 
+	if(fs->dist > 0)
 		ret=m_dist->nextSample(ret);
 
 	// output = IIR2 + dry
@@ -201,7 +201,7 @@ lb302Filter3Pole::lb302Filter3Pole(lb302FilterKnobState *p_fs) :
 	ay1(0),
 	ay2(0),
 	aout(0),
-	lastin(0) 
+	lastin(0)
 {
 };
 
@@ -226,14 +226,14 @@ void lb302Filter3Pole::envRecalc()
 	w = vcf_e0 + vcf_c0;
 	k = (fs->cutoff > 0.975)?0.975:fs->cutoff;
 	kfco = 50.f + (k)*((2300.f-1600.f*(fs->envmod))+(w) *
-	                   (700.f+1500.f*(k)+(1500.f+(k)*(engine::getMixer()->processingSampleRate()/2.f-6000.f)) * 
+	                   (700.f+1500.f*(k)+(1500.f+(k)*(engine::mixer()->processingSampleRate()/2.f-6000.f)) *
 	                   (fs->envmod)) );
 	//+iacc*(.3+.7*kfco*kenvmod)*kaccent*kaccurve*2000
 
 
 #ifdef LB_24_IGNORE_ENVELOPE
 	// kfcn = fs->cutoff;
-	kfcn = 2.0 * kfco / engine::getMixer()->processingSampleRate();
+	kfcn = 2.0 * kfco / engine::mixer()->processingSampleRate();
 #else
 	kfcn = w;
 #endif
@@ -250,7 +250,7 @@ void lb302Filter3Pole::envRecalc()
 }
 
 
-float lb302Filter3Pole::process(const float& samp) 
+float lb302Filter3Pole::process(const float& samp)
 {
 	float ax1  = lastin;
 	float ay11 = ay1;
@@ -275,16 +275,16 @@ lb302Synth::lb302Synth( InstrumentTrack * _instrumentTrack ) :
 	vcf_mod_knob( 0.1f, 0.0f, 1.0f, 0.005f, this, tr( "VCF Envelope Mod" ) ),
 	vcf_dec_knob( 0.1f, 0.0f, 1.0f, 0.005f, this, tr( "VCF Envelope Decay" ) ),
 	dist_knob( 0.0f, 0.0f, 1.0f, 0.01f, this, tr( "Distortion" ) ),
-	wave_shape( 0.0f, 0.0f, 7.0f, this, tr( "Waveform" ) ),
+	wave_shape( 8.0f, 0.0f, 11.0f, this, tr( "Waveform" ) ),
 	slide_dec_knob( 0.6f, 0.0f, 1.0f, 0.005f, this, tr( "Slide Decay" ) ),
 	slideToggle( false, this, tr( "Slide" ) ),
 	accentToggle( false, this, tr( "Accent" ) ),
 	deadToggle( false, this, tr( "Dead" ) ),
-	db24Toggle( false, this, tr( "24dB/oct Filter" ) )	
+	db24Toggle( false, this, tr( "24dB/oct Filter" ) )
 
 {
 
-	connect( engine::getMixer(), SIGNAL( sampleRateChanged( ) ),
+	connect( engine::mixer(), SIGNAL( sampleRateChanged( ) ),
 	         this, SLOT ( filterChanged( ) ) );
 
 	connect( &vcf_cut_knob, SIGNAL( dataChanged( ) ),
@@ -331,38 +331,38 @@ lb302Synth::lb302Synth( InstrumentTrack * _instrumentTrack ) :
 	vca_attack = 1.0 - 0.96406088;
 	vca_decay = 0.99897516;
 
-	vco_shape = SAWTOOTH; 
+	vco_shape = BL_SAWTOOTH;
 
 	// Experimenting with a0 between original (0.5) and 1.0
 	vca_a0 = 0.5;
 	vca_a = 9;
 	vca_mode = 3;
 
-	vcf = new lb302FilterIIR2(&fs);
+	vcfs[0] = new lb302FilterIIR2(&fs);
+	vcfs[1] = new lb302Filter3Pole(&fs);
+	db24Toggled();
 
 	sample_cnt = 0;
-	release_frame = 1<<24;
+	release_frame = 0;
 	catch_frame = 0;
 	catch_decay = 0;
 
-	recalcFilter();
-
 	last_offset = 0;
 
-	new_freq = -1;
-	current_freq = -1;
-	delete_freq = -1;
-
-	InstrumentPlayHandle * iph = new InstrumentPlayHandle( this );
-	engine::getMixer()->addPlayHandle( iph );
+	new_freq = false;
 
 	filterChanged();
+
+	InstrumentPlayHandle * iph = new InstrumentPlayHandle( this );
+	engine::mixer()->addPlayHandle( iph );
 }
 
 
 lb302Synth::~lb302Synth()
 {
-	delete vcf;
+	for (int i=0; i<NUM_FILTERS; ++i) {
+		delete vcfs[i];
+	}
 }
 
 
@@ -397,6 +397,7 @@ void lb302Synth::loadSettings( const QDomElement & _this )
 	slideToggle.loadSettings( _this, "slide");
 	deadToggle.loadSettings( _this, "dead");
 	db24Toggle.loadSettings( _this, "db24");
+ 	db24Toggled();
 
 	filterChanged();
 }
@@ -412,7 +413,7 @@ void lb302Synth::filterChanged()
 
 	float d = 0.2 + (2.3*vcf_dec_knob.value());
 
-	d *= engine::getMixer()->processingSampleRate();                                // d *= smpl rate
+	d *= engine::mixer()->processingSampleRate();                                // d *= smpl rate
 	fs.envdecay = pow(0.1, 1.0/d * ENVINC);    // decay is 0.1 to the 1/d * ENVINC
 	                                           // vcf_envdecay is now adjusted for both
 	                                           // sampling rate and ENVINC
@@ -422,13 +423,8 @@ void lb302Synth::filterChanged()
 
 void lb302Synth::db24Toggled()
 {
-	delete vcf;
-	if(db24Toggle.value()) {
-		vcf = new lb302Filter3Pole(&fs);
-	}
-	else {
-		vcf = new lb302FilterIIR2(&fs);
-	}
+	vcf = vcfs[db24Toggle.value()];
+	// These recalcFilter calls might suck
 	recalcFilter();
 }
 
@@ -448,7 +444,7 @@ void lb302Synth::recalcFilter()
 	// THIS IS OLD 3pole/24dB code, I may reintegrate it.  Don't need it
 	// right now.   Should be toggled by LB_24_RES_TRICK at the moment.
 
-	/*kfcn = 2.0 * (((vcf_cutoff*3000))) / engine::getMixer()->processingSampleRate();
+	/*kfcn = 2.0 * (((vcf_cutoff*3000))) / engine::mixer()->processingSampleRate();
 	kp   = ((-2.7528*kfcn + 3.0429)*kfcn + 1.718)*kfcn - 0.9984;
 	kp1  = kp+1.0;
 	kp1h = 0.5*kp1;
@@ -463,55 +459,57 @@ inline int MIN(int a, int b) {
 }
 
 inline float GET_INC(float freq) {
-	return freq/engine::getMixer()->processingSampleRate();  // TODO: Use actual sampling rate.
+	return freq/engine::mixer()->processingSampleRate();  // TODO: Use actual sampling rate.
 }
 
-int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
+int lb302Synth::process(sampleFrame *outbuf, const int size)
 {
-	unsigned int i;
+	const float sampleRatio = 44100.f / engine::mixer()->processingSampleRate();
 	float w;
 	float samp;
 
-	if( delete_freq == current_freq ) {
-		// Normal release
-		delete_freq = -1;
+	// Hold on to the current VCF, and use it throughout this period
+	lb302Filter *filter = vcf;
+
+	if( release_frame == 0 || ! m_playingNote ) 
+	{
 		vca_mode = 1;
 	}
 
-	if( new_freq > 0.0f ) {
+	if( new_freq ) 
+	{
 		//printf("  playing new note..\n");
 		lb302Note note;
 		note.vco_inc = GET_INC( true_freq );
-		//printf("GET_INC %f %f %d\n", note.vco_inc, new_freq, vca_mode );
-		///**vco_detune*//engine::getMixer()->processingSampleRate();  // TODO: Use actual sampling rate.
-		//printf("VCO_INC = %f\n", note.vco_inc);
 		note.dead = deadToggle.value();
 		initNote(&note);
-		//printf("%f %f,  ", vco_inc, vco_c);
-		
-		current_freq = new_freq; 
 
-		new_freq = -1.0f;
-		//printf("GOT_INC %f %f %d\n\n", note.vco_inc, new_freq, vca_mode );
-	} 
+		new_freq = false;
+	}
+
 
-	
 
 	// TODO: NORMAL RELEASE
 	// vca_mode = 1;
 
-	for(i=0;i<size;i++) {
+	for( int i=0; i<size; i++ ) 
+	{
+		// start decay if we're past release
+		if( i >= release_frame )
+		{
+			vca_mode = 1;
+		}
 
 		// update vcf
 		if(vcf_envpos >= ENVINC) {
-			vcf->envRecalc();
+			filter->envRecalc();
 
 			vcf_envpos = 0;
 
 			if (vco_slide) {
-					vco_inc=vco_slidebase-vco_slide;
+					vco_inc = vco_slidebase - vco_slide;
 					// Calculate coeff from dec_knob on knob change.
-					vco_slide*= 0.9+(slide_dec_knob.value()*0.0999); // TODO: Adjust for Hz and ENVINC
+					vco_slide -= vco_slide * ( 0.1f - slide_dec_knob.value() * 0.0999f ) * sampleRatio; // TODO: Adjust for ENVINC
 
 			}
 		}
@@ -524,17 +522,10 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 
 		// update vco
 		vco_c += vco_inc;
-
+		
 		if(vco_c > 0.5)
 			vco_c -= 1.0;
 
-		/*LB303
-		if (catch_decay > 0) {
-			if (catch_decay < decay_frames) {
-				catch_decay++;
-			}
-		}*/
-
 		switch(int(rint(wave_shape.value()))) {
 			case 0: vco_shape = SAWTOOTH; break;
 			case 1: vco_shape = TRIANGLE; break;
@@ -544,6 +535,10 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 			case 5: vco_shape = SINE; break;
 			case 6: vco_shape = EXPONENTIAL; break;
 			case 7: vco_shape = WHITE_NOISE; break;
+			case 8: vco_shape = BL_SAWTOOTH; break;
+			case 9: vco_shape = BL_SQUARE; break;
+			case 10: vco_shape = BL_TRIANGLE; break;
+			case 11: vco_shape = BL_MOOG; break;
 			default:  vco_shape = SAWTOOTH; break;
 		}
 
@@ -569,7 +564,7 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 				break;
 
 			case MOOG: // Maybe the fall should be exponential/sinsoidal instead of quadric.
-				// [-0.5, 0]: Rise, [0,0.25]: Slope down, [0.25,0.5]: Low 
+				// [-0.5, 0]: Rise, [0,0.25]: Slope down, [0.25,0.5]: Low
 				vco_k = (vco_c*2.0)+0.5;
 				if (vco_k>1.0) {
 					vco_k = -0.5 ;
@@ -578,7 +573,7 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 					w = 2.0*(vco_k-0.5)-1.0;
 					vco_k = 0.5 - sqrtf(1.0-(w*w));
 				}
-				vco_k *= 2.0;  // MOOG wave gets filtered away 
+				vco_k *= 2.0;  // MOOG wave gets filtered away
 				break;
 
 			case SINE:
@@ -593,6 +588,22 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 			case WHITE_NOISE:
 				vco_k = 0.5 * Oscillator::noiseSample( vco_c );
 				break;
+
+			case BL_SAWTOOTH:
+				vco_k = BandLimitedWave::oscillate( vco_c + 0.5f, BandLimitedWave::pdToLen( vco_inc ), BandLimitedWave::BLSaw ) * 0.5f;
+				break;
+
+			case BL_SQUARE:
+				vco_k = BandLimitedWave::oscillate( vco_c + 0.5f, BandLimitedWave::pdToLen( vco_inc ), BandLimitedWave::BLSquare ) * 0.5f;
+				break;
+
+			case BL_TRIANGLE:
+				vco_k = BandLimitedWave::oscillate( vco_c + 0.5f, BandLimitedWave::pdToLen( vco_inc ), BandLimitedWave::BLTriangle ) * 0.5f;
+				break;
+
+			case BL_MOOG:
+				vco_k = BandLimitedWave::oscillate( vco_c + 0.5f, BandLimitedWave::pdToLen( vco_inc ), BandLimitedWave::BLMoog );
+				break;
 		}
 
 		//vca_a = 0.5;
@@ -600,9 +611,9 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 #ifdef LB_FILTERED
 		//samp = vcf->process(vco_k)*2.0*vca_a;
 		//samp = vcf->process(vco_k)*2.0;
-		samp = vcf->process(vco_k) * vca_a;
-		//printf("%f %d\n", vco_c, sample_cnt);	
-		
+		samp = filter->process(vco_k) * vca_a;
+		//printf("%f %d\n", vco_c, sample_cnt);
+
 
 		//samp = vco_k * vca_a;
 
@@ -610,7 +621,7 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 		{
 	//			vca_a = 0;
 		}
-		
+
 #else
 		//samp = vco_k*vca_a;
 #endif
@@ -620,21 +631,15 @@ int lb302Synth::process(sampleFrame *outbuf, const Uint32 size)
 		*/
 		//LB302 samp *= (float)(decay_frames - catch_decay)/(float)decay_frames;
 
-		for(int c=0; c<DEFAULT_CHANNELS; c++) {
-			outbuf[i][c]=samp;
+		for( int c = 0; c < DEFAULT_CHANNELS; c++ ) 
+		{
+			outbuf[i][c] = samp;
 		}
 
-
-		/*LB303
-		if((int)i>=release_frame) {
-			vca_mode=1;
-		}
-		*/
-
 		// Handle Envelope
 		if(vca_mode==0) {
 			vca_a+=(vca_a0-vca_a)*vca_attack;
-			if(sample_cnt>=0.5*engine::getMixer()->processingSampleRate()) 
+			if(sample_cnt>=0.5*engine::mixer()->processingSampleRate())
 				vca_mode = 2;
 		}
 		else if(vca_mode == 1) {
@@ -662,7 +667,7 @@ void lb302Synth::initNote( lb302Note *n)
 	catch_decay = 0;
 
 	vco_inc = n->vco_inc;
-    
+
 	// Always reset vca on non-dead notes, and
 	// Only reset vca on decaying(decayed) and never-played
 	if(n->dead == 0 || (vca_mode==1 || vca_mode==3)) {
@@ -676,8 +681,32 @@ void lb302Synth::initNote( lb302Note *n)
 		vca_mode = 2;
 	}
 
+	initSlide();
+
+	// Slide-from note, save inc for next note
+	if (slideToggle.value()) {
+		vco_slideinc = vco_inc; // May need to equal vco_slidebase+vco_slide if last note slid
+	}
+
+
+	recalcFilter();
+
+	if(n->dead ==0){
+		// Swap next two blocks??
+		vcf->playNote();
+		// Ensure envelope is recalculated
+		vcf_envpos = ENVINC;
+
+		// Double Check
+		//vca_mode = 0;
+		//vca_a = 0.0;
+	}
+}
+
+
+void lb302Synth::initSlide()
+{
 	// Initiate Slide
-	// TODO: Break out into function, should be called again on detuneChanged
 	if (vco_slideinc) {
 		//printf("    sliding\n");
 		vco_slide = vco_inc-vco_slideinc;	// Slide amount
@@ -687,71 +716,55 @@ void lb302Synth::initNote( lb302Note *n)
 	else {
 		vco_slide = 0;
 	}
-	// End break-out
-
-	// Slide-from note, save inc for next note
-	if (slideToggle.value()) {
-		vco_slideinc = vco_inc; // May need to equal vco_slidebase+vco_slide if last note slid
-	}
-
-
-	recalcFilter();
-	
-	if(n->dead ==0){
-		// Swap next two blocks??
-		vcf->playNote();
-		// Ensure envelope is recalculated
-		vcf_envpos = ENVINC;
-
-		// Double Check 
-		//vca_mode = 0;
-		//vca_a = 0.0;
-	}
 }
 
 
-void lb302Synth::playNote( notePlayHandle * _n, sampleFrame * _working_buffer )
+void lb302Synth::playNote( NotePlayHandle * _n, sampleFrame * _working_buffer )
 {
-	//fpp_t framesPerPeriod = engine::getMixer()->framesPerPeriod();
-
-	if( _n->isArpeggioBaseNote() )
+	if( _n->isMasterNote() || ( _n->hasParent() && _n->isReleased() ) )
 	{
 		return;
 	}
 
-	// Currently have release/decay disabled
-	// Start the release decay if this is the first release period.
-	//if (_n->released() && catch_decay == 0)
-	//        catch_decay = 1;
-
-	bool decay_note = false;
-
-	release_frame = _n->framesLeft() - desiredReleaseFrames();
+	// sort notes: new notes to the end
+	m_notesMutex.lock();
+	if( _n->totalFramesPlayed() == 0 )
+	{
+		m_notes.append( _n );
+	}
+	else
+	{
+		m_notes.prepend( _n );
+	}
+	m_notesMutex.unlock();
+	
+	release_frame = qMax( release_frame, _n->framesLeft() + _n->offset() );
+}
 
 
-	//LB303 if ( _n->totalFramesPlayed() <= 0 ) {
-		// This code is obsolete, hence the "if false"
 
-		// Existing note. Allow it to decay. 
-		if(deadToggle.value() == 0 && decay_note) {
-
-	/*		lb302Note note;
-			note.vco_inc = _n->frequency()*vco_detune/engine::getMixer()->processingSampleRate();  // TODO: Use actual sampling rate.
-			note.dead = deadToggle.value();
-			initNote(&note);
-			vca_mode=0;
-	*/
-
-		}
+void lb302Synth::processNote( NotePlayHandle * _n )
+{
 		/// Start a new note.
-		else if( _n->totalFramesPlayed() == 0 ) {
-			new_freq = _n->unpitchedFrequency();
-			true_freq = _n->frequency();
+		if( _n->m_pluginData != this ) 
+		{
+			m_playingNote = _n;
+			new_freq = true;
 			_n->m_pluginData = this;
 		}
+		
+		if( ! m_playingNote && ! _n->isReleased() && release_frame > 0 )
+		{
+			m_playingNote = _n;
+			if ( slideToggle.value() ) 
+			{
+				vco_slideinc = GET_INC( _n->frequency() );
+			}
+		}
 
 		// Check for slide
-		if( _n->unpitchedFrequency() == current_freq ) {
+		if( m_playingNote == _n ) 
+		{
 			true_freq = _n->frequency();
 
 			if( slideToggle.value() ) {
@@ -761,32 +774,34 @@ void lb302Synth::playNote( notePlayHandle * _n, sampleFrame * _working_buffer )
 				vco_inc = GET_INC( true_freq );
 			}
 		}
-
-	//LB303 }
-
-
 }
 
 
 
 void lb302Synth::play( sampleFrame * _working_buffer )
 {
-	//printf(".");
-	const fpp_t frames = engine::getMixer()->framesPerPeriod();
+	m_notesMutex.lock();
+	while( ! m_notes.isEmpty() )
+	{
+		processNote( m_notes.takeFirst() );
+	};
+	m_notesMutex.unlock();
+	
+	const fpp_t frames = engine::mixer()->framesPerPeriod();
 
-	process( _working_buffer, frames); 
-	instrumentTrack()->processAudioBuffer( _working_buffer, frames,
-									NULL );
+	process( _working_buffer, frames );
+	instrumentTrack()->processAudioBuffer( _working_buffer, frames, NULL );
+//	release_frame = 0; //removed for issue # 1432
 }
 
 
 
-void lb302Synth::deleteNotePluginData( notePlayHandle * _n )
+void lb302Synth::deleteNotePluginData( NotePlayHandle * _n )
 {
 	//printf("GONE\n");
-	if( _n->unpitchedFrequency() == current_freq ) 
+	if( m_playingNote == _n )
 	{
-		delete_freq = current_freq;
+		m_playingNote = NULL;
 	}
 }
 
@@ -804,35 +819,35 @@ lb302SynthView::lb302SynthView( Instrument * _instrument, QWidget * _parent ) :
 	m_vcfCutKnob = new knob( knobBright_26, this );
 	m_vcfCutKnob->move( 75, 130 );
 	m_vcfCutKnob->setHintText( tr( "Cutoff Freq:" ) + " ", "" );
-	m_vcfCutKnob->setLabel( tr("CUT") );
+	m_vcfCutKnob->setLabel( "" );
 
 	m_vcfResKnob = new knob( knobBright_26, this );
 	m_vcfResKnob->move( 120, 130 );
 	m_vcfResKnob->setHintText( tr( "Resonance:" ) + " ", "" );
-	m_vcfResKnob->setLabel( tr("RES") );
+	m_vcfResKnob->setLabel( "" );
 
 	m_vcfModKnob = new knob( knobBright_26, this );
 	m_vcfModKnob->move( 165, 130 );
 	m_vcfModKnob->setHintText( tr( "Env Mod:" ) + " ", "" );
-	m_vcfModKnob->setLabel( tr("ENV MOD") );
+	m_vcfModKnob->setLabel( "" );
 
 	m_vcfDecKnob = new knob( knobBright_26, this );
 	m_vcfDecKnob->move( 210, 130 );
 	m_vcfDecKnob->setHintText( tr( "Decay:" ) + " ", "" );
-	m_vcfDecKnob->setLabel( tr("DEC") );
+	m_vcfDecKnob->setLabel( "" );
 
-	m_slideToggle = new ledCheckBox( "Slide", this );
+	m_slideToggle = new ledCheckBox( "", this );
 	m_slideToggle->move( 10, 180 );
 
-	m_accentToggle = new ledCheckBox( "Accent", this );
+/*	m_accentToggle = new ledCheckBox( "", this );
 	m_accentToggle->move( 10, 200 );
-	m_accentToggle->setDisabled(true);
+	m_accentToggle->setDisabled(true);*/ // accent removed pending real implementation - no need for non-functional buttons
 
-	m_deadToggle = new ledCheckBox( "Dead", this );
-	m_deadToggle->move( 10, 220 );
+	m_deadToggle = new ledCheckBox( "", this );
+	m_deadToggle->move( 10, 200 );
 
-	m_db24Toggle = new ledCheckBox( "24dB/oct", this );
-	m_db24Toggle->setWhatsThis( 
+	m_db24Toggle = new ledCheckBox( "", this );
+	m_db24Toggle->setWhatsThis(
 			tr( "303-es-que, 24dB/octave, 3 pole filter" ) );
 	m_db24Toggle->move( 10, 150);
 
@@ -840,12 +855,12 @@ lb302SynthView::lb302SynthView( Instrument * _instrument, QWidget * _parent ) :
 	m_slideDecKnob = new knob( knobBright_26, this );
 	m_slideDecKnob->move( 210, 75 );
 	m_slideDecKnob->setHintText( tr( "Slide Decay:" ) + " ", "" );
-	m_slideDecKnob->setLabel( tr( "SLIDE"));
+	m_slideDecKnob->setLabel( "");
 
 	m_distKnob = new knob( knobBright_26, this );
 	m_distKnob->move( 210, 190 );
 	m_distKnob->setHintText( tr( "DIST:" ) + " ", "" );
-	m_distKnob->setLabel( tr( "DIST"));
+	m_distKnob->setLabel( tr( ""));
 
 
 	// Shapes
@@ -889,8 +904,8 @@ lb302SynthView::lb302SynthView( Instrument * _instrument, QWidget * _parent ) :
 					"round_square_wave_inactive" ) );
 	toolTip::add( roundSqrWaveBtn,
 			tr( "Click here for a square-wave with a rounded end." ) );
-	
-	pixmapButton * moogWaveBtn =	
+
+	pixmapButton * moogWaveBtn =
 		new pixmapButton( this, tr( "Moog wave" ) );
 	moogWaveBtn->move( waveBtnX+(16*4), waveBtnY );
 	moogWaveBtn->setActiveGraphic(
@@ -930,6 +945,47 @@ lb302SynthView::lb302SynthView( Instrument * _instrument, QWidget * _parent ) :
 	toolTip::add( whiteNoiseWaveBtn,
 			tr( "Click here for white-noise." ) );
 
+	pixmapButton * blSawWaveBtn =
+		new pixmapButton( this, tr( "Bandlimited saw wave" ) );
+	blSawWaveBtn->move( waveBtnX+(16*9)-8, waveBtnY );
+	blSawWaveBtn->setActiveGraphic(
+		embed::getIconPixmap( "saw_wave_active" ) );
+	blSawWaveBtn->setInactiveGraphic(
+		embed::getIconPixmap( "saw_wave_inactive" ) );
+	toolTip::add( blSawWaveBtn,
+			tr( "Click here for bandlimited saw wave." ) );
+
+	pixmapButton * blSquareWaveBtn =
+		new pixmapButton( this, tr( "Bandlimited square wave" ) );
+	blSquareWaveBtn->move( waveBtnX+(16*10)-8, waveBtnY );
+	blSquareWaveBtn->setActiveGraphic(
+		embed::getIconPixmap( "square_wave_active" ) );
+	blSquareWaveBtn->setInactiveGraphic(
+		embed::getIconPixmap( "square_wave_inactive" ) );
+	toolTip::add( blSquareWaveBtn,
+			tr( "Click here for bandlimited square wave." ) );
+
+	pixmapButton * blTriangleWaveBtn =
+		new pixmapButton( this, tr( "Bandlimited triangle wave" ) );
+	blTriangleWaveBtn->move( waveBtnX+(16*11)-8, waveBtnY );
+	blTriangleWaveBtn->setActiveGraphic(
+		embed::getIconPixmap( "triangle_wave_active" ) );
+	blTriangleWaveBtn->setInactiveGraphic(
+		embed::getIconPixmap( "triangle_wave_inactive" ) );
+	toolTip::add( blTriangleWaveBtn,
+			tr( "Click here for bandlimited triangle wave." ) );
+
+	pixmapButton * blMoogWaveBtn =
+		new pixmapButton( this, tr( "Bandlimited moog saw wave" ) );
+	blMoogWaveBtn->move( waveBtnX+(16*12)-8, waveBtnY );
+	blMoogWaveBtn->setActiveGraphic(
+		embed::getIconPixmap( "moog_saw_wave_active" ) );
+	blMoogWaveBtn->setInactiveGraphic(
+		embed::getIconPixmap( "moog_saw_wave_inactive" ) );
+	toolTip::add( blMoogWaveBtn,
+			tr( "Click here for bandlimited moog saw wave." ) );
+
+
 	m_waveBtnGrp = new automatableButtonGroup( this );
 	m_waveBtnGrp->addButton( sawWaveBtn );
 	m_waveBtnGrp->addButton( triangleWaveBtn );
@@ -939,6 +995,10 @@ lb302SynthView::lb302SynthView( Instrument * _instrument, QWidget * _parent ) :
 	m_waveBtnGrp->addButton( sinWaveBtn );
 	m_waveBtnGrp->addButton( exponentialWaveBtn );
 	m_waveBtnGrp->addButton( whiteNoiseWaveBtn );
+	m_waveBtnGrp->addButton( blSawWaveBtn );
+	m_waveBtnGrp->addButton( blSquareWaveBtn );
+	m_waveBtnGrp->addButton( blTriangleWaveBtn );
+	m_waveBtnGrp->addButton( blMoogWaveBtn );
 
 	setAutoFillBackground( true );
 	QPalette pal;
@@ -956,7 +1016,7 @@ lb302SynthView::~lb302SynthView()
 void lb302SynthView::modelChanged()
 {
 	lb302Synth * syn = castModel<lb302Synth>();
-	
+
 	m_vcfCutKnob->setModel( &syn->vcf_cut_knob );
 	m_vcfResKnob->setModel( &syn->vcf_res_knob );
 	m_vcfDecKnob->setModel( &syn->vcf_dec_knob );
@@ -965,9 +1025,9 @@ void lb302SynthView::modelChanged()
 
 	m_distKnob->setModel( &syn->dist_knob );
 	m_waveBtnGrp->setModel( &syn->wave_shape );
-    
+
 	m_slideToggle->setModel( &syn->slideToggle );
-	m_accentToggle->setModel( &syn->accentToggle );
+	/*m_accentToggle->setModel( &syn->accentToggle );*/
 	m_deadToggle->setModel( &syn->deadToggle );
 	m_db24Toggle->setModel( &syn->db24Toggle );
 }
