@@ -3,12 +3,12 @@
  *           emulate the Roland TB303 bass synth
  *
  * Copyright (c) 2006-2008 Paul Giblock <pgib/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * lb302FilterIIR2 is based on the gsyn filter code by Andy Sloane.
- * 
- * lb302Filter3Pole is based on the TB303 instrument written by 
+ *
+ * lb302Filter3Pole is based on the TB303 instrument written by
  *   Josep M Comajuncosas for the CSounds library
  *
  * This program is free software; you can redistribute it and/or
@@ -29,18 +29,22 @@
  */
 
 
-#ifndef _LB302_H_
-#define _LB302_H_
+#ifndef LB302_H_
+#define LB302_H_
 
-#include "effect_lib.h"
+#include "DspEffectLibrary.h"
 #include "Instrument.h"
 #include "InstrumentView.h"
 #include "led_checkbox.h"
 #include "knob.h"
-#include "mixer.h"
+#include "Mixer.h"
+#include "NotePlayHandle.h"
+#include <QMutex>
+
+static const int NUM_FILTERS = 2;
 
 class lb302SynthView;
-class notePlayHandle;
+class NotePlayHandle;
 
 class lb302FilterKnobState
 {
@@ -65,12 +69,12 @@ class lb302Filter
 	virtual void playNote();
 
 	protected:
-	lb302FilterKnobState *fs;  
+	lb302FilterKnobState *fs;
 
 	// Filter Decay
 	float vcf_c0;           // c0=e1 on retrigger; c0*=ed every sample; cutoff=e0+c0
 	float vcf_e0,           // e0 and e1 for interpolation
-	      vcf_e1;           
+	      vcf_e1;
 	float vcf_rescoeff;     // Resonance coefficient [0.30,9.54]
 };
 
@@ -85,16 +89,16 @@ class lb302FilterIIR2 : public lb302Filter
 	virtual float process(const float& samp);
 
 	protected:
-	float vcf_d1,           //   d1 and d2 are added back into the sample with 
+	float vcf_d1,           //   d1 and d2 are added back into the sample with
 	      vcf_d2;           //   vcf_a and b as coefficients. IIR2 resonance
 	                        //   loop.
 
 	                        // IIR2 Coefficients for mixing dry and delay.
-	float vcf_a,            //   Mixing coefficients for the final sound.  
-	      vcf_b,            //  
+	float vcf_a,            //   Mixing coefficients for the final sound.
+	      vcf_b,            //
 	      vcf_c;
 
-	effectLib::distortion * m_dist;
+	DspEffectLibrary::Distortion * m_dist;
 };
 
 
@@ -109,15 +113,15 @@ class lb302Filter3Pole : public lb302Filter
 	virtual float process(const float& samp);
 
 	protected:
-	float kfcn, 
-	      kp, 
-	      kp1, 
-	      kp1h, 
+	float kfcn,
+	      kp,
+	      kp1,
+	      kp1h,
 	      kres;
-	float ay1, 
-	      ay2, 
-	      aout, 
-	      lastin, 
+	float ay1,
+	      ay2,
+	      aout,
+	      lastin,
 	      value;
 };
 
@@ -139,9 +143,9 @@ public:
 	virtual ~lb302Synth();
 
 	virtual void play( sampleFrame * _working_buffer );
-	virtual void playNote( notePlayHandle * _n,
+	virtual void playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer );
-	virtual void deleteNotePluginData( notePlayHandle * _n );
+	virtual void deleteNotePluginData( NotePlayHandle * _n );
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
@@ -149,6 +153,11 @@ public:
 
 	virtual QString nodeName() const;
 
+	virtual Flags flags() const
+	{
+		return IsSingleStreamed;
+	}
+
 	virtual f_cnt_t desiredReleaseFrames() const
 	{
 		return 0; //4048;
@@ -157,9 +166,10 @@ public:
 	virtual PluginView * instantiateView( QWidget * _parent );
 
 private:
+	void processNote( NotePlayHandle * n );
 
 	void initNote(lb302Note *note);
-
+	void initSlide();
 
 private:
 	FloatModel vcf_cut_knob;
@@ -172,7 +182,7 @@ private:
 	FloatModel dist_knob;
 	IntModel wave_shape;
 	FloatModel slide_dec_knob;
-    
+
 	BoolModel slideToggle;
 	BoolModel accentToggle;
 	BoolModel deadToggle;
@@ -193,24 +203,25 @@ private:
 	      vco_slideinc,     //* Slide base to use in next node. Nonzero=slide next note
 	      vco_slidebase;    //* The base vco_inc while sliding.
 
-	float vco_detune;
-
-	enum  vco_shape_t { SAWTOOTH, SQUARE, TRIANGLE, MOOG, ROUND_SQUARE, SINE, EXPONENTIAL, WHITE_NOISE };
+	enum  vco_shape_t { SAWTOOTH, SQUARE, TRIANGLE, MOOG, ROUND_SQUARE, SINE, EXPONENTIAL, WHITE_NOISE,
+							BL_SAWTOOTH, BL_SQUARE, BL_TRIANGLE, BL_MOOG };
 	vco_shape_t vco_shape;
 
+	// Filters (just keep both loaded and switch)
+	lb302Filter* vcfs[NUM_FILTERS];
+
 	// User settings
 	lb302FilterKnobState fs;
-	lb302Filter *vcf;
+	QAtomicPointer<lb302Filter> vcf;
 
 	int release_frame;
 
-
 	// More States
 	int   vcf_envpos;       // Update counter. Updates when >= ENVINC
 
-	float vca_attack,       // Amp attack 
+	float vca_attack,       // Amp attack
 	      vca_decay,        // Amp decay
-	      vca_a0,           // Initial amplifier coefficient 
+	      vca_a0,           // Initial amplifier coefficient
 	      vca_a;            // Amplifier coefficient.
 
 	// Envelope State
@@ -224,22 +235,24 @@ private:
 	int catch_frame;
 	int catch_decay;
 
-	float new_freq;
-	float current_freq;
-	float delete_freq;
+	bool new_freq;
 	float true_freq;
 
 	void recalcFilter();
 
-	int process(sampleFrame *outbuf, const Uint32 size);
+	int process(sampleFrame *outbuf, const int size);
 
 	friend class lb302SynthView;
 
+	NotePlayHandle * m_playingNote;
+	NotePlayHandleList m_notes;
+	QMutex m_notesMutex;
 } ;
 
 
 class lb302SynthView : public InstrumentView
 {
+	Q_OBJECT
 public:
 	lb302SynthView( Instrument * _instrument,
 	                QWidget * _parent );
@@ -247,20 +260,18 @@ public:
 
 private:
 	virtual void modelChanged();
-	
+
 	knob * m_vcfCutKnob;
 	knob * m_vcfResKnob;
 	knob * m_vcfDecKnob;
 	knob * m_vcfModKnob;
 
-	knob * m_vcoFineDetuneKnob;
-
 	knob * m_distKnob;
 	knob * m_slideDecKnob;
 	automatableButtonGroup * m_waveBtnGrp;
-    
+
 	ledCheckBox * m_slideToggle;
-	ledCheckBox * m_accentToggle;
+	/*ledCheckBox * m_accentToggle;*/ // removed pending accent implementation
 	ledCheckBox * m_deadToggle;
 	ledCheckBox * m_db24Toggle;
 
