@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2006-2008 Paul Giblock <pgib/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * lb303FilterIIR2 is based on the gsyn filter code by Andy Sloane.
  * 
@@ -37,10 +37,10 @@
 #include "InstrumentView.h"
 #include "led_checkbox.h"
 #include "knob.h"
-#include "mixer.h"
+#include "Mixer.h"
 
 class lb303SynthView;
-class notePlayHandle;
+class NotePlayHandle;
 
 class lb303FilterKnobState
 {
@@ -140,9 +140,9 @@ public:
 	virtual ~lb303Synth();
 
 	virtual void play( sampleFrame * _working_buffer );
-	virtual void playNote( notePlayHandle * _n,
+	virtual void playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer );
-	virtual void deleteNotePluginData( notePlayHandle * _n );
+	virtual void deleteNotePluginData( NotePlayHandle * _n );
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
@@ -241,6 +241,7 @@ private:
 
 class lb303SynthView : public InstrumentView
 {
+	Q_OBJECT
 public:
 	lb303SynthView( Instrument * _instrument,
 	                QWidget * _parent );
