@@ -4,7 +4,7 @@
  * Copyright (c) 2008 Attila Herman <attila589/at/gmail.com>
  *				Csaba Hruska <csaba.hruska/at/gmail.com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,18 +29,20 @@
 #include "Basic_Gb_Apu.h"
 
 #include "papu_instrument.h"
-#include "instrument_track.h"
+#include "base64.h"
+#include "InstrumentTrack.h"
 #include "knob.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "pixmap_button.h"
 #include "tooltip.h"
+#include "engine.h"
 #include "graph.h"
 
 #include "embed.cpp"
 
 extern "C"
 {
-plugin::descriptor PLUGIN_EXPORT papu_plugin_descriptor =
+Plugin::Descriptor PLUGIN_EXPORT papu_plugin_descriptor =
 {
 	STRINGIFY( PLUGIN_NAME ),
 	"FreeBoy",
@@ -49,16 +51,16 @@ plugin::descriptor PLUGIN_EXPORT papu_plugin_descriptor =
 	"Attila Herman <attila589/at/gmail.com>"
 	"Csaba Hruska <csaba.hruska/at/gmail.com>",
 	0x0100,
-	plugin::Instrument,
-	new pluginPixmapLoader( "logo" ),
+	Plugin::Instrument,
+	new PluginPixmapLoader( "logo" ),
 	NULL
 } ;
 
 }
 
 
-papuInstrument::papuInstrument( instrumentTrack * _instrument_track ) :
-	instrument( _instrument_track, &papu_plugin_descriptor ),
+papuInstrument::papuInstrument( InstrumentTrack * _instrument_track ) :
+	Instrument( _instrument_track, &papu_plugin_descriptor ),
 
 	m_ch1SweepTimeModel( 4.0f, 0.0f, 7.0f, 1.0f, this, tr( "Sweep time" ) ),
 	m_ch1SweepDirModel( false, this, tr( "Sweep direction" ) ),
@@ -203,7 +205,7 @@ void papuInstrument::loadSettings( const QDomElement & _this )
 	m_graphModel.setSamples( (float*) dst );
 }
 
-QString papuInstrument::nodeName( void ) const
+QString papuInstrument::nodeName() const
 {
 	return( papu_plugin_descriptor.name );
 }
@@ -211,9 +213,9 @@ QString papuInstrument::nodeName( void ) const
 
 
 
-/*f_cnt_t papuInstrument::desiredReleaseFrames( void ) const
+/*f_cnt_t papuInstrument::desiredReleaseFrames() const
 {
-	const float samplerate = engine::getMixer()->processingSampleRate();
+	const float samplerate = engine::mixer()->processingSampleRate();
 	int maxrel = 0;
 	for( int i = 0 ; i < 3 ; ++i )
 	{
@@ -224,18 +226,18 @@ QString papuInstrument::nodeName( void ) const
 	return f_cnt_t( float(relTime[maxrel])*samplerate/1000.0 );
 }*/
 
-f_cnt_t papuInstrument::desiredReleaseFrames( void ) const
+f_cnt_t papuInstrument::desiredReleaseFrames() const
 {
 	return f_cnt_t( 1000 );
 }
 
 
 
-void papuInstrument::playNote( notePlayHandle * _n,
+void papuInstrument::playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer )
 {
 	const f_cnt_t tfp = _n->totalFramesPlayed();
-	const int samplerate = engine::getMixer()->processingSampleRate();
+	const int samplerate = engine::mixer()->processingSampleRate();
 	const fpp_t frames = _n->framesLeftForCurrentPeriod();
 
 	int data = 0;
@@ -358,11 +360,11 @@ void papuInstrument::playNote( notePlayHandle * _n,
 		//PRNG Frequency = (1048576 Hz / (ratio + 1)) / 2 ^ (shiftclockfreq + 1)
 		char sopt=0;
 		char ropt=1;
-		float fopt = 524288.0 / ( ropt * pow( 2, sopt+1 ) );
+		float fopt = 524288.0 / ( ropt * pow( 2.0, sopt + 1.0 ) );
 		float f;
 		for ( char s=0; s<16; s++ )
 		for ( char r=0; r<8; r++ ) {
-			f = 524288.0 / ( r * pow( 2, s+1 ) );
+			f = 524288.0 / ( r * pow( 2.0, s + 1.0 ) );
 			if( fabs( freq-fopt ) > fabs( freq-f ) ) {
 				fopt = f;
 				ropt = r;
@@ -404,12 +406,12 @@ void papuInstrument::playNote( notePlayHandle * _n,
 		}
 		framesleft -= count;
 	}
-	getInstrumentTrack()->processAudioBuffer( _working_buffer, frames, _n );
+	instrumentTrack()->processAudioBuffer( _working_buffer, frames, _n );
 }
 
 
 
-void papuInstrument::deleteNotePluginData( notePlayHandle * _n )
+void papuInstrument::deleteNotePluginData( NotePlayHandle * _n )
 {
 	delete static_cast<Basic_Gb_Apu *>( _n->m_pluginData );
 }
@@ -417,7 +419,7 @@ void papuInstrument::deleteNotePluginData( notePlayHandle * _n )
 
 
 
-pluginView * papuInstrument::instantiateView( QWidget * _parent )
+PluginView * papuInstrument::instantiateView( QWidget * _parent )
 {
 	return( new papuInstrumentView( this, _parent ) );
 }
@@ -442,9 +444,9 @@ public:
 
 
 
-papuInstrumentView::papuInstrumentView( instrument * _instrument,
+papuInstrumentView::papuInstrumentView( Instrument * _instrument,
 							QWidget * _parent ) :
-	instrumentView( _instrument, _parent )
+	InstrumentView( _instrument, _parent )
 {
 
 	setAutoFillBackground( true );
@@ -689,7 +691,7 @@ papuInstrumentView::~papuInstrumentView()
 }
 
 
-void papuInstrumentView::modelChanged( void )
+void papuInstrumentView::modelChanged()
 {
 	papuInstrument * p = castModel<papuInstrument>();
 
@@ -732,11 +734,11 @@ void papuInstrumentView::modelChanged( void )
 extern "C"
 {
 
-// neccessary for getting instance out of shared lib
-plugin * PLUGIN_EXPORT lmms_plugin_main( model *, void * _data )
+// necessary for getting instance out of shared lib
+Plugin * PLUGIN_EXPORT lmms_plugin_main( Model *, void * _data )
 {
 	return( new papuInstrument(
-				static_cast<instrumentTrack *>( _data ) ) );
+				static_cast<InstrumentTrack *>( _data ) ) );
 }
 
 
