@@ -4,7 +4,7 @@
  * Copyright (c) 2008 <Attila Herman <attila589/at/gmail.com>
  *				Csaba Hruska <csaba.hruska/at/gmail.com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@
 #include "graph.h"
 
 class papuInstrumentView;
-class notePlayHandle;
+class NotePlayHandle;
 class pixmapButton;
 
 class papuInstrument : public Instrument
@@ -44,9 +44,9 @@ public:
 	papuInstrument( InstrumentTrack * _instrument_track );
 	virtual ~papuInstrument();
 
-	virtual void playNote( notePlayHandle * _n,
+	virtual void playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer );
-	virtual void deleteNotePluginData( notePlayHandle * _n );
+	virtual void deleteNotePluginData( NotePlayHandle * _n );
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
@@ -129,15 +129,12 @@ private:
 	pixmapButton * m_ch2VolSweepDirButton;
 	knob * m_ch2SweepStepLengthKnob;
 
-	pixmapButton * m_ch3OnButton;
 	knob * m_ch3VolumeKnob;
 
 	knob * m_ch4VolumeKnob;
 	pixmapButton * m_ch4VolSweepDirButton;
 	knob * m_ch4SweepStepLengthKnob;
-	knob * m_ch4ShiftClockFreqKnob;
 	pixmapButton * m_ch4ShiftRegWidthButton;
-	knob * m_ch4FreqDivRatioKnob;
 
 	knob * m_so1VolumeKnob;
 	knob * m_so2VolumeKnob;
