@@ -2,8 +2,9 @@
  * patman.cpp - a GUS-compatible patch instrument plugin
  *
  * Copyright (c) 2007-2008 Javier Serrano Polo <jasp00/at/users.sourceforge.net>
+ * Copyright (c) 2009-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,7 +25,6 @@
 
 #include "patman.h"
 
-#include <QtGui/QFileDialog>
 #include <QtGui/QDragEnterEvent>
 #include <QtGui/QPainter>
 #include <QtXml/QDomElement>
@@ -33,11 +33,12 @@
 #include "engine.h"
 #include "gui_templates.h"
 #include "InstrumentTrack.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "pixmap_button.h"
 #include "song.h"
 #include "string_pair_drag.h"
 #include "tooltip.h"
+#include "FileDialog.h"
 
 #include "embed.cpp"
 
@@ -128,7 +129,7 @@ QString patmanInstrument::nodeName( void ) const
 
 
 
-void patmanInstrument::playNote( notePlayHandle * _n,
+void patmanInstrument::playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer )
 {
 	if( m_patchFile == "" )
@@ -148,7 +149,7 @@ void patmanInstrument::playNote( notePlayHandle * _n,
 						hdata->sample->frequency();
 
 	if( hdata->sample->play( _working_buffer, hdata->state, frames,
-					play_freq, m_loopedModel.value() ) )
+					play_freq, m_loopedModel.value() ? SampleBuffer::LoopOn : SampleBuffer::LoopOff ) )
 	{
 		applyRelease( _working_buffer, _n );
 		instrumentTrack()->processAudioBuffer( _working_buffer,
@@ -159,7 +160,7 @@ void patmanInstrument::playNote( notePlayHandle * _n,
 
 
 
-void patmanInstrument::deleteNotePluginData( notePlayHandle * _n )
+void patmanInstrument::deleteNotePluginData( NotePlayHandle * _n )
 {
 	handle_data * hdata = (handle_data *)_n->m_pluginData;
 	sharedObject::unref( hdata->sample );
@@ -191,9 +192,8 @@ void patmanInstrument::setFile( const QString & _patch_file, bool _rename )
 	// else we don't touch the instrument-track-name, because the user
 	// named it self
 
-	m_patchFile = sampleBuffer::tryToMakeRelative( _patch_file );
-	LoadErrors error = loadPatch( sampleBuffer::tryToMakeAbsolute(
-								_patch_file ) );
+	m_patchFile = SampleBuffer::tryToMakeRelative( _patch_file );
+	LoadErrors error = loadPatch( SampleBuffer::tryToMakeAbsolute( _patch_file ) );
 	if( error )
 	{
 		printf("Load error\n");
@@ -303,7 +303,7 @@ patmanInstrument::LoadErrors patmanInstrument::loadPatch(
 				short sample;
 				if ( fread( &sample, 2, 1, fd ) != 1 )
 				{
-					delete wave_samples;
+					delete[] wave_samples;
 					fclose( fd );
 					return( LoadIO );
 				}
@@ -327,7 +327,7 @@ patmanInstrument::LoadErrors patmanInstrument::loadPatch(
 				char sample;
 				if ( fread( &sample, 1, 1, fd ) != 1 )
 				{
-					delete wave_samples;
+					delete[] wave_samples;
 					fclose( fd );
 					return( LoadIO );
 				}
@@ -350,7 +350,7 @@ patmanInstrument::LoadErrors patmanInstrument::loadPatch(
 			}
 		}
 
-		sampleBuffer * psample = new sampleBuffer( data, frames );
+		SampleBuffer* psample = new SampleBuffer( data, frames );
 		psample->setFrequency( root_freq / 1000.0f );
 		psample->setSampleRate( sample_rate );
 
@@ -384,15 +384,14 @@ void patmanInstrument::unloadCurrentPatch( void )
 
 
 
-void patmanInstrument::selectSample( notePlayHandle * _n )
+void patmanInstrument::selectSample( NotePlayHandle * _n )
 {
 	const float freq = _n->frequency();
 
 	float min_dist = HUGE_VALF;
-	sampleBuffer * sample = NULL;
+	SampleBuffer* sample = NULL;
 
-	for( QVector<sampleBuffer *>::iterator it = m_patchSamples.begin();
-					it != m_patchSamples.end(); ++it )
+	for( QVector<SampleBuffer *>::iterator it = m_patchSamples.begin(); it != m_patchSamples.end(); ++it )
 	{
 		float patch_freq = ( *it )->frequency();
 		float dist = freq >= patch_freq ? freq / patch_freq :
@@ -413,9 +412,9 @@ void patmanInstrument::selectSample( notePlayHandle * _n )
 	}
 	else
 	{
-		hdata->sample = new sampleBuffer( NULL, 0 );
+		hdata->sample = new SampleBuffer( NULL, 0 );
 	}
-	hdata->state = new sampleBuffer::handleState( _n->hasDetuningInfo() );
+	hdata->state = new SampleBuffer::handleState( _n->hasDetuningInfo() );
 
 	_n->m_pluginData = hdata;
 }
@@ -509,8 +508,8 @@ PatmanView::~PatmanView()
 
 void PatmanView::openFile( void )
 {
-	QFileDialog ofd( NULL, tr( "Open patch file" ) );
-	ofd.setFileMode( QFileDialog::ExistingFiles );
+	FileDialog ofd( NULL, tr( "Open patch file" ) );
+	ofd.setFileMode( FileDialog::ExistingFiles );
 
 	QStringList types;
 	types << tr( "Patch-Files (*.pat)" );
@@ -562,7 +561,7 @@ void PatmanView::openFile( void )
 void PatmanView::updateFilename( void )
 {
  	m_displayFilename = "";
-	Uint16 idx = m_pi->m_patchFile.length();
+	int idx = m_pi->m_patchFile.length();
 
 	QFontMetrics fm( pointSize<8>( font() ) );
 
