@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2007-2008 Javier Serrano Polo <jasp00/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@
 
 #include "Instrument.h"
 #include "InstrumentView.h"
-#include "sample_buffer.h"
+#include "SampleBuffer.h"
 #include "AutomatableModel.h"
 
 
@@ -52,9 +52,9 @@ public:
 	patmanInstrument( InstrumentTrack * _track );
 	virtual ~patmanInstrument();
 
-	virtual void playNote( notePlayHandle * _n,
+	virtual void playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer );
-	virtual void deleteNotePluginData( notePlayHandle * _n );
+	virtual void deleteNotePluginData( NotePlayHandle * _n );
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
@@ -79,13 +79,13 @@ public slots:
 private:
 	typedef struct
 	{
-		sampleBuffer::handleState * state;
+		SampleBuffer::handleState* state;
 		bool tuned;
-		sampleBuffer * sample;
+		SampleBuffer* sample;
 	} handle_data;
 
 	QString m_patchFile;
-	QVector<sampleBuffer *> m_patchSamples;
+	QVector<SampleBuffer *> m_patchSamples;
 	BoolModel m_loopedModel;
 	BoolModel m_tunedModel;
 
@@ -103,7 +103,7 @@ private:
 	LoadErrors loadPatch( const QString & _filename );
 	void unloadCurrentPatch( void );
 
-	void selectSample( notePlayHandle * _n );
+	void selectSample( NotePlayHandle * _n );
 
 
 	friend class PatmanView;
