@@ -2,8 +2,9 @@
  * peak_controller_effect.cpp - PeakController effect plugin
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail/dot/com>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * Copyright (c) 2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -30,7 +31,6 @@
 
 #include "embed.cpp"
 
-
 extern "C"
 {
 
@@ -39,7 +39,7 @@ Plugin::Descriptor PLUGIN_EXPORT peakcontrollereffect_plugin_descriptor =
 	STRINGIFY( PLUGIN_NAME ),
 	"Peak Controller",
 	QT_TRANSLATE_NOOP( "pluginBrowser",
-				"Plugin for controlling knobs with sound peaks" ),
+			"Plugin for controlling knobs with sound peaks" ),
 	"Paul Giblock <drfaygo/at/gmail.com>",
 	0x0100,
 	Plugin::Effect,
@@ -60,7 +60,11 @@ PeakControllerEffect::PeakControllerEffect(
 			Model * _parent,
 			const Descriptor::SubPluginFeatures::Key * _key ) :
 	Effect( &peakcontrollereffect_plugin_descriptor, _parent, _key ),
+	m_effectId( rand() ),
 	m_peakControls( this ),
+	m_lastSample( 0 ),
+	m_lastRMS( -1 ),
+	m_lastRMSavail(false),
 	m_autoController( NULL )
 {
 	m_autoController = new PeakController( engine::getSong(), this );
@@ -77,31 +81,59 @@ PeakControllerEffect::~PeakControllerEffect()
 	if( idx >= 0 )
 	{
 		PeakController::s_effects.remove( idx );
+		engine::getSong()->removeController( m_autoController );
 	}
 }
 
+namespace helpers
+{
 
+	//! returns 1.0f if val > 0.0f, -1.0 else
+	inline float sign(float val) { return -1.0f + 2.0f * (val > 0.0f); }
+
+	//! if val >= 0.0f, returns sqrtf(val), else: -sqrtf(-val)
+	inline float sqrt_neg(float val) {
+		return sqrtf(fabs(val)) * helpers::sign(val);
+	}
+
+}
 
 bool PeakControllerEffect::processAudioBuffer( sampleFrame * _buf,
 							const fpp_t _frames )
 {
 	PeakControllerEffectControls & c = m_peakControls;
-	
+
 	// This appears to be used for determining whether or not to continue processing
 	// audio with this effect	
 	if( !isEnabled() || !isRunning() )
 	{
-		return( FALSE );
+		return false;
 	}
 
-
 	// RMS:
 	double sum = 0;
-	for( int i = 0; i < _frames; ++i )
+
+	if(c.m_absModel.value())
 	{
-		sum += _buf[i][0]*_buf[i][0] + _buf[i][1]*_buf[i][1];
+		for( int i = 0; i < _frames; ++i )
+		{
+			// absolute value is achieved because the squares are > 0
+			sum += _buf[i][0]*_buf[i][0] + _buf[i][1]*_buf[i][1];
+		}
+	}
+	else
+	{
+		for( int i = 0; i < _frames; ++i )
+		{
+			// the value is absolute because of squaring,
+			// so we need to correct it
+			sum +=	_buf[i][0]*_buf[i][0]*helpers::sign(_buf[i][0])
+			 + _buf[i][1]*_buf[i][1]*helpers::sign(_buf[i][1]);
+		}
 	}
 
+	// TODO: flipping this might cause clipping
+	// this will mute the output after the values were measured
 	if( c.m_muteModel.value() )
 	{
 		for( int i = 0; i < _frames; ++i )
@@ -110,12 +142,36 @@ bool PeakControllerEffect::processAudioBuffer( sampleFrame * _buf,
 		}
 	}
 
-	m_lastSample = c.m_baseModel.value() + c.m_amountModel.value() *
-							sqrtf( sum / _frames );
+	float curRMS = helpers::sqrt_neg( sum / _frames );
+	const float origRMS = curRMS;
+
+	if( !m_lastRMSavail )
+	{
+		m_lastRMSavail = true;
+		m_lastRMS = curRMS;
+	}
+	const float v = ( curRMS >= m_lastRMS ) ?
+				c.m_attackModel.value() :
+					c.m_decayModel.value();
+	const float a = helpers::sqrt_neg( helpers::sqrt_neg( v ) );
+	curRMS = (1-a)*curRMS + a*m_lastRMS;
+
+	const float amount = c.m_amountModel.value() * c.m_amountMultModel.value();
+	m_lastSample = c.m_baseModel.value() + amount*curRMS;
+	m_lastRMS = curRMS;
+
+	// on greater buffer sizes our LP is updated less frequently, therfore
+	// replay a certain number of passes so the LP state is as if it was
+	// updated N times with buffer-size 1/N
+	const int timeOversamp = (4*_frames) / DEFAULT_BUFFER_SIZE-1;
+	for( int i = 0; i < timeOversamp; ++i )
+	{
+		m_lastRMS = (1-a)*origRMS + a*m_lastRMS;
+	}
 
 	//checkGate( out_sum / _frames );
 
-	return( isRunning() );
+	return isRunning();
 }
 
 
@@ -128,8 +184,7 @@ extern "C"
 Plugin * PLUGIN_EXPORT lmms_plugin_main( Model * _parent, void * _data )
 {
 	return new PeakControllerEffect( _parent,
-		static_cast<const Plugin::Descriptor::SubPluginFeatures::Key *>(
-								_data ) );
+		static_cast<const Plugin::Descriptor::SubPluginFeatures::Key *>( _data ) );
 }
 
 }
