@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail/dot/com>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -44,45 +44,59 @@ PeakControllerEffectControlDialog::PeakControllerEffectControlDialog(
 	pal.setBrush( backgroundRole(),
 				PLUGIN_NAME::getIconPixmap( "artwork" ) );
 	setPalette( pal );
-	setFixedSize( 144, 110 );
 
 	QVBoxLayout * tl = new QVBoxLayout( this );
-	tl->addSpacing( 25 );
+	tl->setContentsMargins( 5, 30, 8, 8 );
 
 	QHBoxLayout * l = new QHBoxLayout;
-
+	l->setSpacing( 4 );
 	m_baseKnob = new knob( knobBright_26, this );
 	m_baseKnob->setLabel( tr( "BASE" ) );
 	m_baseKnob->setModel( &_controls->m_baseModel );
 	m_baseKnob->setHintText( tr( "Base amount:" ) + " ", "" );
 
 	m_amountKnob = new knob( knobBright_26, this );
-	m_amountKnob->setLabel( tr( "AMT" ) );
+	m_amountKnob->setLabel( tr( "AMNT" ) );
 	m_amountKnob->setModel( &_controls->m_amountModel );
 	m_amountKnob->setHintText( tr( "Modulation amount:" ) + " ", "" );
 
+	m_amountMultKnob = new knob( knobBright_26, this );
+	m_amountMultKnob->setLabel( tr( "MULT" ) );
+	m_amountMultKnob->setModel( &_controls->m_amountMultModel );
+	m_amountMultKnob->setHintText( tr( "Amount Multiplicator:" ) + " ", "" );
+
 	m_attackKnob = new knob( knobBright_26, this );
-	m_attackKnob->setLabel( tr( "ATTACK" ) );
+	m_attackKnob->setLabel( tr( "ATCK" ) );
 	m_attackKnob->setModel( &_controls->m_attackModel );
 	m_attackKnob->setHintText( tr( "Attack:" ) + " ", "" );
 
 	m_decayKnob = new knob( knobBright_26, this );
-	m_decayKnob->setLabel( tr( "DECAY" ) );
+	m_decayKnob->setLabel( tr( "DCAY" ) );
 	m_decayKnob->setModel( &_controls->m_decayModel );
 	m_decayKnob->setHintText( tr( "Release:" ) + " ", "" );
 
 	l->addWidget( m_baseKnob );
 	l->addWidget( m_amountKnob );
+	l->addWidget( m_amountMultKnob );
 	l->addWidget( m_attackKnob );
 	l->addWidget( m_decayKnob );
+	l->addStretch(); // expand, so other widgets have minimum width
 	tl->addLayout( l );
 
-	m_muteLed = new ledCheckBox( "Mute", this );
+	QVBoxLayout * l2 = new QVBoxLayout; // = 2nd vbox
+
+	m_muteLed = new ledCheckBox( "Mute Effect", this );
 	m_muteLed->setModel( &_controls->m_muteModel );
 
-	tl->addSpacing( 5 );
-	tl->addWidget( m_muteLed );
+	m_absLed = new ledCheckBox( "Absolute Value", this );
+	m_absLed->setModel( &_controls->m_absModel );
+
+	l2->addWidget( m_muteLed );
+	l2->addWidget( m_absLed );
+	l2->addStretch(); // expand, so other widgets have minimum height
+	tl->addLayout( l2 );
 
 	setLayout( tl );
 }
 
+#include "moc_peak_controller_effect_control_dialog.cxx"
