@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@
 
 stereoEnhancerControlDialog::stereoEnhancerControlDialog(
 	stereoEnhancerControls * _controls ) :
-	effectControlDialog( _controls )
+	EffectControlDialog( _controls )
 {
 	QHBoxLayout * l = new QHBoxLayout( this );
 
@@ -47,3 +47,4 @@ stereoEnhancerControlDialog::stereoEnhancerControlDialog(
 	this->setLayout(l);
 }
 
+#include "moc_stereoenhancer_control_dialog.cxx"
