@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,13 +25,14 @@
 #ifndef _STEREOENHANCER_CONTROL_DIALOG_H
 #define _STEREOENHANCER_CONTROL_DIALOG_H
 
-#include "effect_control_dialog.h"
+#include "EffectControlDialog.h"
 
 class stereoEnhancerControls;
 
 
-class stereoEnhancerControlDialog : public effectControlDialog
+class stereoEnhancerControlDialog : public EffectControlDialog
 {
+	Q_OBJECT
 public:
 	stereoEnhancerControlDialog( stereoEnhancerControls * _controls );
 	virtual ~stereoEnhancerControlDialog()
