@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -51,7 +51,7 @@ void stereoEnhancerControls::changeWideCoeff()
 
 void stereoEnhancerControls::loadSettings( const QDomElement & _this )
 {
-	m_widthModel.setValue( _this.attribute( "width" ).toFloat() );
+	m_widthModel.loadSettings( _this, "width" );
 }
 
 
@@ -60,7 +60,7 @@ void stereoEnhancerControls::loadSettings( const QDomElement & _this )
 void stereoEnhancerControls::saveSettings( QDomDocument & _doc, 
 							QDomElement & _this )
 {
-	_this.setAttribute( "width", m_widthModel.value() );
+	m_widthModel.saveSettings( _doc, _this, "width" );
 }
 
 
