@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail/dot/com>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -32,6 +32,7 @@ class stereoMatrixControls;
 
 class stereoMatrixControlDialog : public EffectControlDialog
 {
+	Q_OBJECT
 public:
 	stereoMatrixControlDialog( stereoMatrixControls * _controls );
 	virtual ~stereoMatrixControlDialog()
