@@ -1,9 +1,9 @@
 /*
  * TripleOscillator.cpp - powerful instrument with three oscillators
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,10 +33,9 @@
 #include "engine.h"
 #include "InstrumentTrack.h"
 #include "knob.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "pixmap_button.h"
-#include "sample_buffer.h"
-#include "song_editor.h"
+#include "SampleBuffer.h"
 #include "tooltip.h"
 
 #include "embed.cpp"
@@ -50,7 +49,7 @@ Plugin::Descriptor PLUGIN_EXPORT tripleoscillator_plugin_descriptor =
 	STRINGIFY( PLUGIN_NAME ),
 	"TripleOscillator",
 	QT_TRANSLATE_NOOP( "pluginBrowser",
-				"three powerful oscillators you can modulate "
+				"Three powerful oscillators you can modulate "
 				"in several ways" ),
 	"Tobias Doerffel <tobydox/at/users.sf.net>",
 	0x0110,
@@ -88,7 +87,7 @@ OscillatorObject::OscillatorObject( Model * _parent, int _idx ) :
 				Oscillator::NumModulationAlgos-1, this,
 				tr( "Modulation type %1" ).arg( _idx+1 ) ),
 
-	m_sampleBuffer( new sampleBuffer ),
+	m_sampleBuffer( new SampleBuffer ),
 	m_volumeLeft( 0.0f ),
 	m_volumeRight( 0.0f ),
 	m_detuningLeft( 0.0f ),
@@ -138,10 +137,9 @@ OscillatorObject::~OscillatorObject()
 
 void OscillatorObject::oscUserDefWaveDblClick()
 {
-	QString af = m_sampleBuffer->openAudioFile();
+	QString af = m_sampleBuffer->openAndSetWaveformFile();
 	if( af != "" )
 	{
-		m_sampleBuffer->setAudioFile( af );
 		// TODO:
 		//toolTip::add( m_usrWaveBtn, m_sampleBuffer->audioFile() );
 	}
@@ -177,7 +175,7 @@ void OscillatorObject::updateDetuningLeft()
 {
 	m_detuningLeft = powf( 2.0f, ( (float)m_coarseModel.value() * 100.0f
 				+ (float)m_fineLeftModel.value() ) / 1200.0f )
-				/ engine::getMixer()->processingSampleRate();
+				/ engine::mixer()->processingSampleRate();
 }
 
 
@@ -187,7 +185,7 @@ void OscillatorObject::updateDetuningRight()
 {
 	m_detuningRight = powf( 2.0f, ( (float)m_coarseModel.value() * 100.0f
 				+ (float)m_fineRightModel.value() ) / 1200.0f )
-				/ engine::getMixer()->processingSampleRate();
+				/ engine::mixer()->processingSampleRate();
 }
 
 
@@ -219,7 +217,7 @@ TripleOscillator::TripleOscillator( InstrumentTrack * _instrument_track ) :
 
 	}
 
-	connect( engine::getMixer(), SIGNAL( sampleRateChanged() ),
+	connect( engine::mixer(), SIGNAL( sampleRateChanged() ),
 			this, SLOT( updateAllDetuning() ) );
 }
 
@@ -296,7 +294,7 @@ QString TripleOscillator::nodeName() const
 
 
 
-void TripleOscillator::playNote( notePlayHandle * _n,
+void TripleOscillator::playNote( NotePlayHandle * _n,
 						sampleFrame * _working_buffer )
 {
 	if( _n->totalFramesPlayed() == 0 || _n->m_pluginData == NULL )
@@ -304,7 +302,7 @@ void TripleOscillator::playNote( notePlayHandle * _n,
 		Oscillator * oscs_l[NUM_OF_OSCILLATORS];
 		Oscillator * oscs_r[NUM_OF_OSCILLATORS];
 
-		for( Sint8 i = NUM_OF_OSCILLATORS - 1; i >= 0; --i )
+		for( int i = NUM_OF_OSCILLATORS - 1; i >= 0; --i )
 		{
 
 			// the last oscs needs no sub-oscs...
@@ -372,7 +370,7 @@ void TripleOscillator::playNote( notePlayHandle * _n,
 
 
 
-void TripleOscillator::deleteNotePluginData( notePlayHandle * _n )
+void TripleOscillator::deleteNotePluginData( NotePlayHandle * _n )
 {
 	delete static_cast<Oscillator *>( static_cast<oscPtr *>(
 						_n->m_pluginData )->oscLeft );
