@@ -1,9 +1,9 @@
 /*
  * vestige.cpp - instrument-plugin for hosting VST-instruments
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,7 +25,6 @@
 #include "vestige.h"
 
 #include <QtGui/QDropEvent>
-#include <QtGui/QFileDialog>
 #include <QtGui/QMessageBox>
 #include <QtGui/QPainter>
 #include <QtGui/QPushButton>
@@ -43,6 +42,7 @@
 #include "string_pair_drag.h"
 #include "text_float.h"
 #include "tooltip.h"
+#include "FileDialog.h"
 
 #include "embed.cpp"
 
@@ -83,7 +83,7 @@ vestigeInstrument::vestigeInstrument( InstrumentTrack * _instrument_track ) :
 {
 	// now we need a play-handle which cares for calling play()
 	InstrumentPlayHandle * iph = new InstrumentPlayHandle( this );
-	engine::getMixer()->addPlayHandle( iph );
+	engine::mixer()->addPlayHandle( iph );
 }
 
 
@@ -101,7 +101,7 @@ vestigeInstrument::~vestigeInstrument()
 		knobFModel = NULL;
 	}
 
-	engine::getMixer()->removePlayHandles( instrumentTrack() );
+	engine::mixer()->removePlayHandles( instrumentTrack() );
 	closePlugin();
 }
 
@@ -117,22 +117,30 @@ void vestigeInstrument::loadSettings( const QDomElement & _this )
 		m_plugin->loadSettings( _this );
 
 		const QMap<QString, QString> & dump = m_plugin->parameterDump();
-		int paramCount = (dump).size();
+		paramCount = dump.size();
 		char paramStr[35];
-		vstKnobs = new knob *[paramCount];
-		knobFModel = new FloatModel *[paramCount];
-		QStringList list1;
+		vstKnobs = new knob *[ paramCount ];
+		knobFModel = new FloatModel *[ paramCount ];
+		QStringList s_dumpValues;
 		QWidget * widget = new QWidget();
-		for (int i = 0; i < paramCount; i++) {
-			sprintf( paramStr, "param%d", i);
-			list1 = dump[paramStr].split(":");
+		for( int i = 0; i < paramCount; i++ )
+		{
+			sprintf( paramStr, "param%d", i );
+			s_dumpValues = dump[ paramStr ].split( ":" );
 
-			vstKnobs[i] = new knob( knobBright_26, widget );
-			vstKnobs[i]->setHintText( list1.at(1) + ":", "");
-			vstKnobs[i]->setLabel( list1.at(1).left(15) );
+			vstKnobs[i] = new knob( knobBright_26, widget, s_dumpValues.at( 1 ) );
+			vstKnobs[i]->setHintText( s_dumpValues.at( 1 ) + ":", "" );
+			vstKnobs[i]->setLabel( s_dumpValues.at( 1 ).left( 15 ) );
 
-			knobFModel[i] = new FloatModel( (list1.at(2)).toFloat(), 0.0f, 1.0f, 0.01f, this, QString::number(i) );
+			knobFModel[i] = new FloatModel( 0.0f, 0.0f, 1.0f, 0.01f, this, QString::number(i) );
 			knobFModel[i]->loadSettings( _this, paramStr );
+
+			if( !( knobFModel[ i ]->isAutomated() || knobFModel[ i ]->controllerConnection() ) )
+			{
+				knobFModel[ i ]->setValue( ( s_dumpValues.at( 2 )).toFloat() );
+				knobFModel[ i ]->setInitValue( ( s_dumpValues.at( 2 )).toFloat() );
+			}
+
 			connect( knobFModel[i], SIGNAL( dataChanged() ), this, SLOT( setParameter() ) );
 
 			vstKnobs[i]->setModel( knobFModel[i] );
@@ -160,6 +168,17 @@ void vestigeInstrument::setParameter( void )
 
 void vestigeInstrument::saveSettings( QDomDocument & _doc, QDomElement & _this )
 {
+	if( QFileInfo( m_pluginDLL ).isAbsolute() )
+	{
+		QString f = QString( m_pluginDLL ).replace( QDir::separator(), '/' );
+		QString vd = QString( configManager::inst()->vstDir() ).replace( QDir::separator(), '/' );
+        	QString relativePath;
+		if( !( relativePath = f.section( vd, 1, 1 ) ).isEmpty() )
+		{
+			m_pluginDLL = relativePath;
+		}
+	}
+
 	_this.setAttribute( "plugin", m_pluginDLL );
 	m_pluginMutex.lock();
 	if( m_plugin != NULL )
@@ -167,10 +186,11 @@ void vestigeInstrument::saveSettings( QDomDocument & _doc, QDomElement & _this )
 		m_plugin->saveSettings( _doc, _this );
 		if (knobFModel != NULL) {
 			const QMap<QString, QString> & dump = m_plugin->parameterDump();
-			int paramCount = (dump).size();
+			paramCount = dump.size();
 			char paramStr[35];
-			for (int i = 0; i < paramCount; i++) {
-				if (knobFModel[i]->isAutomated() || knobFModel[i]->getControllerConnection()) {
+			for( int i = 0; i < paramCount; i++ )
+			{
+				if (knobFModel[i]->isAutomated() || knobFModel[i]->controllerConnection()) {
 					sprintf( paramStr, "param%d", i);
 					knobFModel[i]->saveSettings( _doc, _this, paramStr );
 				}
@@ -180,7 +200,7 @@ void vestigeInstrument::saveSettings( QDomDocument & _doc, QDomElement & _this )
 				me.setAttribute( "value", knobFModel[i]->value() );
 				_this.appendChild( me );
 
-				ControllerConnection * m_controllerConnection = knobFModel[i]->getControllerConnection();
+				ControllerConnection * m_controllerConnection = knobFModel[i]->controllerConnection();
 				if (m_controllerConnection) {
 					QDomElement controller_element;
 					QDomNode node = _this.namedItem( "connection" );
@@ -218,12 +238,16 @@ void vestigeInstrument::loadFile( const QString & _file )
 {
 	m_pluginMutex.lock();
 	const bool set_ch_name = ( m_plugin != NULL &&
-		instrumentTrack()->name() == m_plugin->name() ) ||
-			instrumentTrack()->name() ==
-				InstrumentTrack::tr( "Default preset" );
+        	instrumentTrack()->name() == m_plugin->name() ) ||
+            	instrumentTrack()->name() == InstrumentTrack::tr( "Default preset" ) ||
+            	instrumentTrack()->name() == displayName();
+
 	m_pluginMutex.unlock();
 
-	closePlugin();
+	if ( m_plugin != NULL )
+	{
+		closePlugin();
+	}
 
 	m_pluginDLL = _file;
 	textFloat * tf = textFloat::displayMessage(
@@ -250,7 +274,7 @@ void vestigeInstrument::loadFile( const QString & _file )
 		return;
 	}
 
-	m_plugin->showEditor();
+	m_plugin->showEditor( NULL, false );
 
 	if( set_ch_name )
 	{
@@ -278,7 +302,7 @@ void vestigeInstrument::play( sampleFrame * _buf )
 
 	m_plugin->process( NULL, _buf );
 
-	const fpp_t frames = engine::getMixer()->framesPerPeriod();
+	const fpp_t frames = engine::mixer()->framesPerPeriod();
 
 	instrumentTrack()->processAudioBuffer( _buf, frames, NULL );
 
@@ -288,18 +312,15 @@ void vestigeInstrument::play( sampleFrame * _buf )
 
 
 
-bool vestigeInstrument::handleMidiEvent( const midiEvent & _me,
-						const midiTime & _time )
+bool vestigeInstrument::handleMidiEvent( const MidiEvent& event, const MidiTime& time, f_cnt_t offset )
 {
-	if( !isMuted() )
+	m_pluginMutex.lock();
+	if( m_plugin != NULL )
 	{
-		m_pluginMutex.lock();
-		if( m_plugin != NULL )
-		{
-			m_plugin->processMidiEvent( _me, _time );
-		}
-		m_pluginMutex.unlock();
+		m_plugin->processMidiEvent( event, offset );
 	}
+	m_pluginMutex.unlock();
+
 	return true;
 }
 
@@ -308,6 +329,51 @@ bool vestigeInstrument::handleMidiEvent( const midiEvent & _me,
 
 void vestigeInstrument::closePlugin( void )
 {
+	// disconnect all signals
+	if( knobFModel != NULL )
+	{
+		for( int i = 0; i < paramCount; i++ )
+		{
+			delete knobFModel[ i ];
+			delete vstKnobs[ i ];
+		}
+	}
+
+	if( vstKnobs != NULL )
+	{
+		delete [] vstKnobs;
+		vstKnobs = NULL;
+	}
+
+	if( knobFModel != NULL )
+	{
+		delete [] knobFModel;
+		knobFModel = NULL;
+	}
+
+	if( m_scrollArea != NULL )
+	{
+//		delete m_scrollArea;
+		m_scrollArea = NULL;
+	}
+
+	if( m_subWindow != NULL )
+	{
+		m_subWindow->setAttribute( Qt::WA_DeleteOnClose );
+		m_subWindow->close();
+
+		if( m_subWindow != NULL )
+		{
+			delete m_subWindow;
+		}
+		m_subWindow = NULL;
+	}
+
+	if( p_subWindow != NULL )
+	{
+		p_subWindow = NULL;
+	}
+
 	m_pluginMutex.lock();
 	if( m_plugin )
 	{
@@ -343,9 +409,9 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_openPluginButton = new pixmapButton( this, "" );
 	m_openPluginButton->setCheckable( false );
 	m_openPluginButton->setCursor( Qt::PointingHandCursor );
-	m_openPluginButton->move( 218, 79 );
+	m_openPluginButton->move( 216, 81 );
 	m_openPluginButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"select_file" ) );
+							"select_file_active" ) );
 	m_openPluginButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"select_file" ) );
 	connect( m_openPluginButton, SIGNAL( clicked() ), this,
@@ -360,11 +426,11 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_managePluginButton = new pixmapButton( this, "" );
 	m_managePluginButton->setCheckable( false );
 	m_managePluginButton->setCursor( Qt::PointingHandCursor );
-	m_managePluginButton->move( 220, 102 );
+	m_managePluginButton->move( 216, 101 );
 	m_managePluginButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"track_op_menu", 20, 20 ) );
+							"track_op_menu_active" ) );
 	m_managePluginButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"track_op_menu", 20, 20 ) );
+							"track_op_menu" ) );
 	connect( m_managePluginButton, SIGNAL( clicked() ), this,
 						SLOT( managePlugin() ) );
 	toolTip::add( m_managePluginButton, tr( "Control VST-plugin from LMMS host" ) );
@@ -376,11 +442,11 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_openPresetButton = new pixmapButton( this, "" );
 	m_openPresetButton->setCheckable( false );
 	m_openPresetButton->setCursor( Qt::PointingHandCursor );
-	m_openPresetButton->move( 224, 192 );
+	m_openPresetButton->move( 200, 224 );
 	m_openPresetButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"stepper-up-press" ) );
+							"project_open", 20, 20 ) );
 	m_openPresetButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"stepper-up" ) );
+							"project_open", 20, 20 ) );
 	connect( m_openPresetButton, SIGNAL( clicked() ), this,
 						SLOT( openPreset() ) );
 	toolTip::add( m_openPresetButton, tr( "Open VST-plugin preset" ) );
@@ -392,7 +458,7 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_rolLPresetButton = new pixmapButton( this, "" );
 	m_rolLPresetButton->setCheckable( false );
 	m_rolLPresetButton->setCursor( Qt::PointingHandCursor );
-	m_rolLPresetButton->move( 167, 192 );
+	m_rolLPresetButton->move( 190, 201 );
 	m_rolLPresetButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"stepper-left-press" ) );
 	m_rolLPresetButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -410,11 +476,11 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_savePresetButton = new pixmapButton( this, "" );
 	m_savePresetButton->setCheckable( false );
 	m_savePresetButton->setCursor( Qt::PointingHandCursor );
-	m_savePresetButton->move( 224, 213 );
+	m_savePresetButton->move( 224, 224 );
 	m_savePresetButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"project_save", 16, 16  ) );
+							"project_save", 20, 20  ) );
 	m_savePresetButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
-							"project_save", 16, 16  ) );
+							"project_save", 20, 20  ) );
 	connect( m_savePresetButton, SIGNAL( clicked() ), this,
 						SLOT( savePreset() ) );
 	toolTip::add( m_savePresetButton, tr( "Save preset" ) );
@@ -426,7 +492,7 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 	m_rolRPresetButton = new pixmapButton( this, "" );
 	m_rolRPresetButton->setCheckable( false );
 	m_rolRPresetButton->setCursor( Qt::PointingHandCursor );
-	m_rolRPresetButton->move( 186, 192 );
+	m_rolRPresetButton->move( 209, 201 );
 	m_rolRPresetButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"stepper-right-press" ) );
 	m_rolRPresetButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -443,7 +509,7 @@ VestigeInstrumentView::VestigeInstrumentView( Instrument * _instrument,
 
 
 	m_selPresetButton = new QPushButton( tr( "" ), this );
-	m_selPresetButton->setGeometry( 205, 192, 16, 16 );
+	m_selPresetButton->setGeometry( 228, 201, 16, 16 );
 
 	QMenu *menu = new QMenu;
 
@@ -486,7 +552,7 @@ void VestigeInstrumentView::managePlugin( void )
 	if ( m_vi->m_plugin != NULL && m_vi->m_subWindow == NULL ) {
 		m_vi->p_subWindow = new manageVestigeInstrumentView( _instrument2, _parent2, m_vi);
 	} else if (m_vi->m_subWindow != NULL) {
-		if (m_vi->m_subWindow->widget()->isVisible() == FALSE) { 
+		if (m_vi->m_subWindow->widget()->isVisible() == FALSE) {
 			m_vi->m_scrollArea->show();
 			m_vi->m_subWindow->show();
 		} else {
@@ -548,7 +614,7 @@ void VestigeInstrumentView::modelChanged()
 
 void VestigeInstrumentView::openPlugin()
 {
-	QFileDialog ofd( NULL, tr( "Open VST-plugin" ) );
+	FileDialog ofd( NULL, tr( "Open VST-plugin" ) );
 
 	QString dir;
 	if( m_vi->m_pluginDLL != "" )
@@ -561,7 +627,7 @@ void VestigeInstrumentView::openPlugin()
 	}
 	// change dir to position of previously opened file
 	ofd.setDirectory( dir );
-	ofd.setFileMode( QFileDialog::ExistingFiles );
+	ofd.setFileMode( FileDialog::ExistingFiles );
 
 	// set filters
 	QStringList types;
@@ -581,15 +647,15 @@ void VestigeInstrumentView::openPlugin()
 		{
 			return;
 		}
-		engine::getMixer()->lock();
-		
+		engine::mixer()->lock();
+
 		if (m_vi->p_subWindow != NULL) {
 			delete m_vi->p_subWindow;
 			m_vi->p_subWindow = NULL;
 		}
 
 		m_vi->loadFile( ofd.selectedFiles()[0] );
-		engine::getMixer()->unlock();
+		engine::mixer()->unlock();
 		if( m_vi->m_plugin && m_vi->m_plugin->pluginWidget() )
 		{
 			m_vi->m_plugin->pluginWidget()->setWindowIcon(
@@ -685,8 +751,7 @@ void VestigeInstrumentView::selPreset( void )
 
 void VestigeInstrumentView::toggleGUI( void )
 {
-	QMutexLocker ml( &m_vi->m_pluginMutex );
-	if( m_vi->m_plugin == NULL )
+	if( m_vi == NULL || m_vi->m_plugin == NULL )
 	{
 		return;
 	}
@@ -713,10 +778,9 @@ void VestigeInstrumentView::noteOffAll( void )
 	m_vi->m_pluginMutex.lock();
 	if( m_vi->m_plugin != NULL )
 	{
-		for( int key = 0; key <= MidiMaxNote; ++key )
+		for( int key = 0; key <= MidiMaxKey; ++key )
 		{
-			m_vi->m_plugin->processMidiEvent(
-				midiEvent( MidiNoteOff, 0, key, 0 ), 0 );
+			m_vi->m_plugin->processMidiEvent( MidiEvent( MidiNoteOff, 0, key, 0 ), 0 );
 		}
 	}
 	m_vi->m_pluginMutex.unlock();
@@ -771,7 +835,7 @@ void VestigeInstrumentView::paintEvent( QPaintEvent * )
 
 	p.drawPixmap( 0, 0, *s_artwork );
 
-	QString plugin_name = ( m_vi->m_plugin != NULL ) ? 
+	QString plugin_name = ( m_vi->m_plugin != NULL ) ?
 				m_vi->m_plugin->name()/* + QString::number(
 						m_plugin->version() )*/
 					:
@@ -779,21 +843,29 @@ void VestigeInstrumentView::paintEvent( QPaintEvent * )
 	QFont f = p.font();
 	f.setBold( true );
 	p.setFont( pointSize<10>( f ) );
-	p.setPen( QColor( 32, 160, 54 ) );
-
+	p.setPen( QColor( 255, 255, 255 ) );
 	p.drawText( 10, 100, plugin_name );
+
+	p.setPen( QColor( 50, 50, 50 ) );
 	p.drawText( 10, 211, tr( "Preset" ) );
 
 //	m_pluginMutex.lock();
 	if( m_vi->m_plugin != NULL )
 	{
-		p.setPen( QColor( 251, 41, 8 ) );
+		p.setPen( QColor( 0, 0, 0 ) );
 		f.setBold( false );
 		p.setFont( pointSize<8>( f ) );
-		p.drawText( 10, 114, tr( "by" ) + " " +
+		p.drawText( 10, 114, tr( "by " ) +
 					m_vi->m_plugin->vendorString() );
+		p.setPen( QColor( 255, 255, 255 ) );
 		p.drawText( 10, 225, m_vi->m_plugin->currentProgramName() );
 	}
+
+	if( m_vi->m_subWindow != NULL )
+	{
+		m_vi->m_subWindow->setWindowTitle( m_vi->instrumentTrack()->name()
+								+ tr( " - VST plugin control" ) );
+	}
 //	m_pluginMutex.unlock();
 }
 
@@ -809,12 +881,14 @@ manageVestigeInstrumentView::manageVestigeInstrumentView( Instrument * _instrume
 	widget = new QWidget(this);
 	l = new QGridLayout( this );
 
-	m_vi->m_subWindow = engine::mainWindow()->workspace()->addSubWindow(new QMdiSubWindow, Qt::SubWindow | 
+	m_vi->m_subWindow = engine::mainWindow()->workspace()->addSubWindow(new QMdiSubWindow, Qt::SubWindow |
 			Qt::CustomizeWindowHint | Qt::WindowTitleHint | Qt::WindowSystemMenuHint);
-	m_vi->m_subWindow->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
-	m_vi->m_subWindow->setFixedSize( 960, 300);
+	m_vi->m_subWindow->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::MinimumExpanding );
+	m_vi->m_subWindow->setFixedWidth( 960 );
+	m_vi->m_subWindow->setMinimumHeight( 300 );
 	m_vi->m_subWindow->setWidget(m_vi->m_scrollArea);
-	m_vi->m_subWindow->setWindowTitle(m_vi->m_plugin->name());
+	m_vi->m_subWindow->setWindowTitle( m_vi->instrumentTrack()->name()
+								+ tr( " - VST plugin control" ) );
 	m_vi->m_subWindow->setWindowIcon( PLUGIN_NAME::getIconPixmap( "logo" ) );
 	//m_vi->m_subWindow->setAttribute(Qt::WA_DeleteOnClose);
 
@@ -831,56 +905,83 @@ manageVestigeInstrumentView::manageVestigeInstrumentView( Instrument * _instrume
 
 	l->addWidget( m_syncButton, 0, 0, 1, 2, Qt::AlignLeft );
 
+	m_displayAutomatedOnly = new QPushButton( tr( "Automated" ), this );
+	connect( m_displayAutomatedOnly, SIGNAL( clicked() ), this,
+							SLOT( displayAutomatedOnly() ) );
+	m_displayAutomatedOnly->setWhatsThis(
+		tr( "Click here if you want to display automated parameters only." ) );
+
+	l->addWidget( m_displayAutomatedOnly, 0, 1, 1, 2, Qt::AlignLeft );
+
+
+	m_closeButton = new QPushButton( tr( "    Close    " ), widget );
+	connect( m_closeButton, SIGNAL( clicked() ), this,
+							SLOT( closeWindow() ) );
+	m_closeButton->setWhatsThis(
+		tr( "Close VST plugin knob-controller window." ) );
+
+	l->addWidget( m_closeButton, 0, 2, 1, 7, Qt::AlignLeft );
+
+
+	for( int i = 0; i < 10; i++ )
+	{
+		l->addItem( new QSpacerItem( 68, 45, QSizePolicy::Fixed, QSizePolicy::Fixed ), 0, i );
+	}
+
 	const QMap<QString, QString> & dump = m_vi->m_plugin->parameterDump();
-	int paramCount = (dump).size();
+	m_vi->paramCount = dump.size();
 
 	bool isVstKnobs = true;
 
 	if (m_vi->vstKnobs == NULL) {
-		m_vi->vstKnobs = new knob *[paramCount];
+		m_vi->vstKnobs = new knob *[ m_vi->paramCount ];
 		isVstKnobs = false;
 	}
 	if (m_vi->knobFModel == NULL) {
-		m_vi->knobFModel = new FloatModel *[paramCount];
+		m_vi->knobFModel = new FloatModel *[ m_vi->paramCount ];
 	}
 
 	char paramStr[35];
-	QStringList list1;
+	QStringList s_dumpValues;
 
 	if (isVstKnobs == false) {
-		for (int i = 0; i < paramCount; i++) {
+		for( int i = 0; i < m_vi->paramCount; i++ )
+		{
 			sprintf( paramStr, "param%d", i);
-    			list1 = dump[paramStr].split(":");
+    			s_dumpValues = dump[ paramStr ].split( ":" );
 
-			m_vi->vstKnobs[i] = new knob( knobBright_26, this );
-			m_vi->vstKnobs[i]->setHintText( list1.at(1) + ":", "");
-			m_vi->vstKnobs[i]->setLabel( list1.at(1).left(15) );
+			m_vi->vstKnobs[ i ] = new knob( knobBright_26, this, s_dumpValues.at( 1 ) );
+			m_vi->vstKnobs[ i ]->setHintText( s_dumpValues.at( 1 ) + ":", "" );
+			m_vi->vstKnobs[ i ]->setLabel( s_dumpValues.at( 1 ).left( 15 ) );
 
 			sprintf( paramStr, "%d", i);
-			m_vi->knobFModel[i] = new FloatModel( (list1.at(2)).toFloat(), 0.0f, 1.0f, 0.01f, 
-					castModel<vestigeInstrument>(), tr( paramStr ) );
+			m_vi->knobFModel[ i ] = new FloatModel( (s_dumpValues.at( 2 )).toFloat(),
+				0.0f, 1.0f, 0.01f, castModel<vestigeInstrument>(), tr( paramStr ) );
 			connect( m_vi->knobFModel[i], SIGNAL( dataChanged() ), this, SLOT( setParameter() ) );
 			m_vi->vstKnobs[i] ->setModel( m_vi->knobFModel[i] );
 		}
 	}
 
 	int i = 0;
-	for (int lrow = 0+1; lrow < (int(paramCount / 10) + 1)+1; lrow++) {
-		for (int lcolumn = 0; lcolumn < 10; lcolumn++) {
-			if (i < paramCount)
+	for( int lrow = 1; lrow < ( int( m_vi->paramCount / 10 ) + 1 ) + 1; lrow++ )
+	{
+		for( int lcolumn = 0; lcolumn < 10; lcolumn++ )
+		{
+			if( i < m_vi->paramCount )
+			{
 				l->addWidget( m_vi->vstKnobs[i], lrow, lcolumn, Qt::AlignCenter );
+			}
 			i++;
 		}
 	}
 
-	l->setRowStretch( (int(paramCount / 10) + 1), 1 );
+	l->setRowStretch( ( int( m_vi->paramCount / 10) + 1), 1 );
 	l->setColumnStretch( 10, 1 );
 
 	widget->setLayout(l);
 	widget->setAutoFillBackground(true);
 
 	m_vi->m_scrollArea->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOn );
-	m_vi->m_scrollArea->setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
 	m_vi->m_scrollArea->setPalette( QApplication::palette( m_vi->m_scrollArea ) );
 	m_vi->m_scrollArea->setMinimumHeight( 64 );
 
@@ -892,43 +993,98 @@ manageVestigeInstrumentView::manageVestigeInstrumentView( Instrument * _instrume
 
 
 
+void manageVestigeInstrumentView::closeWindow()
+{
+	m_vi->m_subWindow->hide();
+}
+
+
+
+
 void manageVestigeInstrumentView::syncPlugin( void )
 {
 	char paramStr[35];
-	QStringList list1;
+	QStringList s_dumpValues;
 	const QMap<QString, QString> & dump = m_vi->m_plugin->parameterDump();
-	float f;
+	float f_value;
 
-	for (int i = 0; i<(dump).size(); i++) {
-		sprintf( paramStr, "param%d", i);
-    		list1 = dump[paramStr].split(":");
-		f = (list1.at(2)).toFloat();
-		m_vi->knobFModel[i]->setValue(f);
-		m_vi->knobFModel[i]->setInitValue(f);
+	for( int i = 0; i < m_vi->paramCount; i++ )
+	{
+		// only not automated knobs are synced from VST
+		// those auto-setted values are not jurnaled, tracked for undo / redo
+		if( !( m_vi->knobFModel[ i ]->isAutomated() || m_vi->knobFModel[ i ]->controllerConnection() ) )
+		{
+			sprintf( paramStr, "param%d", i );
+    			s_dumpValues = dump[ paramStr ].split( ":" );
+			f_value = ( s_dumpValues.at( 2 ) ).toFloat();
+			m_vi->knobFModel[ i ]->setAutomatedValue( f_value );
+			m_vi->knobFModel[ i ]->setInitValue( f_value );
+		}
+	}
+}
+
+
+
+
+void manageVestigeInstrumentView::displayAutomatedOnly( void )
+{
+	bool isAuto = QString::compare( m_displayAutomatedOnly->text(), tr( "Automated" ) ) == 0;
+
+	for( int i = 0; i< m_vi->paramCount; i++ )
+	{
+
+		if( !( m_vi->knobFModel[ i ]->isAutomated() || m_vi->knobFModel[ i ]->controllerConnection() ) )
+		{
+			if( m_vi->vstKnobs[ i ]->isVisible() == true  && isAuto )
+			{
+				m_vi->vstKnobs[ i ]->hide();
+				m_displayAutomatedOnly->setText( "All" );
+			} else {
+				m_vi->vstKnobs[ i ]->show();
+				m_displayAutomatedOnly->setText( "Automated" );
+			}
+		}
 	}
 }
 
 
 manageVestigeInstrumentView::~manageVestigeInstrumentView()
 {
+	if( m_vi->knobFModel != NULL )
+	{
+		for( int i = 0; i < m_vi->paramCount; i++ )
+		{
+			delete m_vi->knobFModel[ i ];
+			delete m_vi->vstKnobs[ i ];
+		}
+	}
+
 	if (m_vi->vstKnobs != NULL) {
 		delete []m_vi->vstKnobs;
 		m_vi->vstKnobs = NULL;
 	}
- 
+
+	if( m_vi->knobFModel != NULL )
+	{
+		delete [] m_vi->knobFModel;
+		m_vi->knobFModel = NULL;
+	}
+
 	if (m_vi->m_scrollArea != NULL) {
 		delete m_vi->m_scrollArea;
 		m_vi->m_scrollArea = NULL;
 	}
- 
+
 	if ( m_vi->m_subWindow != NULL ) {
 		m_vi->m_subWindow->setAttribute(Qt::WA_DeleteOnClose);
 		m_vi->m_subWindow->close();
- 
-		if ( m_vi->m_subWindow != NULL ) 
+
+		if ( m_vi->m_subWindow != NULL )
 			delete m_vi->m_subWindow;
 		m_vi->m_subWindow = NULL;
 	}
+
+	m_vi->p_subWindow = NULL;
 }
 
 
@@ -983,12 +1139,14 @@ void manageVestigeInstrumentView::dropEvent( QDropEvent * _de )
 	}
 	_de->ignore();
 }
- 
- 
- 
- 
+
+
+
+
 void manageVestigeInstrumentView::paintEvent( QPaintEvent * )
 {
+	m_vi->m_subWindow->setWindowTitle( m_vi->instrumentTrack()->name()
+					+ tr( " - VST plugin control" ) );
 }
 
 
