@@ -1,9 +1,9 @@
 /*
  * vestige.h - instrument VeSTige for hosting VST-plugins
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -34,7 +34,6 @@
 
 #include "Instrument.h"
 #include "InstrumentView.h"
-#include "midi.h"
 #include "note.h"
 #include "knob.h"
 
@@ -64,13 +63,12 @@ public:
 
 	virtual void loadFile( const QString & _file );
 
-	virtual bool isMidiBased( void ) const
+	virtual Flags flags() const
 	{
-		return true;
+		return IsSingleStreamed | IsMidiBased;
 	}
 
-	virtual bool handleMidiEvent( const midiEvent & _me,
-						const midiTime & _time );
+	virtual bool handleMidiEvent( const MidiEvent& event, const MidiTime& time, f_cnt_t offset = 0 );
 
 	virtual PluginView * instantiateView( QWidget * _parent );
 
@@ -80,8 +78,6 @@ protected slots:
 private:
 	void closePlugin( void );
 
-	int m_runningNotes[NumKeys];
-
 
 	VstPlugin * m_plugin;
 	QMutex m_pluginMutex;
@@ -92,6 +88,7 @@ private:
 	knob ** vstKnobs;
 	FloatModel ** knobFModel;
 	QObject * p_subWindow;
+	int paramCount;
 
 
 	friend class VestigeInstrumentView;
@@ -110,7 +107,9 @@ public:
 
 protected slots:
 	void syncPlugin( void );
+	void displayAutomatedOnly( void );
 	void setParameter( void );
+	void closeWindow();
 
 
 protected:
@@ -127,6 +126,8 @@ private:
 	QWidget *widget;
 	QGridLayout * l;
 	QPushButton * m_syncButton;
+	QPushButton * m_displayAutomatedOnly;
+	QPushButton * m_closeButton;
 
 } ;
 
