@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2008 Danny McRae <khjklujn/at/yahoo/com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@
 #include "vibed.h"
 #include "engine.h"
 #include "InstrumentTrack.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "tooltip.h"
 #include "base64.h"
 #include "caption_menu.h"
@@ -71,7 +71,7 @@ vibed::vibed( InstrumentTrack * _instrumentTrack ) :
 	nineButtonSelectorModel * harmonic;
 	graphModel * graphTmp;
 
-	for( Uint8 harm = 0; harm < 9; harm++ )
+	for( int harm = 0; harm < 9; harm++ )
 	{
 		knob = new FloatModel( DefaultVolume, MinVolume, MaxVolume,
 				1.0f, this, tr( "String %1 volume" ).arg( harm+1 ) );
@@ -142,7 +142,7 @@ void vibed::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	// Save plugin version
 	_this.setAttribute( "version", "0.1" );
 	
-	for( Uint8 i = 0; i < 9; i++ )
+	for( int i = 0; i < 9; i++ )
 	{
 		name = "active" + QString::number( i );
 		_this.setAttribute( name, QString::number(
@@ -199,7 +199,7 @@ void vibed::loadSettings( const QDomElement & _this )
 
 	QString name;
 
-	for( Uint8 i = 0; i < 9; i++ )
+	for( int i = 0; i < 9; i++ )
 	{
 		name = "active" + QString::number( i );
 		m_powerButtons[i]->setValue( _this.attribute( name ).toInt() );
@@ -272,15 +272,15 @@ QString vibed::nodeName() const
 
 
 
-void vibed::playNote( notePlayHandle * _n, sampleFrame * _working_buffer )
+void vibed::playNote( NotePlayHandle * _n, sampleFrame * _working_buffer )
 {
 	if ( _n->totalFramesPlayed() == 0 || _n->m_pluginData == NULL )
 	{
 		_n->m_pluginData = new stringContainer( _n->frequency(),
-				engine::getMixer()->processingSampleRate(),
+				engine::mixer()->processingSampleRate(),
 						__sampleLength );
 		
-		for( Uint8 i = 0; i < 9; ++i )
+		for( int i = 0; i < 9; ++i )
 		{
 			if( m_powerButtons[i]->value() )
 			{
@@ -309,18 +309,14 @@ void vibed::playNote( notePlayHandle * _n, sampleFrame * _working_buffer )
 	{
 		_working_buffer[i][0] = 0.0f;
 		_working_buffer[i][1] = 0.0f;
-		Uint8 s = 0;
-		for( Uint8 string = 0; string < 9; ++string )
+		int s = 0;
+		for( int string = 0; string < 9; ++string )
 		{
 			if( ps->exists( string ) )
 			{
 				// pan: 0 -> left, 1 -> right
-				const float pan = (
-					m_panKnobs[string]->value() + 1 ) /
-									2.0f;
-				const sample_t sample =
-						ps->getStringSample( s ) *
-					m_volumeKnobs[string]->value() / 100.0f;
+				const float pan = ( m_panKnobs[string]->value() + 1 ) / 2.0f;
+				const sample_t sample = ps->getStringSample( s ) * m_volumeKnobs[string]->value() / 100.0f;
 				_working_buffer[i][0] += ( 1.0f - pan ) * sample;
 				_working_buffer[i][1] += pan * sample;
 				s++;
@@ -334,7 +330,7 @@ void vibed::playNote( notePlayHandle * _n, sampleFrame * _working_buffer )
 
 
 
-void vibed::deleteNotePluginData( notePlayHandle * _n )
+void vibed::deleteNotePluginData( NotePlayHandle * _n )
 {
 	delete static_cast<stringContainer *>( _n->m_pluginData );
 }
@@ -547,8 +543,8 @@ vibedView::vibedView( Instrument * _instrument,
 "vibrating strings.  The LED in the lower right corner of the "
 "waveform editor indicates whether the selected string is active." ) );
 
-	connect( m_stringSelector, SIGNAL( nineButtonSelection( Uint8 ) ),
-			this, SLOT( showString( Uint8 ) ) );
+	connect( m_stringSelector, SIGNAL( nineButtonSelection( int ) ),
+			this, SLOT( showString( int ) ) );
 
 	showString( 0 );
 
@@ -668,7 +664,7 @@ void vibedView::modelChanged()
 
 
 
-void vibedView::showString( Uint8 _string )
+void vibedView::showString( int _string )
 {
 	vibed * v = castModel<vibed>();
 	
@@ -732,9 +728,9 @@ void vibedView::noiseWaveClicked()
 
 void vibedView::usrWaveClicked()
 {
-	// TODO: load file
-	//m_graph->model()->setWaveToUser();
-	//engine::getSongEditor()->setModified();
+	QString fileName = m_graph->model()->setWaveToUser();
+	toolTip::add( m_usrWaveBtn, fileName );
+	engine::getSong()->setModified();
 }
 
 
@@ -759,9 +755,8 @@ void vibedView::normalizeClicked()
 void vibedView::contextMenuEvent( QContextMenuEvent * )
 {
 
-	captionMenu contextMenu( model()->displayName() );
-	contextMenu.addAction( embed::getIconPixmap( "help" ), tr( "&Help" ),
-					this, SLOT( displayHelp() ) );
+	captionMenu contextMenu( model()->displayName(), this );
+	contextMenu.addHelpAction();
 	contextMenu.exec( QCursor::pos() );
 
 }
