@@ -1,9 +1,9 @@
 /*
  * RemoteVstPlugin.cpp - LMMS VST Support Layer (RemotePlugin client)
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * Code partly taken from (X)FST:
  * 		Copyright (c) 2004 Paul Davis
@@ -89,10 +89,23 @@ struct ERect
 
 
 #include "lmms_basics.h"
-#include "midi.h"
+#include "Midi.h"
 #include "communication.h"
 
+#include "VstSyncData.h"
 
+#ifdef LMMS_BUILD_WIN32
+#define USE_QT_SHMEM
+#endif
+
+#ifndef USE_QT_SHMEM
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/ipc.h>
+#include <sys/shm.h>
+#endif
 
 static VstHostLanguages hlang = LanguageEnglish;
 
@@ -119,8 +132,7 @@ public:
 	virtual void process( const sampleFrame * _in, sampleFrame * _out );
 
 
-	virtual void processMidiEvent( const midiEvent & _event,
-							const f_cnt_t _offset );
+	virtual void processMidiEvent( const MidiEvent& event, const f_cnt_t offset );
 
 	// set given sample-rate for plugin
 	virtual void updateSampleRate()
@@ -284,7 +296,7 @@ private:
 
 	AEffect * m_plugin;
 	HWND m_window;
-	Sint32 m_windowID;
+	intptr_t m_windowID;
 	int m_windowWidth;
 	int m_windowHeight;
 
@@ -303,6 +315,18 @@ private:
 	double m_currentSamplePos;
 	int m_currentProgram;
 
+	// host to plugin synchronisation data structure
+	struct in
+	{
+		float lastppqPos;
+		float m_Timestamp;
+	} ;
+
+	in * m_in;
+
+	int m_shmID;
+	VstSyncData* m_vstSyncData;
+
 } ;
 
 
@@ -324,12 +348,59 @@ RemoteVstPlugin::RemoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
 	m_midiEvents(),
 	m_bpm( 0 ),
 	m_currentSamplePos( 0 ),
-	m_currentProgram( -1 )
+	m_currentProgram( -1 ),
+	m_in( NULL ),
+	m_shmID( -1 ),
+	m_vstSyncData( NULL )
+
 {
 	pthread_mutex_init( &m_pluginLock, NULL );
 
 	__plugin = this;
 
+#ifndef USE_QT_SHMEM
+	key_t key;
+	if( ( key = ftok( VST_SNC_SHM_KEY_FILE, 'R' ) ) == -1 )
+	{
+		perror( "RemoteVstPlugin.cpp::ftok" );
+	}
+	else
+	{	// connect to shared memory segment
+		if( ( m_shmID = shmget( key, 0, 0 ) ) == -1 )
+		{
+			perror( "RemoteVstPlugin.cpp::shmget" );
+		}
+		else
+		{	// attach segment
+			m_vstSyncData = (VstSyncData *)shmat(m_shmID, 0, 0);
+			if( m_vstSyncData == (VstSyncData *)( -1 ) )
+			{
+				perror( "RemoteVstPlugin.cpp::shmat" );
+			}
+		}
+	}
+#else
+	m_vstSyncData = RemotePluginClient::getQtVSTshm();
+#endif
+	if( m_vstSyncData == NULL )
+	{
+		fprintf(stderr, "RemoteVstPlugin.cpp: "
+			"Failed to initialize shared memory for VST synchronization.\n"
+			" (VST-host synchronization will be disabled)\n");
+		m_vstSyncData = (VstSyncData*) malloc( sizeof( VstSyncData ) );
+		m_vstSyncData->isPlaying = true;
+		m_vstSyncData->timeSigNumer = 4;
+		m_vstSyncData->timeSigDenom = 4;
+		m_vstSyncData->ppqPos = 0;
+		m_vstSyncData->isCycle = false;
+		m_vstSyncData->hasSHM = false;
+		m_vstSyncData->m_sampleRate = sampleRate();
+	}
+
+	m_in = ( in* ) new char[ sizeof( in ) ];
+	m_in->lastppqPos = 0;
+	m_in->m_Timestamp = -1;
+
 	// process until we have loaded the plugin
 	while( 1 )
 	{
@@ -355,6 +426,23 @@ RemoteVstPlugin::~RemoteVstPlugin()
 #endif
 		m_window = NULL;
 	}
+	pluginDispatch( effMainsChanged, 0, 0 );
+	pluginDispatch( effClose );
+#ifndef USE_QT_SHMEM
+	// detach shared memory segment
+	if( shmdt( m_vstSyncData ) == -1)
+	{
+		if( __plugin->m_vstSyncData->hasSHM )
+		{
+			perror( "~RemoteVstPlugin::shmdt" );
+		}
+		if( m_vstSyncData != NULL )
+		{
+			delete m_vstSyncData;
+			m_vstSyncData = NULL;
+		}
+	}
+#endif
 
 	if( m_libInst != NULL )
 	{
@@ -451,7 +539,7 @@ bool RemoteVstPlugin::processMessage( const message & _m )
 			lock();
 			m_plugin->setParameter( m_plugin, _m.getInt( 0 ), _m.getFloat( 1 ) );
 			unlock();
-			sendMessage( IdVstSetParameter );
+			//sendMessage( IdVstSetParameter );
 			break;
 
 
@@ -486,6 +574,12 @@ void RemoteVstPlugin::init( const std::string & _plugin_file )
 
 	updateInOutCount();
 
+	// some plugins have to set samplerate during init
+	if( m_vstSyncData->hasSHM )
+	{
+		updateSampleRate();
+	}
+
 	/* set program to zero */
 	/* i comment this out because it breaks dfx Geometer
 	 * looks like we cant set programs for it
@@ -558,10 +652,12 @@ void RemoteVstPlugin::initEditor()
 	}
 
 #ifdef LMMS_BUILD_LINUX
-	m_window = CreateWindowEx( 0, "LVSL", m_shortName.c_str(),
-			       ( WS_OVERLAPPEDWINDOW | WS_THICKFRAME ) & ~WS_MAXIMIZEBOX,
-			       0, 0, 10, 10, NULL, NULL, hInst, NULL );
+	//m_window = CreateWindowEx( 0, "LVSL", m_shortName.c_str(),
+	//		       ( WS_OVERLAPPEDWINDOW | WS_THICKFRAME ) & ~WS_MAXIMIZEBOX,
+	//		       0, 0, 10, 10, NULL, NULL, hInst, NULL );
 
+	m_window = CreateWindowEx( 0 , "LVSL", m_shortName.c_str(),
+	   WS_POPUP | WS_SYSMENU | WS_BORDER , 0, 0, 10, 10, NULL, NULL, hInst, NULL);
 #else
 	m_windowID = 1;	// arbitrary value on win32 to signal
 			// vstPlugin-class that we have an editor
@@ -594,7 +690,7 @@ void RemoteVstPlugin::initEditor()
 	UpdateWindow( m_window );
 
 #ifdef LMMS_BUILD_LINUX
-	m_windowID = (Sint32) GetProp( m_window, "__wine_x11_whole_window" );
+	m_windowID = (intptr_t) GetProp( m_window, "__wine_x11_whole_window" );
 #endif
 }
 
@@ -644,8 +740,6 @@ bool RemoteVstPlugin::load( const std::string & _plugin_file )
 		return false;
 	}
 
-	m_plugin->user = this;
-
 	if( m_plugin->magic != kEffectMagic )
 	{
 		debugMessage( "File is not a VST plugin\n" );
@@ -679,16 +773,15 @@ void RemoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 		// dispatcher-call, so we create static copies of the
 		// data and post them
 #define MIDI_EVENT_BUFFER_COUNT		1024
-		static char event_buf[sizeof( VstMidiEvent * ) *
-						MIDI_EVENT_BUFFER_COUNT +
-							sizeof( VstEvents )];
+		static char eventsBuffer[sizeof( VstEvents ) + sizeof( VstMidiEvent * ) * MIDI_EVENT_BUFFER_COUNT];
 		static VstMidiEvent vme[MIDI_EVENT_BUFFER_COUNT];
-		VstEvents * events = (VstEvents *) event_buf;
+
+		VstEvents* events = (VstEvents *) eventsBuffer;
 		events->reserved = 0;
 		events->numEvents = m_midiEvents.size();
+
 		int idx = 0;
-		for( VstMidiEventList::iterator it = m_midiEvents.begin();
-					it != m_midiEvents.end(); ++it, ++idx )
+		for( VstMidiEventList::iterator it = m_midiEvents.begin(); it != m_midiEvents.end(); ++it, ++idx )
 		{
 			memcpy( &vme[idx], &*it, sizeof( VstMidiEvent ) );
 			events->events[idx] = (VstEvent *) &vme[idx];
@@ -736,36 +829,37 @@ void RemoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 
 
 
-void RemoteVstPlugin::processMidiEvent( const midiEvent & _event,
-							const f_cnt_t _offset )
+void RemoteVstPlugin::processMidiEvent( const MidiEvent& event, const f_cnt_t offset )
 {
-	VstMidiEvent event;
+	VstMidiEvent vme;
 
-	event.type = kVstMidiType;
-	event.byteSize = 24;
-	event.deltaFrames = _offset;
-	event.flags = 0;
-	event.detune = 0;
-	event.noteLength = 0;
-	event.noteOffset = 0;
-	event.noteOffVelocity = 0;
-	event.reserved1 = 0;
-	event.reserved2 = 0;
-	event.midiData[0] = _event.m_type + _event.m_channel;
-	switch( _event.m_type )
+	vme.type = kVstMidiType;
+	vme.byteSize = 24;
+	vme.deltaFrames = offset;
+	vme.flags = 0;
+	vme.detune = 0;
+	vme.noteLength = 0;
+	vme.noteOffset = 0;
+	vme.noteOffVelocity = 0;
+	vme.reserved1 = 0;
+	vme.reserved2 = 0;
+	vme.midiData[0] = event.type() + event.channel();
+
+	switch( event.type() )
 	{
 		case MidiPitchBend:
-			event.midiData[1] = _event.m_data.m_param[0] & 0x7f;
-			event.midiData[2] = _event.m_data.m_param[0] >> 7;
+			vme.midiData[1] = event.pitchBend() & 0x7f;
+			vme.midiData[2] = event.pitchBend() >> 7;
 			break;
 		// TODO: handle more special cases
 		default:
-			event.midiData[1] = _event.key();
-			event.midiData[2] = _event.velocity();
+			vme.midiData[1] = event.key();
+			vme.midiData[2] = event.velocity();
 			break;
 	}
-	event.midiData[3] = 0;
-	m_midiEvents.push_back( event );
+	vme.midiData[3] = 0;
+
+	m_midiEvents.push_back( vme );
 }
 
 
@@ -1349,16 +1443,62 @@ intptr_t RemoteVstPlugin::hostCallback( AEffect * _effect, int32_t _opcode,
 			// fields are required (see valid masks above), as some
 			// items may require extensive conversions
 
-			memset( &_timeInfo, 0, sizeof( _timeInfo ) );
+			// Shared memory was initialised? - see song.cpp
+			//assert( __plugin->m_vstSyncData != NULL );
 
+			memset( &_timeInfo, 0, sizeof( _timeInfo ) );
 			_timeInfo.samplePos = __plugin->m_currentSamplePos;
-			_timeInfo.sampleRate = __plugin->sampleRate();
+			_timeInfo.sampleRate = __plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_sampleRate :
+							__plugin->sampleRate();
 			_timeInfo.flags = 0;
-			_timeInfo.tempo = __plugin->m_bpm;
-			_timeInfo.timeSigNumerator = 4;
-			_timeInfo.timeSigDenominator = 4;
-			_timeInfo.flags |= (/* kVstBarsValid|*/kVstTempoValid );
-			_timeInfo.flags |= kVstTransportPlaying;
+			_timeInfo.tempo = __plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_bpm :
+							__plugin->m_bpm;
+			_timeInfo.timeSigNumerator = __plugin->m_vstSyncData->timeSigNumer;
+			_timeInfo.timeSigDenominator = __plugin->m_vstSyncData->timeSigDenom;
+			_timeInfo.flags |= kVstTempoValid;
+			_timeInfo.flags |= kVstTimeSigValid;
+
+			if( __plugin->m_vstSyncData->isCycle )
+			{
+				_timeInfo.cycleStartPos = __plugin->m_vstSyncData->cycleStart;
+				_timeInfo.cycleEndPos = __plugin->m_vstSyncData->cycleEnd;
+				_timeInfo.flags |= kVstCyclePosValid;
+				_timeInfo.flags |= kVstTransportCycleActive;
+			}
+
+			if( __plugin->m_vstSyncData->ppqPos != 
+							__plugin->m_in->m_Timestamp )
+			{
+				_timeInfo.ppqPos = __plugin->m_vstSyncData->ppqPos;
+				_timeInfo.flags |= kVstTransportChanged;
+				__plugin->m_in->lastppqPos = __plugin->m_vstSyncData->ppqPos;
+				__plugin->m_in->m_Timestamp = __plugin->m_vstSyncData->ppqPos;
+			}
+			else if( __plugin->m_vstSyncData->isPlaying )
+			{
+				__plugin->m_in->lastppqPos += (
+							__plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_bpm :
+							__plugin->m_bpm ) / (float)10340;
+				_timeInfo.ppqPos = __plugin->m_in->lastppqPos;
+			}
+//			_timeInfo.ppqPos = __plugin->m_vstSyncData->ppqPos;
+			_timeInfo.flags |= kVstPpqPosValid;
+
+			if( __plugin->m_vstSyncData->isPlaying )
+			{
+				_timeInfo.flags |= kVstTransportPlaying;
+			}
+			_timeInfo.barStartPos = ( (int) ( _timeInfo.ppqPos / 
+				( 4 *__plugin->m_vstSyncData->timeSigNumer
+				/ (float) __plugin->m_vstSyncData->timeSigDenom ) ) ) *
+				( 4 * __plugin->m_vstSyncData->timeSigNumer
+				/ (float) __plugin->m_vstSyncData->timeSigDenom );
+
+			_timeInfo.flags |= kVstBarsValid;
+
 #ifdef LMMS_BUILD_WIN64
 			return (long long) &_timeInfo;
 #else
@@ -1720,10 +1860,12 @@ int main( int _argc, char * * _argv )
 	}
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	// (non-portable) initialization of statically linked pthread library
 	pthread_win32_process_attach_np();
 	pthread_win32_thread_attach_np();
 #endif
+#endif
 
 #ifdef LMMS_BUILD_LINUX
 #ifdef LMMS_HAVE_SCHED_H
@@ -1757,8 +1899,10 @@ int main( int _argc, char * * _argv )
 
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	pthread_win32_thread_detach_np();
 	pthread_win32_process_detach_np();
+#endif
 #endif
 
 	return 0;
