@@ -1,9 +1,9 @@
 /*
  * VstPlugin.cpp - implementation of VstPlugin class
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2013 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,7 +24,6 @@
 
 #include "VstPlugin.h"
 
-#include <QtGui/QFileDialog>
 #include <QtCore/QDir>
 #include <QtCore/QFileInfo>
 #include <QtCore/QLocale>
@@ -49,6 +48,8 @@
 #include "MainWindow.h"
 #include "song.h"
 #include "templates.h"
+#include "FileDialog.h"
+#include <QtGui/QLayout>
 
 
 class vstSubWin : public QMdiSubWindow
@@ -109,7 +110,7 @@ VstPlugin::VstPlugin( const QString & _plugin ) :
 
 	connect( engine::getSong(), SIGNAL( tempoChanged( bpm_t ) ),
 			this, SLOT( setTempo( bpm_t ) ) );
-	connect( engine::getMixer(), SIGNAL( sampleRateChanged() ),
+	connect( engine::mixer(), SIGNAL( sampleRateChanged() ),
 				this, SLOT( updateSampleRate() ) );
 
 	// update once per second
@@ -200,11 +201,24 @@ void VstPlugin::tryLoad( const QString &remoteVstPluginExecutable )
 
 
 
-void VstPlugin::showEditor( QWidget * _parent )
+void VstPlugin::showEditor( QWidget * _parent, bool isEffect )
 {
 	QWidget * w = pluginWidget();
 	if( w )
 	{
+#ifdef LMMS_BUILD_WIN32
+		// hide sw, plugin window wrapper on win32
+		// this is obtained from pluginWidget()
+		if( isEffect )
+		{
+			w->setWindowFlags( Qt::FramelessWindowHint );
+			w->setAttribute( Qt::WA_TranslucentBackground );
+		}
+		else
+		{
+			w->setWindowFlags( Qt::WindowCloseButtonHint );
+		}
+#endif
 		w->show();
 		return;
 	}
@@ -222,13 +236,30 @@ void VstPlugin::showEditor( QWidget * _parent )
 	{
 		vstSubWin * sw = new vstSubWin(
 					engine::mainWindow()->workspace() );
-		sw->setWidget( m_pluginWidget );
+		if( isEffect )
+		{
+			sw->setAttribute( Qt::WA_TranslucentBackground );
+			sw->setWindowFlags( Qt::FramelessWindowHint );
+			sw->setWidget( m_pluginWidget );
+
+			QX11EmbedContainer * xe = new QX11EmbedContainer( sw );
+			xe->embedClient( m_pluginWindowID );
+			xe->setFixedSize( m_pluginGeometry );
+			xe->show();
+		} 
+		else
+		{
+			sw->setWindowFlags( Qt::WindowCloseButtonHint );
+			sw->setWidget( m_pluginWidget );
+
+			QX11EmbedContainer * xe = new QX11EmbedContainer( sw );
+			xe->embedClient( m_pluginWindowID );
+			xe->setFixedSize( m_pluginGeometry );
+			xe->move( 4, 24 );
+			xe->show();
+		}
 	}
 
-	QX11EmbedContainer * xe = new QX11EmbedContainer( m_pluginWidget );
-	xe->embedClient( m_pluginWindowID );
-	xe->setFixedSize( m_pluginGeometry );
-	xe->show();
 #endif
 
 	if( m_pluginWidget )
@@ -258,7 +289,7 @@ void VstPlugin::loadSettings( const QDomElement & _this )
 	{
 		if( _this.attribute( "guivisible" ).toInt() )
 		{
-			showEditor();
+			showEditor( NULL, false );
 		}
 		else
 		{
@@ -341,7 +372,7 @@ void VstPlugin::updateSampleRate()
 {
 	lock();
 	sendMessage( message( IdSampleRateInformation ).
-			addInt( engine::getMixer()->processingSampleRate() ) );
+			addInt( engine::mixer()->processingSampleRate() ) );
 	unlock();
 }
 
@@ -384,7 +415,7 @@ void VstPlugin::setParameterDump( const QMap<QString, QString> & _pdump )
 		{
 			( *it ).section( ':', 0, 0 ).toInt(),
 			"",
-			( *it ).section( ':', 1, 1 ).toFloat()
+			( *it ).section( ':', 2, -1 ).toFloat()
 		} ;
 		m.addInt( item.index );
 		m.addString( item.shortLabel );
@@ -479,9 +510,9 @@ bool VstPlugin::processMessage( const message & _m )
 void VstPlugin::openPreset( )
 {
 
-	QFileDialog ofd( NULL, tr( "Open Preset" ), "",
+	FileDialog ofd( NULL, tr( "Open Preset" ), "",
 		tr( "Vst Plugin Preset (*.fxp *.fxb)" ) );
-	ofd.setFileMode( QFileDialog::ExistingFiles );
+	ofd.setFileMode( FileDialog::ExistingFiles );
 	if( ofd.exec () == QDialog::Accepted &&
 					!ofd.selectedFiles().isEmpty() )
 	{
@@ -537,7 +568,7 @@ void VstPlugin::savePreset( )
 	QString presName = currentProgramName().isEmpty() ? tr(": default") : currentProgramName();
 	presName.replace(tr("\""), tr("'")); // QFileDialog unable to handle double quotes properly
 
-	QFileDialog sfd( NULL, tr( "Save Preset" ), presName.section(": ", 1, 1) + tr(".fxp"),
+	FileDialog sfd( NULL, tr( "Save Preset" ), presName.section(": ", 1, 1) + tr(".fxp"),
 		tr( "Vst Plugin Preset (*.fxp *.fxb)" ) );
 
 	if( p_name != "" ) // remember last directory
@@ -545,8 +576,8 @@ void VstPlugin::savePreset( )
 		sfd.setDirectory( QFileInfo( p_name ).absolutePath() );
 	}
 
-	sfd.setAcceptMode( QFileDialog::AcceptSave );
-	sfd.setFileMode( QFileDialog::AnyFile );
+	sfd.setAcceptMode( FileDialog::AcceptSave );
+	sfd.setFileMode( FileDialog::AnyFile );
 	if( sfd.exec () == QDialog::Accepted &&
 				!sfd.selectedFiles().isEmpty() && sfd.selectedFiles()[0] != "" )
 	{
@@ -574,7 +605,7 @@ void VstPlugin::setParam( int i, float f )
 {
 	lock();
 	sendMessage( message( IdVstSetParameter ).addInt( i ).addFloat( f ) );
-	waitForMessage( IdVstSetParameter );
+	//waitForMessage( IdVstSetParameter );
 	unlock();
 }
 
