@@ -1,9 +1,9 @@
 /*
  * VstPlugin.h - declaration of VstPlugin class
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,13 +25,14 @@
 #ifndef _VST_PLUGIN_H
 #define _VST_PLUGIN_H
 
+#include <QtCore/QMap>
 #include <QtCore/QMutex>
 #include <QtCore/QPointer>
 #include <QtCore/QString>
 #include <QtCore/QTimer>
 #include <QtGui/QWidget>
 
-#include "mixer.h"
+#include "Mixer.h"
 #include "JournallingObject.h"
 #include "communication.h"
 
@@ -53,7 +54,7 @@ public:
 		return m_pluginWindowID != 0;
 	}
 
-	void showEditor( QWidget * _parent = NULL );
+	void showEditor( QWidget * _parent = NULL, bool isEffect = false );
 	void hideEditor();
 
 	inline const QString & name() const
@@ -61,7 +62,7 @@ public:
 		return m_name;
 	}
 
-	inline Sint32 version() const
+	inline int version() const
 	{
 		return m_version;
 	}
@@ -137,7 +138,7 @@ private:
 	bool m_badDllFormat;
 
 	QString m_name;
-	Sint32 m_version;
+	int m_version;
 	QString m_vendorString;
 	QString m_productString;
 	QString m_currentProgramName;
