@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2005-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -64,6 +64,12 @@ enum VstRemoteMessageIDs
 	IdVstGetParameterDump,
 	IdVstSetParameterDump,
 	IdVstGetParameterProperties,
+	IdVstProgramNames,
+	IdVstCurrentProgram,
+	IdVstCurrentProgramName,
+	IdVstSetProgram,
+	IdVstRotateProgram,
+	IdVstIdleUpdate,
 
 	// remoteVstPlugin -> vstPlugin
 	IdVstFailedLoadingPlugin,
@@ -74,7 +80,9 @@ enum VstRemoteMessageIDs
 	IdVstPluginVersion,
 	IdVstPluginVendorString,
 	IdVstPluginProductString,
+	IdVstPluginPresetsString,
 	IdVstPluginUniqueID,
+	IdVstSetParameter,
 	IdVstParameterCount,
 	IdVstParameterDump,
 	IdVstParameterProperties
