@@ -1,9 +1,9 @@
 /*
  * LocalZynAddSubFx.cpp - local implementation of ZynAddSubFx plugin
  *
- * Copyright (c) 2009-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2009-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,19 +24,26 @@
 
 #include <lmmsconfig.h>
 
+#include "zynaddsubfx/src/Misc/Util.h"
 #include <unistd.h>
+#include <ctime>
 
 #include "LocalZynAddSubFx.h"
 
-#include "src/Input/NULLMidiIn.h"
-#include "src/Misc/Master.h"
-#include "src/Misc/Dump.h"
+#include "zynaddsubfx/src/Nio/NulEngine.h"
+#include "zynaddsubfx/src/Misc/Master.h"
+#include "zynaddsubfx/src/Misc/Part.h"
+#include "zynaddsubfx/src/Misc/Dump.h"
 
 
+SYNTH_T* synth = NULL;
+
 int LocalZynAddSubFx::s_instanceCount = 0;
 
 
-LocalZynAddSubFx::LocalZynAddSubFx()
+LocalZynAddSubFx::LocalZynAddSubFx() :
+	m_master( NULL ),
+	m_ioEngine( NULL )
 {
 	for( int i = 0; i < NumKeys; ++i )
 	{
@@ -46,24 +53,32 @@ LocalZynAddSubFx::LocalZynAddSubFx()
 	if( s_instanceCount == 0 )
 	{
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 		// (non-portable) initialization of statically linked pthread library
 		pthread_win32_process_attach_np();
 		pthread_win32_thread_attach_np();
+#endif
 #endif
 
 		initConfig();
 
-		OSCIL_SIZE = config.cfg.OscilSize;
+		synth = new SYNTH_T;
+		synth->oscilsize = config.cfg.OscilSize;
+		synth->alias();
 
 		srand( time( NULL ) );
-		denormalkillbuf = new REALTYPE[SOUND_BUFFER_SIZE];
-		for( int i = 0; i < SOUND_BUFFER_SIZE; ++i )
+
+		denormalkillbuf = new float[synth->buffersize];
+		for( int i = 0; i < synth->buffersize; ++i )
 		{
 			denormalkillbuf[i] = (RND-0.5)*1e-16;
 		}
 	}
+
 	++s_instanceCount;
 
+	m_ioEngine = new NulEngine;
+
 	m_master = new Master();
 	m_master->swaplr = 0;
 }
@@ -74,6 +89,7 @@ LocalZynAddSubFx::LocalZynAddSubFx()
 LocalZynAddSubFx::~LocalZynAddSubFx()
 {
 	delete m_master;
+	delete m_ioEngine;
 
 	if( --s_instanceCount == 0 )
 	{
@@ -94,17 +110,19 @@ void LocalZynAddSubFx::initConfig()
 
 
 
-void LocalZynAddSubFx::setSampleRate( int _sampleRate )
+void LocalZynAddSubFx::setSampleRate( int sampleRate )
 {
-	SAMPLE_RATE = _sampleRate;
+	synth->samplerate = sampleRate;
+	synth->alias();
 }
 
 
 
 
-void LocalZynAddSubFx::setBufferSize( int _bufferSize )
+void LocalZynAddSubFx::setBufferSize( int bufferSize )
 {
-	SOUND_BUFFER_SIZE = _bufferSize;
+	synth->buffersize = bufferSize;
+	synth->alias();
 }
 
 
@@ -160,14 +178,12 @@ void LocalZynAddSubFx::setPresetDir( const std::string & _dir )
 	m_presetsDir = _dir;
 	for( int i = 0; i < MAX_BANK_ROOT_DIRS; ++i )
 	{
-		if( config.cfg.bankRootDirList[i] == NULL )
+		if( config.cfg.bankRootDirList[i].empty() )
 		{
-			config.cfg.bankRootDirList[i] = new char[MAX_STRING_SIZE];
-			strcpy( config.cfg.bankRootDirList[i], m_presetsDir.c_str() );
+			config.cfg.bankRootDirList[i] = m_presetsDir;
 			break;
 		}
-		else if( strcmp( config.cfg.bankRootDirList[i],
-							m_presetsDir.c_str() ) == 0 )
+		else if( config.cfg.bankRootDirList[i] == m_presetsDir )
 		{
 			break;
 		}
@@ -190,47 +206,50 @@ void LocalZynAddSubFx::setLmmsWorkingDir( const std::string & _dir )
 
 
 
-void LocalZynAddSubFx::processMidiEvent( const midiEvent & _e )
+void LocalZynAddSubFx::setPitchWheelBendRange( int semitones )
 {
-	// all functions are called while m_master->mutex is held
-	static NULLMidiIn midiIn;
+	for( int i = 0; i < NUM_MIDI_PARTS; ++i )
+	{
+		m_master->part[i]->ctl.setpitchwheelbendrange( semitones * 100 );
+	}
+}
 
-	switch( _e.m_type )
+
+
+void LocalZynAddSubFx::processMidiEvent( const MidiEvent& event )
+{
+	switch( event.type() )
 	{
 		case MidiNoteOn:
-			if( _e.velocity() > 0 )
+			if( event.velocity() > 0 )
 			{
-				if( _e.key() <= 0 || _e.key() >= 128 )
+				if( event.key() < 0 || event.key() > MidiMaxKey )
 				{
 					break;
 				}
-				if( m_runningNotes[_e.key()] > 0 )
+				if( m_runningNotes[event.key()] > 0 )
 				{
-					m_master->NoteOff( 0, _e.key() );
+					m_master->noteOff( event.channel(), event.key() );
 				}
-				++m_runningNotes[_e.key()];
-				m_master->NoteOn( 0, _e.key(), _e.velocity() );
+				++m_runningNotes[event.key()];
+				m_master->noteOn( event.channel(), event.key(), event.velocity() );
 				break;
 			}
 		case MidiNoteOff:
-			if( _e.key() <= 0 || _e.key() >= 128 )
+			if( event.key() < 0 || event.key() > MidiMaxKey )
 			{
 				break;
 			}
-			if( --m_runningNotes[_e.key()] <= 0 )
+			if( --m_runningNotes[event.key()] <= 0 )
 			{
-				m_master->NoteOff( 0, _e.key() );
+				m_master->noteOff( event.channel(), event.key() );
 			}
 			break;
 		case MidiPitchBend:
-			m_master->SetController( 0, C_pitchwheel,
-						_e.m_data.m_param[0] +
-							_e.m_data.m_param[1]*128-8192 );
+			m_master->setController( event.channel(), C_pitchwheel, event.pitchBend()-8192 );
 			break;
 		case MidiControlChange:
-			m_master->SetController( 0,
-						midiIn.getcontroller( _e.m_data.m_param[0] ),
-						_e.m_data.m_param[1] );
+			m_master->setController( event.channel(), event.controllerNumber(), event.controllerValue() );
 			break;
 		default:
 			break;
@@ -242,12 +261,13 @@ void LocalZynAddSubFx::processMidiEvent( const midiEvent & _e )
 
 void LocalZynAddSubFx::processAudio( sampleFrame * _out )
 {
-	REALTYPE outputl[SOUND_BUFFER_SIZE];
-	REALTYPE outputr[SOUND_BUFFER_SIZE];
+	float outputl[synth->buffersize];
+	float outputr[synth->buffersize];
 
-	m_master->AudioOut( outputl, outputr );
+	m_master->GetAudioOutSamples( synth->buffersize, synth->samplerate, outputl, outputr );
 
-	for( int f = 0; f < SOUND_BUFFER_SIZE; ++f )
+	// TODO: move to MixHelpers
+	for( int f = 0; f < synth->buffersize; ++f )
 	{
 		_out[f][0] = outputl[f];
 		_out[f][1] = outputr[f];
