@@ -1,9 +1,9 @@
 /*
  * RemoteZynAddSubFx.h - ZynAddSubFX-embedding plugin
  *
- * Copyright (c) 2008-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2008-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,15 +22,16 @@
  *
  */
 
-#ifndef _REMOTE_ZYNADDSUBFX_H
-#define _REMOTE_ZYNADDSUBFX_H
+#ifndef REMOTE_ZYNADDSUBFX_H
+#define REMOTE_ZYNADDSUBFX_H
 
 #include "RemotePlugin.h"
 
 enum ZasfRemoteMessageIDs
 {
 	IdZasfPresetDirectory = IdUserBase,
-	IdZasfLmmsWorkingDirectory
+	IdZasfLmmsWorkingDirectory,
+	IdZasfSetPitchWheelBendRange
 } ;
 
 #endif
