@@ -3,8 +3,9 @@
  *                  remote-control of AutomatableModels
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail.com>
+ * Copyright (c) 2014 Lukas W <lukaswhl/at/gmail.com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -30,7 +31,7 @@
 
 #include "song.h"
 #include "engine.h"
-#include "mixer.h"
+#include "Mixer.h"
 #include "Controller.h"
 #include "ControllerConnection.h"
 #include "ControllerDialog.h"
@@ -48,13 +49,36 @@ Controller::Controller( ControllerTypes _type, Model * _parent,
 					const QString & _display_name ) :
 	Model( _parent, _display_name ),
 	JournallingObject(),
+	m_connectionCount( 0 ),
 	m_type( _type )
 {
 	if( _type != DummyController && _type != MidiController )
 	{
 		s_controllers.append( this );
-		m_name = QString( tr( "Controller %1" ) )
-				.arg( s_controllers.size() );
+		// Determine which name to use
+		for ( uint i=s_controllers.size(); ; i++ )
+		{
+			QString new_name = QString( tr( "Controller %1" ) )
+					.arg( i );
+
+			// Check if name is already in use
+			bool name_used = false;
+			QVector<Controller *>::const_iterator it;
+			for ( it = s_controllers.constBegin();
+				  it != s_controllers.constEnd(); ++it )
+			{
+				if ( (*it)->name() == new_name )
+				{
+					name_used = true;
+					break;
+				}
+			}
+			if ( ! name_used )
+			{
+				m_name = new_name;
+				break;
+			}
+		}
 	}
 }
 
@@ -109,7 +133,7 @@ unsigned int Controller::runningFrames()
 // Get position in seconds
 float Controller::runningTime()
 {
-	return s_frames / engine::getMixer()->processingSampleRate();
+	return s_frames / engine::mixer()->processingSampleRate();
 }
 
 
@@ -125,7 +149,7 @@ void Controller::triggerFrameCounter()
 		emit s_controllers.at(i)->valueChanged();
 	}
 
-	s_frames += engine::getMixer()->framesPerPeriod();
+	s_frames += engine::mixer()->framesPerPeriod();
 	//emit s_signaler.triggerValueChanged();
 }
 
@@ -149,16 +173,20 @@ Controller * Controller::create( ControllerTypes _ct, Model * _parent )
 			if( dummy )
 				c = dummy;
 			else
+			{
 				c = new Controller( DummyController, NULL,
 								QString() );
+				dummy = c;
+			}
 			break;
 
-		case Controller::LfoController: 
-			c = new ::LfoController( _parent ); 
+		case Controller::LfoController:
+			c = new ::LfoController( _parent );
 			break;
 
 		case Controller::PeakController:
-			c = new ::PeakController( _parent );
+			//Already instantiated in EffectChain::loadSettings()
+			Q_ASSERT( false );
 			break;
 
 		case Controller::MidiController:
@@ -176,9 +204,18 @@ Controller * Controller::create( ControllerTypes _ct, Model * _parent )
 
 Controller * Controller::create( const QDomElement & _this, Model * _parent )
 {
-	Controller * c = create(
-		static_cast<ControllerTypes>( _this.attribute( "type" ).toInt() ),
-									_parent );
+	Controller * c;
+	if( _this.attribute( "type" ).toInt() == Controller::PeakController )
+	{
+		c = PeakController::getControllerBySetting( _this );
+	}
+	else
+	{
+		c = create(
+			static_cast<ControllerTypes>( _this.attribute( "type" ).toInt() ),
+										_parent );
+	}
+
 	if( c != NULL )
 	{
 		c->restoreState( _this );
@@ -203,7 +240,7 @@ bool Controller::hasModel( const Model * m )
 				return true;
 			}
 
-			ControllerConnection * cc = am->getControllerConnection();
+			ControllerConnection * cc = am->controllerConnection();
 			if( cc != NULL )
 			{
 				if( cc->getController()->hasModel( m ) )
@@ -254,6 +291,32 @@ ControllerDialog * Controller::createDialog( QWidget * _parent )
 }
 
 
+
+
+void Controller::addConnection( ControllerConnection * )
+{
+	m_connectionCount++;
+}
+
+
+
+
+void Controller::removeConnection( ControllerConnection * )
+{
+	m_connectionCount--;
+	Q_ASSERT( m_connectionCount >= 0 );
+}
+
+
+
+
+int Controller::connectionCount() const{
+	return m_connectionCount;
+}
+
+
+
+
 #include "moc_Controller.cxx"
 
 
