@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail.com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@
 
 #include "song.h"
 #include "engine.h"
-#include "mixer.h"
+#include "Mixer.h"
 #include "LfoController.h"
 #include "ControllerDialog.h"
 
@@ -49,7 +49,8 @@ LfoController::LfoController( Model * _parent ) :
 	m_duration( 1000 ),
 	m_phaseCorrection( 0 ),
 	m_phaseOffset( 0 ),
-	m_sampleFunction( &Oscillator::sinSample )
+	m_sampleFunction( &Oscillator::sinSample ),
+	m_userDefSampleBuffer( new SampleBuffer )
 {
 
 	connect( &m_waveModel, SIGNAL( dataChanged() ),
@@ -61,6 +62,7 @@ LfoController::LfoController( Model * _parent ) :
 
 LfoController::~LfoController()
 {
+	sharedObject::unref( m_userDefSampleBuffer );
 	m_baseModel.disconnect( this );
 	m_speedModel.disconnect( this );
 	m_amountModel.disconnect( this );
@@ -76,20 +78,17 @@ LfoController::~LfoController()
 // definately be optimized.
 // The code should probably be integrated with the oscillator class. But I
 // don't know how to use oscillator because it is so confusing
-
 float LfoController::value( int _offset )
 {
 	int frame = runningFrames() + _offset + m_phaseCorrection;
 
-	// Recalculate speed each period
-	// Actually, _offset != only if HQ, and we may want to recalc in that case,
-	// so this statement may be unrequired
-	if (_offset == 0) {
-
-		// The new duration in frames 
+	//If the song is playing, sync the value with the time of the song.
+	if( engine::getSong()->isPlaying() || engine::getSong()->isExporting() )
+	{
+		// The new duration in frames
 		// (Samples/Second) / (periods/second) = (Samples/cycle)
 		float newDurationF =
-				engine::getMixer()->processingSampleRate() *
+				engine::mixer()->processingSampleRate() *
 				m_speedModel.value();
 
 		switch(m_multiplierModel.value() )
@@ -105,39 +104,17 @@ float LfoController::value( int _offset )
 			default:
 				break;
 		}
-		
+
 		m_phaseOffset = qRound(
-				m_phaseModel.value() * newDurationF / 360.0 );
+			m_phaseModel.value() * newDurationF / 360.0 );
+
+
 		int newDuration = static_cast<int>( newDurationF );
+		m_phaseCorrection = static_cast<int>(engine::getSong()->getTicks()*engine::framesPerTick())%newDuration
+								+ m_phaseOffset;
 
-		if (newDuration != m_duration) {
-			// frame offset
-			// (Samples - Samples) = Samples
-			float oldFramePhase = float(frame % m_duration);
-
-			// Phase between 0 and 1
-			// (Samples/Samples) = factor
-			float phase = oldFramePhase / m_duration;
-
-			// where we SHOULD be according to new frequency
-			// (factor*Samples) = Samples
-			int newFrameOffset = static_cast<int>( phase * newDuration );
-
-			// recalc
-			// (Samples - (Samples-Samples)) = Samples
-			
-			// Go back to beginning of last natural period
-			m_phaseCorrection = -(runningFrames()%newDuration);
-
-			// newFrameOffset has old phaseCorrection built-in
-			m_phaseCorrection += newFrameOffset;
-
-			// re-run the first calculation again
-			frame = runningFrames() + m_phaseCorrection;
-
-			m_duration = newDuration;
-			
-		}
+		// re-run the first calculation again
+		frame = m_phaseCorrection + _offset;
 	}
 
 	// speedModel  0..1   fast..slow  0ms..20000ms
@@ -146,7 +123,7 @@ float LfoController::value( int _offset )
 
 	//  frames / (20seconds of frames)
 	float sampleFrame = float( frame+m_phaseOffset ) / 
-		(engine::getMixer()->processingSampleRate() *  m_speedModel.value() );
+		(engine::mixer()->processingSampleRate() *  m_speedModel.value() );
 
 	switch(m_multiplierModel.value() )
 	{
@@ -164,7 +141,9 @@ float LfoController::value( int _offset )
 
 	// 44100 frames/sec
 	return m_baseModel.value() + ( m_amountModel.value() * 
-			m_sampleFunction(sampleFrame) 
+				( m_sampleFunction != NULL ?
+					m_sampleFunction(sampleFrame):
+					m_userDefSampleBuffer->userWaveSample(sampleFrame) )
 			/ 2.0f );
 }
 
@@ -196,6 +175,14 @@ void LfoController::updateSampleFunction()
 		case Oscillator::WhiteNoise:
 			m_sampleFunction = &Oscillator::noiseSample;
 			break;
+		case Oscillator::UserDefinedWave:
+			m_sampleFunction = NULL;
+			/*TODO: If C++11 is allowed, should change the type of
+			 m_sampleFunction be std::function<sample_t(const float)>
+			 and use the line below:
+			*/
+			//m_sampleFunction = &(m_userDefSampleBuffer->userWaveSample)
+			break;
 	}
 }
 
@@ -211,6 +198,7 @@ void LfoController::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	m_phaseModel.saveSettings( _doc, _this, "phase" );
 	m_waveModel.saveSettings( _doc, _this, "wave" );
 	m_multiplierModel.saveSettings( _doc, _this, "multiplier" );
+	_this.setAttribute( "userwavefile" , m_userDefSampleBuffer->audioFile() );
 }
 
 
@@ -225,6 +213,7 @@ void LfoController::loadSettings( const QDomElement & _this )
 	m_phaseModel.loadSettings( _this, "phase" );
 	m_waveModel.loadSettings( _this, "wave" );
 	m_multiplierModel.loadSettings( _this, "multiplier" );
+	m_userDefSampleBuffer->setAudioFile( _this.attribute("userwavefile" ) );
 
 	updateSampleFunction();
 }
