@@ -1,9 +1,9 @@
 /*
  * bb_track_container.cpp - model-component of BB-Editor
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@
 
 
 bbTrackContainer::bbTrackContainer() :
-	trackContainer(),
+	TrackContainer(),
 	m_bbComboBoxModel( this )
 {
 	connect( &m_bbComboBoxModel, SIGNAL( dataChanged() ),
@@ -54,20 +54,19 @@ bbTrackContainer::~bbTrackContainer()
 
 
 
-bool bbTrackContainer::play( midiTime _start, fpp_t _frames,
-							f_cnt_t _offset,
-							Sint16 _tco_num )
+bool bbTrackContainer::play( MidiTime _start, fpp_t _frames,
+								f_cnt_t _offset, int _tco_num )
 {
 	bool played_a_note = false;
 	if( lengthOfBB( _tco_num ) <= 0 )
 	{
-		return( false );
+		return false;
 	}
 
-	_start = _start % ( lengthOfBB( _tco_num ) * midiTime::ticksPerTact() );
+	_start = _start % ( lengthOfBB( _tco_num ) * MidiTime::ticksPerTact() );
 
-	trackList tl = tracks();
-	for( trackList::iterator it = tl.begin(); it != tl.end(); ++it )
+	TrackList tl = tracks();
+	for( TrackList::iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		if( ( *it )->play( _start, _frames, _offset, _tco_num ) )
 		{
@@ -75,7 +74,7 @@ bool bbTrackContainer::play( midiTime _start, fpp_t _frames,
 		}
 	}
 
-	return( played_a_note );
+	return played_a_note;
 }
 
 
@@ -83,6 +82,11 @@ bool bbTrackContainer::play( midiTime _start, fpp_t _frames,
 
 void bbTrackContainer::updateAfterTrackAdd()
 {
+	if( numOfBBs() == 0 && !engine::getSong()->isLoadingProject() )
+	{
+		engine::getSong()->addBBTrack();
+	}
+
 	// make sure, new track(s) have TCOs for every beat/bassline
 	for( int i = 0; i < qMax<int>( 1, numOfBBs() ); ++i )
 	{
@@ -95,16 +99,16 @@ void bbTrackContainer::updateAfterTrackAdd()
 
 tact_t bbTrackContainer::lengthOfBB( int _bb )
 {
-	midiTime max_length = midiTime::ticksPerTact();
+	MidiTime max_length = MidiTime::ticksPerTact();
 
-	const trackList & tl = tracks();
-	for( trackList::const_iterator it = tl.begin(); it != tl.end(); ++it )
+	const TrackList & tl = tracks();
+	for( TrackList::const_iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		max_length = qMax( max_length,
 					( *it )->getTCO( _bb )->length() );
 	}
 
-	return( max_length.nextFullTact() );
+	return max_length.nextFullTact();
 }
 
 
@@ -112,7 +116,7 @@ tact_t bbTrackContainer::lengthOfBB( int _bb )
 
 int bbTrackContainer::numOfBBs() const
 {
-	return( engine::getSong()->countTracks( track::BBTrack ) );
+	return engine::getSong()->countTracks( track::BBTrack );
 }
 
 
@@ -120,8 +124,8 @@ int bbTrackContainer::numOfBBs() const
 
 void bbTrackContainer::removeBB( int _bb )
 {
-	trackList tl = tracks();
-	for( trackList::iterator it = tl.begin(); it != tl.end(); ++it )
+	TrackList tl = tracks();
+	for( TrackList::iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		delete ( *it )->getTCO( _bb );
 		( *it )->removeTact( _bb * DefaultTicksPerTact );
@@ -137,8 +141,8 @@ void bbTrackContainer::removeBB( int _bb )
 
 void bbTrackContainer::swapBB( int _bb1, int _bb2 )
 {
-	trackList tl = tracks();
-	for( trackList::iterator it = tl.begin(); it != tl.end(); ++it )
+	TrackList tl = tracks();
+	for( TrackList::iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		( *it )->swapPositionOfTCOs( _bb1, _bb2 );
 	}
@@ -163,12 +167,12 @@ void bbTrackContainer::updateBBTrack( trackContentObject * _tco )
 
 void bbTrackContainer::fixIncorrectPositions()
 {
-	trackList tl = tracks();
-	for( trackList::iterator it = tl.begin(); it != tl.end(); ++it )
+	TrackList tl = tracks();
+	for( TrackList::iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		for( int i = 0; i < numOfBBs(); ++i )
 		{
-			( *it )->getTCO( i )->movePosition( midiTime( i, 0 ) );
+			( *it )->getTCO( i )->movePosition( MidiTime( i, 0 ) );
 		}
 	}
 }
@@ -178,27 +182,14 @@ void bbTrackContainer::fixIncorrectPositions()
 
 void bbTrackContainer::play()
 {
-	if( engine::getSong()->isPlaying() )
-	{
-		if( engine::getSong()->playMode() != song::Mode_PlayBB )
-		{
-			engine::getSong()->stop();
-			engine::getSong()->playBB();
-		}
-		else
-		{
-			engine::getSong()->pause();
-		}
-	}
-	else if( engine::getSong()->isPaused() )
-	{
-		engine::getSong()->resumeFromPause();
-	}
-	else
+	if( engine::getSong()->playMode() != song::Mode_PlayBB )
 	{
 		engine::getSong()->playBB();
 	}
-
+	else
+	{
+		engine::getSong()->togglePause();
+	}
 }
 
 
@@ -236,8 +227,8 @@ void bbTrackContainer::currentBBChanged()
 
 	// now update all track-labels (the current one has to become white,
 	// the others gray)
-	trackList tl = engine::getSong()->tracks();
-	for( trackList::iterator it = tl.begin(); it != tl.end(); ++it )
+	TrackList tl = engine::getSong()->tracks();
+	for( TrackList::iterator it = tl.begin(); it != tl.end(); ++it )
 	{
 		if( ( *it )->type() == track::BBTrack )
 		{
@@ -256,15 +247,15 @@ void bbTrackContainer::createTCOsForBB( int _bb )
 		return;
 	}
 
-	trackList tl = tracks();
+	TrackList tl = tracks();
 	for( int i = 0; i < tl.size(); ++i )
 	{
 		while( tl[i]->numOfTCOs() < _bb + 1 )
 		{
-			midiTime position = midiTime( tl[i]->numOfTCOs(), 0 );
+			MidiTime position = MidiTime( tl[i]->numOfTCOs(), 0 );
 			trackContentObject * tco = tl[i]->createTCO( position );
 			tco->movePosition( position );
-			tco->changeLength( midiTime( 1, 0 ) );
+			tco->changeLength( MidiTime( 1, 0 ) );
 		}
 	}
 }
