@@ -1,9 +1,10 @@
 /*
  * main.cpp - just main.cpp which is starting up app...
  *
- * Copyright (c) 2004-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2012-2013 Paul Giblock    <p/at/pgiblock.net>
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,6 +25,15 @@
 
 #include "lmmsconfig.h"
 #include "lmmsversion.h"
+#include "versioninfo.h"
+
+// denormals stripping
+#ifdef __SSE__
+#include <xmmintrin.h>
+#endif
+#ifdef __SSE3__
+#include <pmmintrin.h>
+#endif
 
 #include <QtCore/QDir>
 #include <QtCore/QFileInfo>
@@ -34,6 +44,7 @@
 #include <QtGui/QApplication>
 #include <QtGui/QBitmap>
 #include <QtGui/QDesktopWidget>
+#include <QtGui/QMessageBox>
 #include <QtGui/QPainter>
 #include <QtGui/QSplashScreen>
 
@@ -56,13 +67,14 @@
 #include "config_mgr.h"
 #include "embed.h"
 #include "engine.h"
-#include "lmms_style.h"
+#include "LmmsStyle.h"
 #include "ImportFilter.h"
 #include "MainWindow.h"
 #include "ProjectRenderer.h"
+#include "DataFile.h"
 #include "song.h"
+#include "LmmsPalette.h"
 
-#warning TODO: move somewhere else
 static inline QString baseName( const QString & _file )
 {
 	return( QFileInfo( _file ).absolutePath() + "/" +
@@ -88,10 +100,20 @@ int main( int argc, char * * argv )
 	// intialize RNG
 	srand( getpid() + time( 0 ) );
 
+	// set denormal protection for this thread
+	#ifdef __SSE3__
+	/* DAZ flag */
+	_MM_SET_DENORMALS_ZERO_MODE( _MM_DENORMALS_ZERO_ON );
+	#endif
+	#ifdef __SSE__
+	/* FTZ flag */
+	_MM_SET_FLUSH_ZERO_MODE( _MM_FLUSH_ZERO_ON );
+	#endif
+
 	bool core_only = false;
 	bool fullscreen = true;
 	bool exit_after_import = false;
-	QString file_to_load, file_to_save, file_to_import, render_out;
+	QString file_to_load, file_to_save, file_to_import, render_out, profilerOutputFile;
 
 	for( int i = 1; i < argc; ++i )
 	{
@@ -116,8 +138,7 @@ int main( int argc, char * * argv )
 			new QCoreApplication( argc, argv ) :
 					new QApplication( argc, argv ) ;
 
-
-	mixer::qualitySettings qs( mixer::qualitySettings::Mode_HighQuality );
+	Mixer::qualitySettings qs( Mixer::qualitySettings::Mode_HighQuality );
 	ProjectRenderer::OutputSettings os( 44100, false, 160,
 						ProjectRenderer::Depth_16Bit );
 	ProjectRenderer::ExportFileFormats eff = ProjectRenderer::WaveFile;
@@ -128,21 +149,23 @@ int main( int argc, char * * argv )
 		if( QString( argv[i] ) == "--version" ||
 						QString( argv[i] ) == "-v" )
 		{
-			printf( "\nLinux MultiMedia Studio %s\n\n"
-	"Copyright (c) 2004-2008 LMMS developers.\n\n"
+			printf( "LMMS %s\n(%s %s, Qt %s, %s)\n\n"
+	"Copyright (c) 2004-2014 LMMS developers.\n\n"
 	"This program is free software; you can redistribute it and/or\n"
 	"modify it under the terms of the GNU General Public\n"
 	"License as published by the Free Software Foundation; either\n"
 	"version 2 of the License, or (at your option) any later version.\n\n"
 	"Try \"%s --help\" for more information.\n\n", LMMS_VERSION,
-								argv[0] );
+				PLATFORM, MACHINE, QT_VERSION_STR, GCC_VERSION,
+				argv[0] );
+
 			return( EXIT_SUCCESS );
 		}
 		else if( argc > i && ( QString( argv[i] ) == "--help" ||
 						QString( argv[i] ) == "-h" ) )
 		{
-			printf( "\nLinux MultiMedia Studio %s\n"
-	"Copyright (c) 2004-2008 LMMS developers.\n\n"
+			printf( "LMMS %s\n"
+	"Copyright (c) 2004-2014 LMMS developers.\n\n"
 	"usage: lmms [ -r <project file> ] [ options ]\n"
 	"            [ -u <in> <out> ]\n"
 	"            [ -d <in> ]\n"
@@ -165,7 +188,8 @@ int main( int argc, char * * argv )
 	"-x, --oversampling <value>	specify oversampling\n"
 	"				possible values: 1, 2, 4, 8\n"
 	"				default: 2\n"
-	"-u, --upgrade <in> <out>	upgrade file <in> and save as <out>\n"
+	"-u, --upgrade <in> [out]	upgrade file <in> and save as <out>\n"
+	"       standard out is used if no output file is specifed\n"
 	"-d, --dump <in>			dump XML of compressed file <in>\n"
 	"-v, --version			show version information and exit.\n"
 	"-h, --help			show this usage information and exit.\n\n",
@@ -175,9 +199,20 @@ int main( int argc, char * * argv )
 		else if( argc > i+1 && ( QString( argv[i] ) == "--upgrade" ||
 						QString( argv[i] ) == "-u" ) )
 		{
-			file_to_load = argv[i + 1];
-			file_to_save = argv[i + 2];
-			i += 2;
+			QString inFile( argv[i + 1] );
+			DataFile dataFile( inFile );
+			if (argc > i+2)
+			{
+				const QString outFile = argv[i + 2];
+				dataFile.writeFile( outFile );
+			}
+			else
+			{
+				QTextStream ts( stdout );
+				dataFile.write( ts );
+				fflush( stdout );
+			}
+			return( EXIT_SUCCESS );
 		}
 		else if( argc > i && ( QString( argv[i] ) == "--dump" ||
 						QString( argv[i] ) == "-d" ) )
@@ -186,7 +221,7 @@ int main( int argc, char * * argv )
 			f.open( QIODevice::ReadOnly );
 			QString d = qUncompress( f.readAll() );
 			printf( "%s\n", d.toUtf8().constData() );
-			return( 0 );
+			return( EXIT_SUCCESS );
 		}
 		else if( argc > i && ( QString( argv[i] ) == "--render" ||
 						QString( argv[i] ) == "-r" ) )
@@ -265,19 +300,19 @@ int main( int argc, char * * argv )
 			const QString ip = QString( argv[i + 1] );
 			if( ip == "linear" )
 			{
-		qs.interpolation = mixer::qualitySettings::Interpolation_Linear;
+		qs.interpolation = Mixer::qualitySettings::Interpolation_Linear;
 			}
 			else if( ip == "sincfastest" )
 			{
-		qs.interpolation = mixer::qualitySettings::Interpolation_SincFastest;
+		qs.interpolation = Mixer::qualitySettings::Interpolation_SincFastest;
 			}
 			else if( ip == "sincmedium" )
 			{
-		qs.interpolation = mixer::qualitySettings::Interpolation_SincMedium;
+		qs.interpolation = Mixer::qualitySettings::Interpolation_SincMedium;
 			}
 			else if( ip == "sincbest" )
 			{
-		qs.interpolation = mixer::qualitySettings::Interpolation_SincBest;
+		qs.interpolation = Mixer::qualitySettings::Interpolation_SincBest;
 			}
 			else
 			{
@@ -295,16 +330,16 @@ int main( int argc, char * * argv )
 			switch( o )
 			{
 				case 1:
-		qs.oversampling = mixer::qualitySettings::Oversampling_None;
+		qs.oversampling = Mixer::qualitySettings::Oversampling_None;
 		break;
 				case 2:
-		qs.oversampling = mixer::qualitySettings::Oversampling_2x;
+		qs.oversampling = Mixer::qualitySettings::Oversampling_2x;
 		break;
 				case 4:
-		qs.oversampling = mixer::qualitySettings::Oversampling_4x;
+		qs.oversampling = Mixer::qualitySettings::Oversampling_4x;
 		break;
 				case 8:
-		qs.oversampling = mixer::qualitySettings::Oversampling_8x;
+		qs.oversampling = Mixer::qualitySettings::Oversampling_8x;
 		break;
 				default:
 				printf( "\nInvalid oversampling %s.\n\n"
@@ -324,6 +359,11 @@ int main( int argc, char * * argv )
 				exit_after_import = true;
 			}
 		}
+		else if( argc > i && ( QString( argv[i] ) == "--profile" || QString( argv[i] ) == "-p" ) )
+		{
+			profilerOutputFile = argv[i+1];
+			++i;
+		}
 		else
 		{
 			if( argv[i][0] == '-' )
@@ -370,46 +410,30 @@ int main( int argc, char * * argv )
 
 	configManager::inst()->loadConfigFile();
 
-	if( render_out.isEmpty() && file_to_save.isEmpty() )
+	if( render_out.isEmpty() )
 	{
 		// init style and palette
-		QApplication::setStyle( new lmmsStyle() );
+		LmmsStyle * lmmsstyle = new LmmsStyle();
+		QApplication::setStyle( lmmsstyle );
 
-		// init splash screen - this is a bit difficult as we have a
-		// semi-transparent splash-image therefore we first need to grab
-		// the screen, paint the splash onto it and then set a mask
-		// which covers all pixels which are not fully transparent in
-		// splash-image - otherwise we get nasty edges etc.
-		const QPixmap splash = embed::getIconPixmap( "splash" );
-    		const QPoint pt = QApplication::desktop()->
-#ifdef LMMS_BUILD_LINUX
-			availableGeometry().
-#else
-			screenGeometry().
-#endif
-					center() - splash.rect().center();
-		QPixmap pm = QPixmap::grabWindow(
-					QApplication::desktop()->winId(),
-					pt.x(), pt.y(),
-					splash.width(), splash.height() );
-		QPainter p( &pm );
-		p.drawPixmap( 0, 0, splash );
-		p.end();
+		LmmsPalette * lmmspal = new LmmsPalette( NULL, lmmsstyle );
+		QPalette lpal = lmmspal->palette();
 
-		QSplashScreen * ss = new QSplashScreen( pm );
-		ss->setAttribute( Qt::WA_PaintOnScreen, true );
-		ss->setMask( splash.alphaChannel().createMaskFromColor(
-							QColor( 0, 0, 0 ) ) );
-		if( !QProcess::systemEnvironment().contains( "NOSPLASH=1" ) )
-		{
-			ss->show();
-		}
+		QApplication::setPalette( lpal );
+		LmmsStyle::s_palette = &lpal;
+
+
+		// show splash screen
+		QSplashScreen splashScreen( embed::getIconPixmap( "splash" ) );
+		splashScreen.show();
+		splashScreen.showMessage( MainWindow::tr( "Version %1" ).arg( LMMS_VERSION ),
+									Qt::AlignRight | Qt::AlignBottom, Qt::white );
 		qApp->processEvents();
 
 		// init central engine which handles all components of LMMS
 		engine::init();
 
-		delete ss;
+		splashScreen.hide();
 
 		// re-intialize RNG - shared libraries might have srand() or
 		// srandom() calls in their init procedure
@@ -417,7 +441,11 @@ int main( int argc, char * * argv )
 
 		// recover a file?
 		QString recoveryFile = QDir(configManager::inst()->workingDir()).absoluteFilePath("recover.mmp");
-		if( QFileInfo(recoveryFile).exists() )
+		if( QFileInfo(recoveryFile).exists() &&
+			QMessageBox::question( engine::mainWindow(), MainWindow::tr( "Project recovery" ),
+						MainWindow::tr( "It looks like the last session did not end properly. "
+										"Do you want to recover the project of this session?" ),
+						QMessageBox::Yes | QMessageBox::No ) == QMessageBox::Yes )
 		{
 			file_to_load = recoveryFile;
 		}
@@ -430,7 +458,14 @@ int main( int argc, char * * argv )
 			{
 				engine::mainWindow()->showMaximized();
 			}
-			engine::getSong()->loadProject( file_to_load );
+			if( file_to_load == recoveryFile )
+			{
+				engine::getSong()->createNewProjectFromTemplate( file_to_load );
+			}
+			else
+			{
+				engine::getSong()->loadProject( file_to_load );
+			}
 		}
 		else if( !file_to_import.isEmpty() )
 		{
@@ -467,31 +502,28 @@ int main( int argc, char * * argv )
 		engine::getSong()->loadProject( file_to_load );
 		printf( "done\n" );
 
-		if( !render_out.isEmpty() )
-		{
-			// create renderer
-			ProjectRenderer * r = new ProjectRenderer( qs, os, eff,
-				render_out +
-					QString( ( eff ==
-						ProjectRenderer::WaveFile ) ?
-							"wav" : "ogg" ) );
-			QCoreApplication::instance()->connect( r,
-					SIGNAL( finished() ), SLOT( quit() ) );
+		// create renderer
+		ProjectRenderer * r = new ProjectRenderer( qs, os, eff,
+			render_out +
+				QString( ( eff ==
+					ProjectRenderer::WaveFile ) ?
+						"wav" : "ogg" ) );
+		QCoreApplication::instance()->connect( r,
+				SIGNAL( finished() ), SLOT( quit() ) );
 
-			// timer for progress-updates
-			QTimer * t = new QTimer( r );
-			r->connect( t, SIGNAL( timeout() ),
-					SLOT( updateConsoleProgress() ) );
-			t->start( 200 );
+		// timer for progress-updates
+		QTimer * t = new QTimer( r );
+		r->connect( t, SIGNAL( timeout() ),
+				SLOT( updateConsoleProgress() ) );
+		t->start( 200 );
 
-			// start now!
-			r->startProcessing();
-		}
-		else
+		if( profilerOutputFile.isEmpty() == false )
 		{
-			engine::getSong()->saveProjectFile( file_to_save );
-			return( 0 );
+			engine::mixer()->profiler().setOutputFile( profilerOutputFile );
 		}
+
+		// start now!
+		r->startProcessing();
 	}
 
 	const int ret = app->exec();
