@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail.com>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@
 
 #include "song.h"
 #include "engine.h"
-#include "mixer.h"
+#include "Mixer.h"
 #include "MidiClient.h"
 #include "MidiController.h"
 
@@ -38,7 +38,7 @@ MidiController::MidiController( Model * _parent ) :
 	Controller( Controller::MidiController, _parent, tr( "MIDI Controller" ) ),
 	MidiEventProcessor(),
 	m_midiPort( tr( "unnamed_midi_controller" ),
-			engine::getMixer()->midiClient(), this, this, MidiPort::Input ),
+			engine::mixer()->midiClient(), this, this, MidiPort::Input ),
 	m_lastValue( 0.0f )
 {
 	connect( &m_midiPort, SIGNAL( modeChanged() ),
@@ -73,22 +73,19 @@ void MidiController::updateName()
 
 
 
-void MidiController::processInEvent( const midiEvent & _me,
-						const midiTime & _time )
+void MidiController::processInEvent( const MidiEvent& event, const MidiTime& time, f_cnt_t offset )
 {
-	Uint8 controllerNum;
-	const Uint8 * bytes;
-	switch( _me.m_type )
+	unsigned char controllerNum;
+	switch( event.type() )
 	{
 		case MidiControlChange:
-			bytes = _me.m_data.m_bytes;
-			controllerNum = _me.m_data.m_bytes[0] & 0x7F;
+			controllerNum = event.controllerNumber();
 
 			if( m_midiPort.inputController() == controllerNum + 1 &&
-					( m_midiPort.inputChannel() == _me.m_channel + 1 ||
+					( m_midiPort.inputChannel() == event.channel() + 1 ||
 					  m_midiPort.inputChannel() == 0 ) )
 			{
-				Uint8 val = _me.m_data.m_bytes[2] & 0x7F;
+				unsigned char val = event.controllerValue();
 				m_lastValue = (float)( val ) / 127.0f;
 				emit valueChanged();
 			}
