@@ -1,9 +1,9 @@
 /*
  * note.cpp - implementation of class note
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -35,23 +35,21 @@
 
 
 
-note::note( const midiTime & _length, const midiTime & _pos,
+note::note( const MidiTime & _length, const MidiTime & _pos,
 		int _key, volume_t _volume, panning_t _panning,
 						DetuningHelper * _detuning ) :
 	m_selected( false ),
-	m_oldKey( tLimit( _key, 0, NumKeys ) ),
+	m_oldKey( qBound( 0, _key, NumKeys ) ),
 	m_oldPos( _pos ),
 	m_oldLength( _length ),
 	m_isPlaying( false ),
-	m_key( tLimit( _key, 0, NumKeys ) ),
-	m_volume( tLimit( _volume, MinVolume, MaxVolume ) ),
-	m_panning( tLimit( _panning, PanningLeft, PanningRight ) ),
+	m_key( qBound( 0, _key, NumKeys ) ),
+	m_volume( qBound( MinVolume, _volume, MaxVolume ) ),
+	m_panning( qBound( PanningLeft, _panning, PanningRight ) ),
 	m_length( _length ),
 	m_pos( _pos ),
 	m_detuning( NULL )
 {
-	//saveJournallingState( false );
-//	setJournalling( false );
 	if( _detuning )
 	{
 		m_detuning = sharedObject::ref( _detuning );
@@ -60,7 +58,6 @@ note::note( const midiTime & _length, const midiTime & _pos,
 	{
 		createDetuning();
 	}
-	//restoreJournallingState();
 }
 
 
@@ -84,10 +81,6 @@ note::note( const note & _note ) :
 	{
 		m_detuning = sharedObject::ref( _note.m_detuning );
 	}
-	else
-	{
-		createDetuning();
-	}
 }
 
 
@@ -104,18 +97,16 @@ note::~note()
 
 
 
-void note::setLength( const midiTime & _length )
+void note::setLength( const MidiTime & _length )
 {
-//	addJournalEntry( journalEntry( ChangeLength, m_length - _length ) );
 	m_length = _length;
 }
 
 
 
 
-void note::setPos( const midiTime & _pos )
+void note::setPos( const MidiTime & _pos )
 {
-//	addJournalEntry( journalEntry( ChangePosition, m_pos - _pos ) );
 	m_pos = _pos;
 }
 
@@ -124,35 +115,32 @@ void note::setPos( const midiTime & _pos )
 
 void note::setKey( const int _key )
 {
-	const int k = tLimit( _key, 0, NumKeys );
-//	addJournalEntry( journalEntry( ChangeKey, m_key - k ) );
+	const int k = qBound( 0, _key, NumKeys );
 	m_key = k;
 }
 
 
 
 
-void note::setVolume( const volume_t _volume )
+void note::setVolume( volume_t _volume )
 {
-	const volume_t v = tLimit( _volume, MinVolume, MaxVolume );
-//	addJournalEntry( journalEntry( ChangeVolume, (int) m_volume - v ) );
+	const volume_t v = qBound( MinVolume, _volume, MaxVolume );
 	m_volume = v;
 }
 
 
 
 
-void note::setPanning( const panning_t _panning )
+void note::setPanning( panning_t _panning )
 {
-	const panning_t p = tLimit( _panning, PanningLeft, PanningRight );
-//	addJournalEntry( journalEntry( ChangePanning, (int) m_panning - p ) );
+	const panning_t p = qBound( PanningLeft, _panning, PanningRight );
 	m_panning = p;
 }
 
 
 
 
-midiTime note::quantized( const midiTime & _m, const int _q_grid )
+MidiTime note::quantized( const MidiTime & _m, const int _q_grid )
 {
 	float p = ( (float) _m / _q_grid );
 	if( p - floorf( p ) < 0.5f )
@@ -192,7 +180,8 @@ void note::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	_this.setAttribute( "pan", m_panning );
 	_this.setAttribute( "len", m_length );
 	_this.setAttribute( "pos", m_pos );
-	if( m_length > 0 )
+
+	if( m_detuning && m_length )
 	{
 		m_detuning->saveSettings( _doc, _this );
 	}
@@ -203,15 +192,16 @@ void note::saveSettings( QDomDocument & _doc, QDomElement & _this )
 
 void note::loadSettings( const QDomElement & _this )
 {
-	const int old_key = _this.attribute( "tone" ).toInt() +
-			_this.attribute( "oct" ).toInt() * KeysPerOctave;
-	m_key = qMax( old_key, _this.attribute( "key" ).toInt() );
+	const int oldKey = _this.attribute( "tone" ).toInt() + _this.attribute( "oct" ).toInt() * KeysPerOctave;
+	m_key = qMax( oldKey, _this.attribute( "key" ).toInt() );
 	m_volume = _this.attribute( "vol" ).toInt();
 	m_panning = _this.attribute( "pan" ).toInt();
 	m_length = _this.attribute( "len" ).toInt();
 	m_pos = _this.attribute( "pos" ).toInt();
+
 	if( _this.hasChildNodes() )
 	{
+		createDetuning();
 		m_detuning->loadSettings( _this );
 	}
 }
@@ -219,48 +209,9 @@ void note::loadSettings( const QDomElement & _this )
 
 
 
-/*void note::undoStep( journalEntry & _je )
-{
-	saveJournallingState( false );
-	switch( static_cast<Actions>( _je.actionID() ) )
-	{
-		case ChangeKey:
-			setKey( key() - _je.data().toInt() );
-			break;
-
-		case ChangeVolume:
-			setVolume( getVolume() - _je.data().toInt() );
-			break;
-
-		case ChangePanning:
-			setPanning( getPanning() - _je.data().toInt() );
-			break;
-
-		case ChangeLength:
-			setLength( length() - _je.data().toInt() );
-			break;
-
-		case ChangePosition:
-			setPos( pos() - _je.data().toInt() );
-			break;
-	}
-	restoreJournallingState();
-}
-
-
-
-
-void note::redoStep( journalEntry & _je )
-{
-	journalEntry je( _je.actionID(), -_je.data().toInt() );
-	undoStep( je );
-}*/
-
-
-
-
 void note::editDetuningPattern()
 {
+	createDetuning();
 	m_detuning->automationPattern()->openInAutomationEditor();
 }
 
@@ -269,9 +220,13 @@ void note::editDetuningPattern()
 
 void note::createDetuning()
 {
-	m_detuning = new DetuningHelper;
-	(void) m_detuning->automationPattern();
-	m_detuning->setRange( -MaxDetuning, MaxDetuning, 0.1f );
+	if( m_detuning == NULL )
+	{
+		m_detuning = new DetuningHelper;
+		(void) m_detuning->automationPattern();
+		m_detuning->setRange( -MaxDetuning, MaxDetuning, 0.5f );
+		m_detuning->automationPattern()->setProgressionType( AutomationPattern::LinearProgression );
+	}
 }
 
 
