@@ -1,9 +1,9 @@
 /*
  * song.cpp - root of the model tree
  *
- * Copyright (c) 2004-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,8 +25,8 @@
 #include <QtCore/QCoreApplication>
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
-#include <QtGui/QFileDialog>
 #include <QtGui/QMessageBox>
+#include <QApplication>
 
 #include <math.h>
 
@@ -47,26 +47,29 @@
 #include "ImportFilter.h"
 #include "InstrumentTrack.h"
 #include "MainWindow.h"
+#include "FileDialog.h"
 #include "MidiClient.h"
-#include "mmp.h"
-#include "note_play_handle.h"
-#include "pattern.h"
-#include "piano_roll.h"
+#include "DataFile.h"
+#include "NotePlayHandle.h"
+#include "Pattern.h"
+#include "PianoRoll.h"
 #include "ProjectJournal.h"
 #include "project_notes.h"
 #include "ProjectRenderer.h"
 #include "rename_dialog.h"
-#include "song_editor.h"
+#include "SongEditor.h"
 #include "templates.h"
 #include "text_float.h"
 #include "timeline.h"
+#include "PeakController.h"
 
-tick_t midiTime::s_ticksPerTact = DefaultTicksPerTact;
+
+tick_t MidiTime::s_ticksPerTact = DefaultTicksPerTact;
 
 
 
 song::song() :
-	trackContainer(),
+	TrackContainer(),
 	m_globalAutomationTrack( dynamic_cast<AutomationTrack *>(
 				track::create( track::HiddenAutomationTrack,
 								this ) ) ),
@@ -84,11 +87,14 @@ song::song() :
 	m_playing( false ),
 	m_paused( false ),
 	m_loadingProject( false ),
-	m_playMode( Mode_PlaySong ),
+	m_playMode( Mode_None ),
 	m_length( 0 ),
 	m_trackToPlay( NULL ),
 	m_patternToPlay( NULL ),
-	m_loopPattern( false )
+	m_loopPattern( false ),
+	m_elapsedMilliSeconds( 0 ),
+	m_elapsedTicks( 0 ),
+	m_elapsedTacts( 0 )
 {
 	connect( &m_tempoModel, SIGNAL( dataChanged() ),
 						this, SLOT( setTempo() ) );
@@ -98,17 +104,15 @@ song::song() :
 					this, SLOT( setTimeSignature() ) );
 
 
-	connect( engine::getMixer(), SIGNAL( sampleRateChanged() ), this,
+	connect( engine::mixer(), SIGNAL( sampleRateChanged() ), this,
 						SLOT( updateFramesPerTick() ) );
 
-
 	connect( &m_masterVolumeModel, SIGNAL( dataChanged() ),
 			this, SLOT( masterVolumeChanged() ) );
 /*	connect( &m_masterPitchModel, SIGNAL( dataChanged() ),
 			this, SLOT( masterPitchChanged() ) );*/
 
 	qRegisterMetaType<note>( "note" );
-
 }
 
 
@@ -125,7 +129,7 @@ song::~song()
 
 void song::masterVolumeChanged()
 {
-	engine::getMixer()->setMasterGain( m_masterVolumeModel.value() /
+	engine::mixer()->setMasterGain( m_masterVolumeModel.value() /
 								100.0f );
 }
 
@@ -135,21 +139,23 @@ void song::masterVolumeChanged()
 void song::setTempo()
 {
 	const bpm_t tempo = (bpm_t) m_tempoModel.value();
-	engine::getMixer()->lock();
-	PlayHandleList & playHandles = engine::getMixer()->playHandles();
+	engine::mixer()->lock();
+	PlayHandleList & playHandles = engine::mixer()->playHandles();
 	for( PlayHandleList::Iterator it = playHandles.begin();
 						it != playHandles.end(); ++it )
 	{
-		notePlayHandle * nph = dynamic_cast<notePlayHandle *>( *it );
-		if( nph && !nph->released() )
+		NotePlayHandle * nph = dynamic_cast<NotePlayHandle *>( *it );
+		if( nph && !nph->isReleased() )
 		{
 			nph->resize( tempo );
 		}
 	}
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 
 	engine::updateFramesPerTick();
 
+	m_vstSyncController.setTempo( tempo );
+
 	emit tempoChanged( tempo );
 }
 
@@ -158,124 +164,25 @@ void song::setTempo()
 
 void song::setTimeSignature()
 {
-	midiTime::setTicksPerTact( ticksPerTact() );
+	MidiTime::setTicksPerTact( ticksPerTact() );
 	emit timeSignatureChanged( m_oldTicksPerTact, ticksPerTact() );
 	emit dataChanged();
 	m_oldTicksPerTact = ticksPerTact();
+
+	m_vstSyncController.setTimeSignature( getTimeSigModel().getNumerator(), getTimeSigModel().getDenominator() );
 }
 
 
 
 
-void song::doActions()
+void song::savePos()
 {
-	while( !m_actions.empty() )
+	timeLine * tl = m_playPos[m_playMode].m_timeLine;
+
+	if( tl != NULL )
 	{
-		switch( m_actions.front() )
-		{
-			case ActionStop:
-			{
-				timeLine * tl =
-					m_playPos[m_playMode].m_timeLine;
-				m_playing = false;
-				m_recording = true;
-				if( tl != NULL )
-				{
-
-		switch( tl->behaviourAtStop() )
-		{
-			case timeLine::BackToZero:
-				m_playPos[m_playMode].setTicks( 0 );
-				break;
-
-			case timeLine::BackToStart:
-				if( tl->savedPos() >= 0 )
-				{
-					m_playPos[m_playMode].setTicks(
-						tl->savedPos().getTicks() );
-					tl->savePos( -1 );
-				}
-				break;
-
-			case timeLine::KeepStopPosition:
-			default:
-				break;
-		}
-
-				}
-				else
-				{
-					m_playPos[m_playMode].setTicks( 0 );
-				}
-
-				m_playPos[m_playMode].setCurrentFrame( 0 );
-
-				// remove all note-play-handles that are active
-				engine::getMixer()->clear();
-
-				break;
-			}
-
-			case ActionPlaySong:
-				m_playMode = Mode_PlaySong;
-				m_playing = true;
-				Controller::resetFrameCounter();
-				break;
-
-			case ActionPlayTrack:
-				m_playMode = Mode_PlayTrack;
-				m_playing = true;
-				break;
-
-			case ActionPlayBB:
-				m_playMode = Mode_PlayBB;
-				m_playing = true;
-				break;
-
-			case ActionPlayPattern:
-				m_playMode = Mode_PlayPattern;
-				m_playing = true;
-				break;
-
-			case ActionPause:
-				m_playing = false;// just set the play-flag
-				m_paused = true;
-				break;
-
-			case ActionResumeFromPause:
-				m_playing = true;// just set the play-flag
-				m_paused = false;
-				break;
-		}
-
-		// a second switch for saving pos when starting to play
-		// anything (need pos for restoring it later in certain
-		// timeline-modes)
-		switch( m_actions.front() )
-		{
-			case ActionPlaySong:
-			case ActionPlayTrack:
-			case ActionPlayBB:
-			case ActionPlayPattern:
-			{
-				timeLine * tl =
-					m_playPos[m_playMode].m_timeLine;
-				if( tl != NULL )
-				{
-					tl->savePos( m_playPos[m_playMode] );
-				}
-				break;
-			}
-
-			// keep GCC happy...
-			default:
-				break;
-		}
-
-		m_actions.erase( m_actions.begin() );
-
+		tl->savePos( m_playPos[m_playMode] );
 	}
-
 }
 
 
@@ -283,14 +190,12 @@ void song::doActions()
 
 void song::processNextBuffer()
 {
-	doActions();
-
 	if( m_playing == false )
 	{
 		return;
 	}
 
-	trackList track_list;
+	TrackList track_list;
 	int tco_num = -1;
 
 	switch( m_playMode )
@@ -341,14 +246,13 @@ void song::processNextBuffer()
 	// check for looping-mode and act if necessary
 	timeLine * tl = m_playPos[m_playMode].m_timeLine;
 	bool check_loop = tl != NULL && m_exporting == false &&
-				tl->loopPointsEnabled() &&
-				!( m_playMode == Mode_PlayPattern &&
-					m_patternToPlay->isFreezing() == true );
+				tl->loopPointsEnabled();
 	if( check_loop )
 	{
 		if( m_playPos[m_playMode] < tl->loopBegin() ||
 					m_playPos[m_playMode] >= tl->loopEnd() )
 		{
+			m_elapsedMilliSeconds = (tl->loopBegin().getTicks()*60*1000/48)/getTempo();
 			m_playPos[m_playMode].setTicks(
 						tl->loopBegin().getTicks() );
 		}
@@ -358,19 +262,22 @@ void song::processNextBuffer()
 	const float frames_per_tick = engine::framesPerTick();
 
 	while( total_frames_played
-				< engine::getMixer()->framesPerPeriod() )
+				< engine::mixer()->framesPerPeriod() )
 	{
-		f_cnt_t played_frames = engine::getMixer()
-				->framesPerPeriod() - total_frames_played;
+		m_vstSyncController.update();
+
+		f_cnt_t played_frames = engine::mixer()->framesPerPeriod() - total_frames_played;
 
 		float current_frame = m_playPos[m_playMode].currentFrame();
 		// did we play a tick?
 		if( current_frame >= frames_per_tick )
 		{
-			int ticks = m_playPos[m_playMode].getTicks()
-				+ (int)( current_frame / frames_per_tick );
+			int ticks = m_playPos[m_playMode].getTicks() + (int)( current_frame / frames_per_tick );
+
+			m_vstSyncController.setAbsolutePosition( ticks );
+
 			// did we play a whole tact?
-			if( ticks >= midiTime::ticksPerTact() )
+			if( ticks >= MidiTime::ticksPerTact() )
 			{
 				// per default we just continue playing even if
 				// there's no more stuff to play
@@ -400,20 +307,30 @@ void song::processNextBuffer()
 				{
 					// then start from beginning and keep
 					// offset
-					ticks = ticks % ( max_tact *
-						midiTime::ticksPerTact() );
+					ticks = ticks % ( max_tact * MidiTime::ticksPerTact() );
+
+					// wrap milli second counter
+					m_elapsedMilliSeconds = ( ticks * 60 * 1000 / 48 ) / getTempo();
+
+					m_vstSyncController.setAbsolutePosition( ticks );
 				}
 			}
 			m_playPos[m_playMode].setTicks( ticks );
 
 			if( check_loop )
 			{
+				m_vstSyncController.startCycle( tl->loopBegin().getTicks(), tl->loopEnd().getTicks() );
+
 				if( m_playPos[m_playMode] >= tl->loopEnd() )
 				{
-					m_playPos[m_playMode].setTicks(
-						tl->loopBegin().getTicks() );
+					m_playPos[m_playMode].setTicks( tl->loopBegin().getTicks() );
+					m_elapsedMilliSeconds = ((tl->loopBegin().getTicks())*60*1000/48)/getTempo();
 				}
 			}
+			else
+			{
+				m_vstSyncController.stopCycle();
+			}
 
 			current_frame = fmodf( current_frame, frames_per_tick );
 			m_playPos[m_playMode].setCurrentFrame( current_frame );
@@ -461,51 +378,33 @@ void song::processNextBuffer()
 		total_frames_played += played_frames;
 		m_playPos[m_playMode].setCurrentFrame( played_frames +
 								current_frame );
+		m_elapsedMilliSeconds += (((played_frames/frames_per_tick)*60*1000/48)/getTempo());
+		m_elapsedTacts = m_playPos[Mode_PlaySong].getTact();
+		m_elapsedTicks = (m_playPos[Mode_PlaySong].getTicks()%ticksPerTact())/48;
 	}
 }
 
 
 
 
-bool song::isFreezingPattern() const
-{
-	return isPlaying() &&
-				m_playMode == Mode_PlayPattern &&
-				m_patternToPlay != NULL &&
-				m_patternToPlay->isFreezing();
-}
-
-
-
-
-bool song::realTimeTask() const
-{
-	return !( m_exporting == true || ( m_playMode == Mode_PlayPattern &&
-		  	m_patternToPlay != NULL &&
-			m_patternToPlay->isFreezing() == true ) );
-}
-
-
-
-
-void song::play()
+void song::playSong()
 {
 	m_recording = false;
-	if( m_playing == true )
+
+	if( isStopped() == false )
 	{
-		if( m_playMode != Mode_PlaySong )
-		{
-			// make sure, bb-editor updates/resets it play-button
-			engine::getBBTrackContainer()->stop();
-			//pianoRoll::inst()->stop();
-		}
-		else
-		{
-			pause();
-			return;
-		}
+		stop();
 	}
-	m_actions.push_back( ActionPlaySong );
+
+	m_playMode = Mode_PlaySong;
+	m_playing = true;
+	m_paused = false;
+
+	m_vstSyncController.setPlaybackState( true );
+
+	savePos();
+
+	emit playbackStateChanged();
 }
 
 
@@ -522,7 +421,7 @@ void song::record()
 
 void song::playAndRecord()
 {
-	play();
+	playSong();
 	m_recording = true;
 }
 
@@ -531,13 +430,21 @@ void song::playAndRecord()
 
 void song::playTrack( track * _trackToPlay )
 {
-	if( m_playing == true )
+	if( isStopped() == false )
 	{
 		stop();
 	}
 	m_trackToPlay = _trackToPlay;
 
-	m_actions.push_back( ActionPlayTrack );
+	m_playMode = Mode_PlayTrack;
+	m_playing = true;
+	m_paused = false;
+
+	m_vstSyncController.setPlaybackState( true );
+
+	savePos();
+
+	emit playbackStateChanged();
 }
 
 
@@ -545,28 +452,45 @@ void song::playTrack( track * _trackToPlay )
 
 void song::playBB()
 {
-	if( m_playing == true )
+	if( isStopped() == false )
 	{
 		stop();
 	}
-	m_actions.push_back( ActionPlayBB );
+
+	m_playMode = Mode_PlayBB;
+	m_playing = true;
+	m_paused = false;
+
+	m_vstSyncController.setPlaybackState( true );
+
+	savePos();
+
+	emit playbackStateChanged();
 }
 
 
 
 
-void song::playPattern( pattern * _patternToPlay, bool _loop )
+void song::playPattern( Pattern* patternToPlay, bool _loop )
 {
-	if( m_playing == true )
+	if( isStopped() == false )
 	{
 		stop();
 	}
-	m_patternToPlay = _patternToPlay;
+
+	m_patternToPlay = patternToPlay;
 	m_loopPattern = _loop;
+
 	if( m_patternToPlay != NULL )
 	{
-		m_actions.push_back( ActionPlayPattern );
+		m_playMode = Mode_PlayPattern;
+		m_playing = true;
+		m_paused = false;
 	}
+
+	savePos();
+
+	emit playbackStateChanged();
 }
 
 
@@ -576,7 +500,7 @@ void song::updateLength()
 {
 	m_length = 0;
 	m_tracksMutex.lockForRead();
-	for( trackList::const_iterator it = tracks().begin();
+	for( TrackList::const_iterator it = tracks().begin();
 						it != tracks().end(); ++it )
 	{
 		const tact_t cur = ( *it )->length();
@@ -595,6 +519,8 @@ void song::updateLength()
 
 void song::setPlayPos( tick_t _ticks, PlayModes _play_mode )
 {
+	m_elapsedTicks += m_playPos[_play_mode].getTicks() - _ticks;
+	m_elapsedMilliSeconds += (((( _ticks - m_playPos[_play_mode].getTicks()))*60*1000/48)/getTempo());
 	m_playPos[_play_mode].setTicks( _ticks );
 	m_playPos[_play_mode].setCurrentFrame( 0.0f );
 }
@@ -602,27 +528,81 @@ void song::setPlayPos( tick_t _ticks, PlayModes _play_mode )
 
 
 
+void song::togglePause()
+{
+	if( m_paused == true )
+	{
+		m_playing = true;
+		m_paused = false;
+	}
+	else
+	{
+		m_playing = false;
+		m_paused = true;
+	}
+
+	m_vstSyncController.setPlaybackState( m_playing );
+
+	emit playbackStateChanged();
+}
+
+
+
+
 void song::stop()
 {
-	m_actions.push_back( ActionStop );
-}
+	// do not stop/reset things again if we're stopped already
+	if( m_playMode == Mode_None )
+	{
+		return;
+	}
 
+	timeLine * tl = m_playPos[m_playMode].m_timeLine;
+	m_playing = false;
+	m_paused = false;
+	m_recording = true;
 
+	if( tl != NULL )
+	{
 
+		switch( tl->behaviourAtStop() )
+		{
+			case timeLine::BackToZero:
+				m_playPos[m_playMode].setTicks( 0 );
+				m_elapsedMilliSeconds = 0;
+				break;
 
+			case timeLine::BackToStart:
+				if( tl->savedPos() >= 0 )
+				{
+					m_playPos[m_playMode].setTicks( tl->savedPos().getTicks() );
+					m_elapsedMilliSeconds = (((tl->savedPos().getTicks())*60*1000/48)/getTempo());
+					tl->savePos( -1 );
+				}
+				break;
 
+			case timeLine::KeepStopPosition:
+			default:
+				break;
+		}
+	}
+	else
+	{
+		m_playPos[m_playMode].setTicks( 0 );
+		m_elapsedMilliSeconds = 0;
+	}
 
-void song::pause()
-{
-	m_actions.push_back( ActionPause );
-}
+	m_playPos[m_playMode].setCurrentFrame( 0 );
 
+	m_vstSyncController.setPlaybackState( m_exporting );
+	m_vstSyncController.setAbsolutePosition( m_playPos[m_playMode].getTicks() );
 
+	// remove all note-play-handles that are active
+	engine::mixer()->clear();
 
+	m_playMode = Mode_None;
 
-void song::resumeFromPause()
-{
-	m_actions.push_back( ActionResumeFromPause );
+	emit playbackStateChanged();
 }
 
 
@@ -631,12 +611,12 @@ void song::resumeFromPause()
 void song::startExport()
 {
 	stop();
-	doActions();
 
-	play();
-	doActions();
+	playSong();
 
 	m_exporting = true;
+
+	m_vstSyncController.setPlaybackState( true );
 }
 
 
@@ -647,6 +627,8 @@ void song::stopExport()
 	stop();
 	m_exporting = false;
 	m_exportLoop = false;
+
+	m_vstSyncController.setPlaybackState( m_playing );
 }
 
 
@@ -655,7 +637,7 @@ void song::stopExport()
 void song::insertBar()
 {
 	m_tracksMutex.lockForRead();
-	for( trackList::const_iterator it = tracks().begin();
+	for( TrackList::const_iterator it = tracks().begin();
 					it != tracks().end(); ++it )
 	{
 		( *it )->insertTact( m_playPos[Mode_PlaySong] );
@@ -669,7 +651,7 @@ void song::insertBar()
 void song::removeBar()
 {
 	m_tracksMutex.lockForRead();
-	for( trackList::const_iterator it = tracks().begin();
+	for( TrackList::const_iterator it = tracks().begin();
 					it != tracks().end(); ++it )
 	{
 		( *it )->removeTact( m_playPos[Mode_PlaySong] );
@@ -682,11 +664,10 @@ void song::removeBar()
 
 void song::addBBTrack()
 {
-	engine::getMixer()->lock();
+	engine::mixer()->lock();
 	track * t = track::create( track::BBTrack, this );
-	engine::getBBTrackContainer()->setCurrentBB(
-						bbTrack::numOfBBTrack( t ) );
-	engine::getMixer()->unlock();
+	engine::getBBTrackContainer()->setCurrentBB( dynamic_cast<bbTrack *>( t )->index() );
+	engine::mixer()->unlock();
 }
 
 
@@ -694,9 +675,9 @@ void song::addBBTrack()
 
 void song::addSampleTrack()
 {
-	engine::getMixer()->lock();
+	engine::mixer()->lock();
 	(void) track::create( track::SampleTrack, this );
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 }
 
 
@@ -704,9 +685,9 @@ void song::addSampleTrack()
 
 void song::addAutomationTrack()
 {
-	engine::getMixer()->lock();
+	engine::mixer()->lock();
 	(void) track::create( track::AutomationTrack, this );
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 }
 
 
@@ -737,14 +718,20 @@ void song::clearProject()
 		stop();
 	}
 
-	engine::getMixer()->lock();
+	for( int i = 0; i < Mode_Count; i++ )
+	{
+		setPlayPos( 0, ( PlayModes )i );
+	}
+
+
+	engine::mixer()->lock();
 	if( engine::getBBEditor() )
 	{
 		engine::getBBEditor()->clearAllTracks();
 	}
-	if( engine::getSongEditor() )
+	if( engine::songEditor() )
 	{
-		engine::getSongEditor()->clearAllTracks();
+		engine::songEditor()->clearAllTracks();
 	}
 	if( engine::fxMixerView() )
 	{
@@ -761,6 +748,11 @@ void song::clearProject()
 		engine::automationEditor()->setCurrentPattern( NULL );
 	}
 
+	if( engine::pianoRoll() )
+	{
+		engine::pianoRoll()->reset();
+	}
+
 	m_tempoModel.reset();
 	m_masterVolumeModel.reset();
 	m_masterPitchModel.reset();
@@ -772,7 +764,7 @@ void song::clearProject()
 	AutomationPattern::globalAutomationPattern( &m_masterPitchModel )->
 									clear();
 
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 
 	if( engine::getProjectNotes() )
 	{
@@ -790,6 +782,8 @@ void song::clearProject()
 	engine::projectJournal()->clearJournal();
 
 	engine::projectJournal()->setJournalling( true );
+
+	InstrumentTrackView::cleanupWindowCache();
 }
 
 
@@ -801,6 +795,7 @@ void song::createNewProject()
 {
 	QString default_template = configManager::inst()->userProjectsDir()
 						+ "templates/default.mpt";
+
 	if( QFile::exists( default_template ) )
 	{
 		createNewProjectFromTemplate( default_template );
@@ -830,7 +825,7 @@ void song::createNewProject()
 	t = track::create( track::InstrumentTrack,
 						engine::getBBTrackContainer() );
 	dynamic_cast<InstrumentTrack * >( t )->loadInstrument(
-						"tripleoscillator" );
+						"kicker" );
 	track::create( track::SampleTrack, this );
 	track::create( track::BBTrack, this );
 	track::create( track::AutomationTrack, this );
@@ -881,6 +876,8 @@ void song::createNewProjectFromTemplate( const QString & _template )
 // load given song
 void song::loadProject( const QString & _file_name )
 {
+	QDomNode node;
+
 	m_loadingProject = true;
 
 	clearProject();
@@ -890,22 +887,24 @@ void song::loadProject( const QString & _file_name )
 	m_fileName = _file_name;
 	m_oldFileName = _file_name;
 
-	multimediaProject mmp( m_fileName );
+	DataFile dataFile( m_fileName );
 	// if file could not be opened, head-node is null and we create
 	// new project
-	if( mmp.head().isNull() )
+	if( dataFile.head().isNull() )
 	{
 		createNewProject();
 		return;
 	}
 
-	engine::getMixer()->lock();
+	DataFile::LocaleHelper localeHelper( DataFile::LocaleHelper::ModeLoad );
+
+	engine::mixer()->lock();
 
 	// get the header information from the DOM
-	m_tempoModel.loadSettings( mmp.head(), "bpm" );
-	m_timeSigModel.loadSettings( mmp.head(), "timesig" );
-	m_masterVolumeModel.loadSettings( mmp.head(), "mastervol" );
-	m_masterPitchModel.loadSettings( mmp.head(), "masterpitch" );
+	m_tempoModel.loadSettings( dataFile.head(), "bpm" );
+	m_timeSigModel.loadSettings( dataFile.head(), "timesig" );
+	m_masterVolumeModel.loadSettings( dataFile.head(), "mastervol" );
+	m_masterPitchModel.loadSettings( dataFile.head(), "masterpitch" );
 
 	if( m_playPos[Mode_PlaySong].m_timeLine )
 	{
@@ -913,64 +912,61 @@ void song::loadProject( const QString & _file_name )
 		m_playPos[Mode_PlaySong].m_timeLine->toggleLoopPoints( 0 );
 	}
 
-	if( !mmp.content().firstChildElement( "track" ).isNull() )
+	if( !dataFile.content().firstChildElement( "track" ).isNull() )
 	{
-		m_globalAutomationTrack->restoreState( mmp.content().
+		m_globalAutomationTrack->restoreState( dataFile.content().
 						firstChildElement( "track" ) );
 	}
-	QDomNode node = mmp.content().firstChild();
+
+	//Backward compatibility for LMMS <= 0.4.15
+	PeakController::initGetControllerBySetting();
+
+	// Load mixer first to be able to set the correct range for FX channels
+	node = dataFile.content().firstChildElement( engine::fxMixer()->nodeName() );
+	if( !node.isNull() )
+	{
+		engine::fxMixer()->restoreState( node.toElement() );
+		if( engine::hasGUI() )
+		{
+			// refresh FxMixerView
+			engine::fxMixerView()->refreshDisplay();
+		}
+	}
+
+	node = dataFile.content().firstChild();
 	while( !node.isNull() )
 	{
 		if( node.isElement() )
 		{
 			if( node.nodeName() == "trackcontainer" )
 			{
-				( (JournallingObject *)( this ) )->
-					restoreState( node.toElement() );
+				( (JournallingObject *)( this ) )->restoreState( node.toElement() );
 			}
 			else if( node.nodeName() == "controllers" )
 			{
 				restoreControllerStates( node.toElement() );
 			}
-			else if( node.nodeName() == engine::fxMixer()->nodeName() )
-			{
-				engine::fxMixer()->restoreState( node.toElement() );
-			}
 			else if( engine::hasGUI() )
 			{
-				if( node.nodeName() ==
-					engine::getControllerRackView()->nodeName() )
+				if( node.nodeName() == engine::getControllerRackView()->nodeName() )
 				{
-					engine::getControllerRackView()->
-						restoreState( node.toElement() );
+					engine::getControllerRackView()->restoreState( node.toElement() );
 				}
-				else if( node.nodeName() ==
-					engine::getPianoRoll()->nodeName() )
+				else if( node.nodeName() == engine::pianoRoll()->nodeName() )
 				{
-					engine::getPianoRoll()->restoreState(
-							node.toElement() );
+					engine::pianoRoll()->restoreState( node.toElement() );
 				}
-				else if( node.nodeName() ==
-					engine::automationEditor()->
-								nodeName() )
+				else if( node.nodeName() == engine::automationEditor()->nodeName() )
 				{
-					engine::automationEditor()->
-						restoreState( node.toElement() );
+					engine::automationEditor()->restoreState( node.toElement() );
 				}
-				else if( node.nodeName() ==
-						engine::getProjectNotes()->
-								nodeName() )
+				else if( node.nodeName() == engine::getProjectNotes()->nodeName() )
 				{
-					 engine::getProjectNotes()->
-			SerializingObject::restoreState( node.toElement() );
+					 engine::getProjectNotes()->SerializingObject::restoreState( node.toElement() );
 				}
-				else if( node.nodeName() ==
-						m_playPos[Mode_PlaySong].
-							m_timeLine->nodeName() )
+				else if( node.nodeName() == m_playPos[Mode_PlaySong].m_timeLine->nodeName() )
 				{
-					m_playPos[Mode_PlaySong].
-						m_timeLine->restoreState(
-							node.toElement() );
+					m_playPos[Mode_PlaySong].m_timeLine->restoreState( node.toElement() );
 				}
 			}
 		}
@@ -989,7 +985,7 @@ void song::loadProject( const QString & _file_name )
 	AutomationPattern::resolveAllIDs();
 
 
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 
 	configManager::inst()->addRecentlyOpenedProject( _file_name );
 
@@ -1010,31 +1006,31 @@ void song::loadProject( const QString & _file_name )
 // only save current song as _filename and do nothing else
 bool song::saveProjectFile( const QString & _filename )
 {
-	multimediaProject mmp( multimediaProject::SongProject );
+	DataFile::LocaleHelper localeHelper( DataFile::LocaleHelper::ModeSave );
 
-	m_tempoModel.saveSettings( mmp, mmp.head(), "bpm" );
-	m_timeSigModel.saveSettings( mmp, mmp.head(), "timesig" );
-	m_masterVolumeModel.saveSettings( mmp, mmp.head(), "mastervol" );
-	m_masterPitchModel.saveSettings( mmp, mmp.head(), "masterpitch" );
+	DataFile dataFile( DataFile::SongProject );
 
-	saveState( mmp, mmp.content() );
+	m_tempoModel.saveSettings( dataFile, dataFile.head(), "bpm" );
+	m_timeSigModel.saveSettings( dataFile, dataFile.head(), "timesig" );
+	m_masterVolumeModel.saveSettings( dataFile, dataFile.head(), "mastervol" );
+	m_masterPitchModel.saveSettings( dataFile, dataFile.head(), "masterpitch" );
 
-	m_globalAutomationTrack->saveState( mmp, mmp.content() );
-	engine::fxMixer()->saveState( mmp, mmp.content() );
+	saveState( dataFile, dataFile.content() );
+
+	m_globalAutomationTrack->saveState( dataFile, dataFile.content() );
+	engine::fxMixer()->saveState( dataFile, dataFile.content() );
 	if( engine::hasGUI() )
 	{
-		engine::getControllerRackView()->saveState( mmp, mmp.content() );
-		engine::getPianoRoll()->saveState( mmp, mmp.content() );
-		engine::automationEditor()->saveState( mmp, mmp.content() );
-		engine::getProjectNotes()->
-			SerializingObject::saveState( mmp, mmp.content() );
-		m_playPos[Mode_PlaySong].m_timeLine->saveState(
-							mmp, mmp.content() );
+		engine::getControllerRackView()->saveState( dataFile, dataFile.content() );
+		engine::pianoRoll()->saveState( dataFile, dataFile.content() );
+		engine::automationEditor()->saveState( dataFile, dataFile.content() );
+		engine::getProjectNotes()->SerializingObject::saveState( dataFile, dataFile.content() );
+		m_playPos[Mode_PlaySong].m_timeLine->saveState( dataFile, dataFile.content() );
 	}
 
-	saveControllerStates( mmp, mmp.content() );
+	saveControllerStates( dataFile, dataFile.content() );
 
-    return mmp.writeFile( _filename );
+	return dataFile.writeFile( _filename );
 }
 
 
@@ -1042,8 +1038,8 @@ bool song::saveProjectFile( const QString & _filename )
 // save current song and update the gui
 bool song::guiSaveProject()
 {
-	multimediaProject mmp( multimediaProject::SongProject );
-	m_fileName = mmp.nameWithExtension( m_fileName );
+	DataFile dataFile( DataFile::SongProject );
+	m_fileName = dataFile.nameWithExtension( m_fileName );
 	if( saveProjectFile( m_fileName ) && engine::hasGUI() )
 	{
 		textFloat::displayMessage( tr( "Project saved" ),
@@ -1091,17 +1087,18 @@ bool song::guiSaveProjectAs( const QString & _file_name )
 
 void song::importProject()
 {
-	QFileDialog ofd( NULL, tr( "Import file" ),
+	FileDialog ofd( NULL, tr( "Import file" ),
 			configManager::inst()->userProjectsDir(),
 			tr("MIDI sequences") +
 			" (*.mid *.midi *.rmi);;" +
 			tr("FL Studio projects") +
-			" (*.flp"
-			 	");;" +
+			" (*.flp);;" +
+			tr("Hydrogen projects") +
+			" (*.h2song);;" +
 			tr("All file types") +
 			" (*.*)");
 
-	ofd.setFileMode( QFileDialog::ExistingFiles );
+	ofd.setFileMode( FileDialog::ExistingFiles );
 	if( ofd.exec () == QDialog::Accepted && !ofd.selectedFiles().isEmpty() )
 	{
 		ImportFilter::import( ofd.selectedFiles()[0], this );
@@ -1130,7 +1127,16 @@ void song::restoreControllerStates( const QDomElement & _this )
 	QDomNode node = _this.firstChild();
 	while( !node.isNull() )
 	{
-		addController( Controller::create( node.toElement(), this ) );
+		Controller * c = Controller::create( node.toElement(), this );
+		Q_ASSERT( c != NULL );
+
+		/* For PeakController, addController() was called in
+		 * PeakControllerEffect::PeakControllerEffect().
+		 * This line removes the previously added controller for PeakController
+		 * without affecting the order of controllers in Controller Rack
+		 */
+		engine::getSong()->removeController( c );
+		addController( c );
 
 		node = node.nextSibling();
 	}
@@ -1154,10 +1160,10 @@ void song::exportProject(bool multiExport)
 		return;
 	}
 
-	QFileDialog efd( engine::mainWindow() );
+	FileDialog efd( engine::mainWindow() );
 	if (multiExport)
 	{
-		efd.setFileMode( QFileDialog::Directory);
+		efd.setFileMode( FileDialog::Directory);
 		efd.setWindowTitle( tr( "Select directory for writing exported tracks..." ) );
 		if( !m_fileName.isEmpty() )
 		{
@@ -1166,11 +1172,10 @@ void song::exportProject(bool multiExport)
 	}
 	else
 	{
-		efd.setFileMode( QFileDialog::AnyFile );
+		efd.setFileMode( FileDialog::AnyFile );
 		int idx = 0;
 		QStringList types;
-		while( __fileEncodeDevices[idx].m_fileFormat !=
-						ProjectRenderer::NumFileFormats )
+		while( __fileEncodeDevices[idx].m_fileFormat != ProjectRenderer::NumFileFormats )
 		{
 			types << tr( __fileEncodeDevices[idx].m_description );
 			++idx;
@@ -1191,15 +1196,31 @@ void song::exportProject(bool multiExport)
 		efd.setWindowTitle( tr( "Select file for project-export..." ) );
 	}
 
-	efd.setAcceptMode( QFileDialog::AcceptSave );
+	efd.setAcceptMode( FileDialog::AcceptSave );
 
 
-	if( efd.exec() == QDialog::Accepted &&
-		!efd.selectedFiles().isEmpty() && !efd.selectedFiles()[0].isEmpty() )
+	if( efd.exec() == QDialog::Accepted && !efd.selectedFiles().isEmpty() && !efd.selectedFiles()[0].isEmpty() )
 	{
-		const QString export_file_name = efd.selectedFiles()[0];
-		exportProjectDialog epd( export_file_name,
-						engine::mainWindow(), multiExport );
+		QString suffix = "";
+		if ( !multiExport )
+		{
+			int stx = efd.selectedNameFilter().indexOf( "(*." );
+			int etx = efd.selectedNameFilter().indexOf( ")" );
+	
+			if ( stx > 0 && etx > stx ) 
+			{
+				// Get first extension from selected dropdown.
+				// i.e. ".wav" from "WAV-File (*.wav), Dummy-File (*.dum)"
+				suffix = efd.selectedNameFilter().mid( stx + 2, etx - stx - 2 ).split( " " )[0].trimmed();
+				if ( efd.selectedFiles()[0].endsWith( suffix ) )
+				{
+					suffix = "";
+				}
+			}
+		}
+
+		const QString export_file_name = efd.selectedFiles()[0] + suffix;
+		exportProjectDialog epd( export_file_name, engine::mainWindow(), multiExport );
 		epd.exec();
 	}
 }
@@ -1221,8 +1242,7 @@ void song::setModified()
 	{
 		m_modified = true;
 		if( engine::mainWindow() &&
-			QThread::currentThread() ==
-					engine::mainWindow()->thread() )
+			QThread::currentThread() == engine::mainWindow()->thread() )
 		{
 			engine::mainWindow()->resetWindowTitle();
 		}
@@ -1260,7 +1280,6 @@ void song::removeController( Controller * _controller )
 }
 
 
-
 #include "moc_song.cxx"
 
 
