@@ -1,11 +1,9 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
- * main_window.cpp - implementation of LMMS-main-window
+ * MainWindow.cpp - implementation of LMMS-main-window
  *
- * Copyright (c) 2004-2011 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -30,31 +28,31 @@
 #include <QtGui/QApplication>
 #include <QtGui/QCloseEvent>
 #include <QtGui/QDesktopServices>
-#include <QtGui/QFileDialog>
 #include <QtGui/QMdiArea>
 #include <QtGui/QMdiSubWindow>
 #include <QtGui/QMenuBar>
 #include <QtGui/QMessageBox>
 #include <QtGui/QSplitter>
+#include <QtGui/QWhatsThis>
 
 #include "lmmsversion.h"
 #include "MainWindow.h"
 #include "bb_editor.h"
-#include "song_editor.h"
+#include "SongEditor.h"
 #include "song.h"
-#include "piano_roll.h"
+#include "PianoRoll.h"
 #include "embed.h"
 #include "engine.h"
-#include "FxMixerView.h" 
+#include "FxMixerView.h"
 #include "InstrumentTrack.h"
 #include "PianoView.h"
 #include "about_dialog.h"
 #include "ControllerRackView.h"
-#include "file_browser.h"
+#include "FileBrowser.h"
 #include "plugin_browser.h"
 #include "SideBar.h"
 #include "config_mgr.h"
-#include "mixer.h"
+#include "Mixer.h"
 #include "PluginView.h"
 #include "project_notes.h"
 #include "setup_dialog.h"
@@ -64,11 +62,13 @@
 #include "ProjectJournal.h"
 #include "AutomationEditor.h"
 #include "templates.h"
+#include "FileDialog.h"
+#include "VersionedSaveDialog.h"
 
 
 
 
-MainWindow::MainWindow( void ) :
+MainWindow::MainWindow() :
 	m_workspace( NULL ),
 	m_templatesMenu( NULL ),
 	m_recentlyOpenedProjectsMenu( NULL ),
@@ -94,44 +94,52 @@ MainWindow::MainWindow( void ) :
 	splitter->setChildrenCollapsible( FALSE );
 
 	QString wdir = configManager::inst()->workingDir();
-	sideBar->appendTab( new pluginBrowser( splitter ) );
-	sideBar->appendTab( new fileBrowser(
+	sideBar->appendTab( new PluginBrowser( splitter ) );
+	sideBar->appendTab( new FileBrowser(
 				configManager::inst()->userProjectsDir() + "*" +
 				configManager::inst()->factoryProjectsDir(),
 					"*.mmp *.mmpz *.xml *.mid *.flp",
 							tr( "My projects" ),
-					embed::getIconPixmap( "project_file" ),
+					embed::getIconPixmap( "project_file" ).transformed( QTransform().rotate( 90 ) ),
 							splitter ) );
-	sideBar->appendTab( new fileBrowser(
+	sideBar->appendTab( new FileBrowser(
 				configManager::inst()->userSamplesDir() + "*" +
 				configManager::inst()->factorySamplesDir(),
 					"*", tr( "My samples" ),
-					embed::getIconPixmap( "sample_file" ),
+					embed::getIconPixmap( "sample_file" ).transformed( QTransform().rotate( 90 ) ),
 							splitter ) );
-	sideBar->appendTab( new fileBrowser(
+	sideBar->appendTab( new FileBrowser(
 				configManager::inst()->userPresetsDir() + "*" +
 				configManager::inst()->factoryPresetsDir(),
 					"*.xpf *.cs.xml *.xiz",
 					tr( "My presets" ),
-					embed::getIconPixmap( "preset_file" ),
+					embed::getIconPixmap( "preset_file" ).transformed( QTransform().rotate( 90 ) ),
 							splitter ) );
-	sideBar->appendTab( new fileBrowser( QDir::homePath(), "*",
+	sideBar->appendTab( new FileBrowser( QDir::homePath(), "*",
 							tr( "My home" ),
-					embed::getIconPixmap( "home" ),
+					embed::getIconPixmap( "home" ).transformed( QTransform().rotate( 90 ) ),
 							splitter ) );
-	QFileInfoList drives = QDir::drives();
+
 	QStringList root_paths;
+#ifdef LMMS_BUILD_APPLE
+	root_paths += "/Volumes";
+#else
+	QFileInfoList drives = QDir::drives();
 	foreach( const QFileInfo & drive, drives )
 	{
 		root_paths += drive.absolutePath();
 	}
-	sideBar->appendTab( new fileBrowser( root_paths.join( "*" ), "*",
+#endif
+	sideBar->appendTab( new FileBrowser( root_paths.join( "*" ), "*",
 #ifdef LMMS_BUILD_WIN32
 							tr( "My computer" ),
+#elif defined(LMMS_BUILD_APPLE)
+							tr( "Volumes" ),
 #else
 							tr( "Root directory" ),
 #endif
-					embed::getIconPixmap( "computer" ),
+
+					embed::getIconPixmap( "computer" ).transformed( QTransform().rotate( 90 ) ),
 							splitter,
 #ifdef LMMS_BUILD_WIN32
 							true
@@ -144,7 +152,7 @@ MainWindow::MainWindow( void ) :
 
 	// Load background
 	QString bgArtwork = configManager::inst()->backgroundArtwork();
-	QImage bgImage; 
+	QImage bgImage;
 	if( !bgArtwork.isEmpty() )
 	{
 		bgImage = QImage( bgArtwork );
@@ -190,6 +198,9 @@ MainWindow::MainWindow( void ) :
 		connect(&m_autoSaveTimer, SIGNAL(timeout()), this, SLOT(autoSave()));
 		m_autoSaveTimer.start(1000 * 60); // 1 minute
 	}
+
+	connect( engine::getSong(), SIGNAL( playbackStateChanged() ),
+				this, SLOT( updatePlayPauseIcons() ) );
 }
 
 
@@ -212,7 +223,7 @@ MainWindow::~MainWindow()
 
 
 
-void MainWindow::finalize( void )
+void MainWindow::finalize()
 {
 	resetWindowTitle();
 	setWindowIcon( embed::getIconPixmap( "icon" ) );
@@ -229,7 +240,7 @@ void MainWindow::finalize( void )
 	project_menu->addAction( embed::getIconPixmap( "project_open" ),
 					tr( "&Open..." ),
 					this, SLOT( openProject() ),
-					Qt::CTRL + Qt::Key_O );	
+					Qt::CTRL + Qt::Key_O );
 
 	m_recentlyOpenedProjectsMenu = project_menu->addMenu(
 				embed::getIconPixmap( "project_open_recent" ),
@@ -244,6 +255,10 @@ void MainWindow::finalize( void )
 					this, SLOT( saveProject() ),
 					Qt::CTRL + Qt::Key_S );
 
+	project_menu->addAction( embed::getIconPixmap( "project_save" ),
+					tr( "Save as new &version" ),
+					this, SLOT( saveProjectAsNewVersion() ),
+					Qt::CTRL + Qt::ALT + Qt::Key_S );
 	project_menu->addAction( embed::getIconPixmap( "project_saveas" ),
 					tr( "Save &As..." ),
 					this, SLOT( saveProjectAs() ),
@@ -279,7 +294,7 @@ void MainWindow::finalize( void )
 	edit_menu->addAction( embed::getIconPixmap( "edit_redo" ),
 					tr( "Redo" ),
 					this, SLOT( redo() ),
-					Qt::CTRL + Qt::Key_R );
+					Qt::CTRL + Qt::Key_Y );
 	edit_menu->addSeparator();
 	edit_menu->addAction( embed::getIconPixmap( "setup_general" ),
 					tr( "Settings" ),
@@ -353,34 +368,40 @@ void MainWindow::finalize( void )
 	project_new_from_template->setMenu( m_templatesMenu );
 	project_new_from_template->setPopupMode( toolButton::InstantPopup );
 
-	toolButton * project_open = new toolButton( 
+	toolButton * project_open = new toolButton(
 					embed::getIconPixmap( "project_open" ),
 					tr( "Open existing project" ),
 					this, SLOT( openProject() ),
 								m_toolBar );
 
 
-	toolButton * project_open_recent = new toolButton( 
+	toolButton * project_open_recent = new toolButton(
 				embed::getIconPixmap( "project_open_recent" ),
 					tr( "Recently opened project" ),
 					this, SLOT( emptySlot() ), m_toolBar );
 	project_open_recent->setMenu( m_recentlyOpenedProjectsMenu );
 	project_open_recent->setPopupMode( toolButton::InstantPopup );
 
-	toolButton * project_save = new toolButton( 
+	toolButton * project_save = new toolButton(
 					embed::getIconPixmap( "project_save" ),
 					tr( "Save current project" ),
 					this, SLOT( saveProject() ),
 								m_toolBar );
 
 
-	toolButton * project_export = new toolButton( 
+	toolButton * project_export = new toolButton(
 				embed::getIconPixmap( "project_export" ),
 					tr( "Export current project" ),
 					engine::getSong(),
 							SLOT( exportProject() ),
 								m_toolBar );
 
+	toolButton * whatsthis = new toolButton(
+				embed::getIconPixmap( "whatsthis" ),
+					tr( "What's this?" ),
+					this, SLOT( enterWhatsThisMode() ),
+								m_toolBar );
+
 
 	m_toolBarLayout->setColumnMinimumWidth( 0, 5 );
 	m_toolBarLayout->addWidget( project_new, 0, 1 );
@@ -389,7 +410,7 @@ void MainWindow::finalize( void )
 	m_toolBarLayout->addWidget( project_open_recent, 0, 4 );
 	m_toolBarLayout->addWidget( project_save, 0, 5 );
 	m_toolBarLayout->addWidget( project_export, 0, 6 );
-
+	m_toolBarLayout->addWidget( whatsthis, 0, 7 );
 
 
 	// window-toolbar
@@ -409,7 +430,7 @@ void MainWindow::finalize( void )
 
 
 	toolButton * bb_editor_window = new toolButton(
-					embed::getIconPixmap( "bb_track" ),
+					embed::getIconPixmap( "bb_track_btn" ),
 					tr( "Show/hide Beat+Bassline Editor" ) +
 									" (F6)",
 					this, SLOT( toggleBBEditorWin() ),
@@ -458,7 +479,7 @@ void MainWindow::finalize( void )
 					this, SLOT( toggleFxMixerWin() ),
 					m_toolBar );
 	fx_mixer_window->setShortcut( Qt::Key_F9 );
-	fx_mixer_window->setWhatsThis( 
+	fx_mixer_window->setWhatsThis(
 		tr( "Click here to show or hide the "
 			"FX Mixer. The FX Mixer is a very powerful tool "
 			"for managing effects for your song. You can insert "
@@ -502,12 +523,17 @@ void MainWindow::finalize( void )
 		sd.exec();
 	}
 	// look whether mixer could use a audio-interface beside AudioDummy
-	else if( engine::getMixer()->audioDevName() == AudioDummy::name() )
+	else if( engine::mixer()->audioDevName() == AudioDummy::name() )
 	{
 		// no, so we offer setup-dialog with audio-settings...
 		setupDialog sd( setupDialog::AudioSettings );
 		sd.exec();
 	}
+	// reset window title every time we change the state of a subwindow to show the correct title
+	foreach( QMdiSubWindow * subWindow, workspace()->subWindowList() )
+	{
+		connect( subWindow, SIGNAL( windowStateChanged(Qt::WindowStates,Qt::WindowStates) ), this, SLOT( resetWindowTitle() ) );
+	}
 }
 
 
@@ -539,7 +565,7 @@ void MainWindow::addSpacingToToolBar( int _size )
 
 
 
-void MainWindow::resetWindowTitle( void )
+void MainWindow::resetWindowTitle()
 {
 	QString title = "";
 	if( engine::getSong()->projectFileName() != "" )
@@ -561,7 +587,7 @@ void MainWindow::resetWindowTitle( void )
 
 
 
-bool MainWindow::mayChangeProject( void )
+bool MainWindow::mayChangeProject()
 {
 	engine::getSong()->stop();
 
@@ -596,7 +622,7 @@ bool MainWindow::mayChangeProject( void )
 
 
 
-void MainWindow::clearKeyModifiers( void )
+void MainWindow::clearKeyModifiers()
 {
 	m_keyMods.m_ctrl = FALSE;
 	m_keyMods.m_shift = FALSE;
@@ -613,7 +639,7 @@ void MainWindow::saveWidgetState( QWidget * _w, QDomElement & _de )
 	{
 		_w = _w->parentWidget();
 	}
-	
+
 	_de.setAttribute( "x", _w->x() );
 	_de.setAttribute( "y", _w->y() );
 	_de.setAttribute( "visible", _w->isVisible() );
@@ -655,8 +681,20 @@ void MainWindow::restoreWidgetState( QWidget * _w, const QDomElement & _de )
 
 
 
+void MainWindow::emptySlot()
+{
+}
 
-void MainWindow::createNewProject( void )
+
+
+void MainWindow::enterWhatsThisMode()
+{
+	QWhatsThis::enterWhatsThisMode();
+}
+
+
+
+void MainWindow::createNewProject()
 {
 	if( mayChangeProject() )
 	{
@@ -683,15 +721,14 @@ void MainWindow::createNewProjectFromTemplate( QAction * _idx )
 
 
 
-
-void MainWindow::openProject( void )
+void MainWindow::openProject()
 {
 	if( mayChangeProject() )
 	{
-		QFileDialog ofd( this, tr( "Open project" ), "",
-			tr( "MultiMedia Project (*.mmp *.mmpz *.xml)" ) );
+		FileDialog ofd( this, tr( "Open project" ), "", tr( "LMMS (*.mmp *.mmpz)" ) );
+
 		ofd.setDirectory( configManager::inst()->userProjectsDir() );
-		ofd.setFileMode( QFileDialog::ExistingFiles );
+		ofd.setFileMode( FileDialog::ExistingFiles );
 		if( ofd.exec () == QDialog::Accepted &&
 						!ofd.selectedFiles().isEmpty() )
 		{
@@ -706,7 +743,7 @@ void MainWindow::openProject( void )
 
 
 
-void MainWindow::updateRecentlyOpenedProjectsMenu( void )
+void MainWindow::updateRecentlyOpenedProjectsMenu()
 {
 	m_recentlyOpenedProjectsMenu->clear();
 	QStringList rup = configManager::inst()->recentlyOpenedProjects();
@@ -722,17 +759,20 @@ void MainWindow::updateRecentlyOpenedProjectsMenu( void )
 
 void MainWindow::openRecentlyOpenedProject( QAction * _action )
 {
-	const QString & f = _action->text();
-	setCursor( Qt::WaitCursor );
-	engine::getSong()->loadProject( f );
-	configManager::inst()->addRecentlyOpenedProject( f );
-	setCursor( Qt::ArrowCursor );
+	if ( mayChangeProject() )
+	{
+		const QString & f = _action->text();
+		setCursor( Qt::WaitCursor );
+		engine::getSong()->loadProject( f );
+		configManager::inst()->addRecentlyOpenedProject( f );
+		setCursor( Qt::ArrowCursor );
+	}
 }
 
 
 
 
-bool MainWindow::saveProject( void )
+bool MainWindow::saveProject()
 {
 	if( engine::getSong()->projectFileName() == "" )
 	{
@@ -748,13 +788,11 @@ bool MainWindow::saveProject( void )
 
 
 
-bool MainWindow::saveProjectAs( void )
+bool MainWindow::saveProjectAs()
 {
-	QFileDialog sfd( this, tr( "Save project" ), "",
-			tr( "MultiMedia Project (*.mmp *.mmpz);;"
-				"MultiMedia Project Template (*.mpt)" ) );
-	sfd.setAcceptMode( QFileDialog::AcceptSave );
-	sfd.setFileMode( QFileDialog::AnyFile );
+	VersionedSaveDialog sfd( this, tr( "Save project" ), "",
+			tr( "LMMS Project (*.mmpz *.mmp);;"
+				"LMMS Project Template (*.mpt)" ) );
 	QString f = engine::getSong()->projectFileName();
 	if( f != "" )
 	{
@@ -766,7 +804,7 @@ bool MainWindow::saveProjectAs( void )
 		sfd.setDirectory( configManager::inst()->userProjectsDir() );
 	}
 
-	if( sfd.exec () == QFileDialog::Accepted &&
+	if( sfd.exec () == FileDialog::Accepted &&
 		!sfd.selectedFiles().isEmpty() && sfd.selectedFiles()[0] != "" )
 	{
 		engine::getSong()->guiSaveProjectAs(
@@ -779,7 +817,27 @@ bool MainWindow::saveProjectAs( void )
 
 
 
-void MainWindow::showSettingsDialog( void )
+bool MainWindow::saveProjectAsNewVersion()
+{
+	QString fileName = engine::getSong()->projectFileName();
+	if( fileName == "" )
+	{
+		return saveProjectAs();
+	}
+	else
+	{
+		do 		VersionedSaveDialog::changeFileNameVersion( fileName, true );
+		while 	( QFile( fileName ).exists() );
+
+		engine::getSong()->guiSaveProjectAs( fileName );
+		return true;
+	}
+}
+
+
+
+
+void MainWindow::showSettingsDialog()
 {
 	setupDialog sd;
 	sd.exec();
@@ -788,7 +846,7 @@ void MainWindow::showSettingsDialog( void )
 
 
 
-void MainWindow::aboutLMMS( void )
+void MainWindow::aboutLMMS()
 {
 	aboutDialog().exec();
 }
@@ -796,7 +854,7 @@ void MainWindow::aboutLMMS( void )
 
 
 
-void MainWindow::help( void )
+void MainWindow::help()
 {
 	QMessageBox::information( this, tr( "Help not available" ),
 				  tr( "Currently there's no help "
@@ -810,16 +868,17 @@ void MainWindow::help( void )
 
 
 
-void MainWindow::toggleWindow( QWidget * _w )
+void MainWindow::toggleWindow( QWidget *window, bool forceShow )
 {
-	QWidget * parent = _w->parentWidget();
+	QWidget *parent = window->parentWidget();
 
-	if( m_workspace->activeSubWindow() != parent
-				|| parent->isHidden() )
+	if( forceShow ||
+		m_workspace->activeSubWindow() != parent ||
+		parent->isHidden() )
 	{
 		parent->show();
-		_w->show();
-		_w->setFocus();
+		window->show();
+		window->setFocus();
 	}
 	else
 	{
@@ -836,23 +895,23 @@ void MainWindow::toggleWindow( QWidget * _w )
 
 
 
-void MainWindow::toggleBBEditorWin( void )
+void MainWindow::toggleBBEditorWin( bool forceShow )
 {
-	toggleWindow( engine::getBBEditor() );
+	toggleWindow( engine::getBBEditor(), forceShow );
 }
 
 
 
 
-void MainWindow::toggleSongEditorWin( void )
+void MainWindow::toggleSongEditorWin()
 {
-	toggleWindow( engine::getSongEditor() );
+	toggleWindow( engine::songEditor() );
 }
 
 
 
 
-void MainWindow::toggleProjectNotesWin( void )
+void MainWindow::toggleProjectNotesWin()
 {
 	toggleWindow( engine::getProjectNotes() );
 }
@@ -860,15 +919,15 @@ void MainWindow::toggleProjectNotesWin( void )
 
 
 
-void MainWindow::togglePianoRollWin( void )
+void MainWindow::togglePianoRollWin()
 {
-	toggleWindow( engine::getPianoRoll() );
+	toggleWindow( engine::pianoRoll() );
 }
 
 
 
 
-void MainWindow::toggleAutomationEditorWin( void )
+void MainWindow::toggleAutomationEditorWin()
 {
 	toggleWindow( engine::automationEditor() );
 }
@@ -876,7 +935,7 @@ void MainWindow::toggleAutomationEditorWin( void )
 
 
 
-void MainWindow::toggleFxMixerWin( void )
+void MainWindow::toggleFxMixerWin()
 {
 	toggleWindow( engine::fxMixerView() );
 }
@@ -884,7 +943,7 @@ void MainWindow::toggleFxMixerWin( void )
 
 
 
-void MainWindow::toggleControllerRack( void )
+void MainWindow::toggleControllerRack()
 {
 	toggleWindow( engine::getControllerRackView() );
 }
@@ -892,7 +951,43 @@ void MainWindow::toggleControllerRack( void )
 
 
 
-void MainWindow::undo( void )
+void MainWindow::updatePlayPauseIcons()
+{
+	engine::songEditor()->setPauseIcon( false );
+	engine::automationEditor()->setPauseIcon( false );
+	engine::getBBEditor()->setPauseIcon( false );
+	engine::pianoRoll()->setPauseIcon( false );
+
+	if( engine::getSong()->isPlaying() )
+	{
+		switch( engine::getSong()->playMode() )
+		{
+			case song::Mode_PlaySong:
+				engine::songEditor()->setPauseIcon( true );
+				break;
+
+			case song::Mode_PlayAutomationPattern:
+				engine::automationEditor()->setPauseIcon( true );
+				break;
+
+			case song::Mode_PlayBB:
+				engine::getBBEditor()->setPauseIcon( true );
+				break;
+
+			case song::Mode_PlayPattern:
+				engine::pianoRoll()->setPauseIcon( true );
+				break;
+
+			default:
+				break;
+		}
+	}
+}
+
+
+
+
+void MainWindow::undo()
 {
 	engine::projectJournal()->undo();
 }
@@ -900,7 +995,7 @@ void MainWindow::undo( void )
 
 
 
-void MainWindow::redo( void )
+void MainWindow::redo()
 {
 	engine::projectJournal()->redo();
 }
@@ -994,7 +1089,7 @@ void MainWindow::timerEvent( QTimerEvent * _te)
 
 
 
-void MainWindow::fillTemplatesMenu( void )
+void MainWindow::fillTemplatesMenu()
 {
 	m_templatesMenu->clear();
 
@@ -1043,7 +1138,7 @@ void MainWindow::showTool( QAction * _idx )
 
 
 
-void MainWindow::browseHelp( void )
+void MainWindow::browseHelp()
 {
 	// file:// alternative for offline help
 	QString url = "http://lmms.sf.net/wiki/index.php?title=Main_Page";
@@ -1072,5 +1167,3 @@ void MainWindow::autoSave()
 
 #include "moc_MainWindow.cxx"
 
-
-#endif
