@@ -2,9 +2,9 @@
  * Piano.cpp - implementation of piano-widget used in instrument-track-window
  *             for testing + according model class
  *
- * Copyright (c) 2004-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@
  * \mainpage Instrument plugin keyboard display classes
  *
  * \section introduction Introduction
- * 
+ *
  * \todo fill this out
  * \todo write isWhite inline function and replace throughout
  */
@@ -53,15 +53,10 @@
 #include "knob.h"
 #include "string_pair_drag.h"
 #include "MainWindow.h"
-#include "midi.h"
+#include "MidiEvent.h"
 #include "templates.h"
 #include "update_event.h"
 
-#ifdef Q_WS_X11
-
-#include <X11/Xlib.h>
-
-#endif
 
 /*! The black / white order of keys as they appear on the keyboard.
  */
@@ -165,7 +160,7 @@ PianoView::~PianoView()
 
 
 
-/*! \brief Map a keyboard key being pressed to a note in our keyboard view 
+/*! \brief Map a keyboard key being pressed to a note in our keyboard view
  *
  *  \param _k The keyboard scan code of the key being pressed.
  *  \todo check the scan codes for ',' = c, 'L' = c#, '.' = d, ':' = d#,
@@ -198,7 +193,8 @@ int PianoView::getKeyFromKeyEvent( QKeyEvent * _ke )
 		case 38: return 13; // L = c#
 		case 52: return 14; // . = d
 		case 39: return 15; // ; = d#
-		case 86: return 16; // / = e
+		//case 86: return 16; // / = e
+		case 53: return 16; // / = e
 		case 16: return 12; // Q = c
 		case 3: return 13; // 2 = c#
 		case 17: return 14; // W = d
@@ -216,6 +212,9 @@ int PianoView::getKeyFromKeyEvent( QKeyEvent * _ke )
 		case 24: return 26; // O = d'
 		case 11: return 27; // 0 = d'#
 		case 25: return 28; // P = e'
+		case 26: return 29; // [
+		case 13: return 30; // =
+		case 27: return 31; // ]
 	}
 #endif
 #ifdef LMMS_BUILD_LINUX
@@ -255,6 +254,9 @@ int PianoView::getKeyFromKeyEvent( QKeyEvent * _ke )
 		case 32: return 26; // O = d'
 		case 19: return 27; // 0 = d'#
 		case 33: return 28; // P = e'
+		case 34: return 29; // [
+		case 21: return 30; // =
+		case 35: return 31; // ]
 	}
 #endif
 #ifdef LMMS_BUILD_APPLE
@@ -311,8 +313,8 @@ void PianoView::modelChanged()
 	m_piano = castModel<Piano>();
 	if( m_piano != NULL )
 	{
-		connect( m_piano->m_instrumentTrack->baseNoteModel(),
-			SIGNAL( dataChanged() ), this, SLOT( update() ) );
+		connect( m_piano->instrumentTrack()->baseNoteModel(), SIGNAL( dataChanged() ),
+					this, SLOT( update() ) );
 	}
 
 }
@@ -418,8 +420,7 @@ void PianoView::contextMenuEvent( QContextMenuEvent * _me )
 	}
 
 	captionMenu contextMenu( tr( "Base note" ) );
-	AutomatableModelView amv( m_piano->m_instrumentTrack->baseNoteModel(),
-								&contextMenu );
+	AutomatableModelView amv( m_piano->instrumentTrack()->baseNoteModel(), &contextMenu );
 	amv.addDefaultActions( &contextMenu );
 	contextMenu.exec( QCursor::pos() );
 }
@@ -450,7 +451,7 @@ void PianoView::mousePressEvent( QMouseEvent * _me )
 	if( _me->button() == Qt::LeftButton && m_piano != NULL )
 	{
 		// get pressed key
-		Uint32 key_num = getKeyFromMouse( _me->pos() );
+		int key_num = getKeyFromMouse( _me->pos() );
 		if( _me->pos().y() > PIANO_BASE )
 		{
 			int y_diff = _me->pos().y() - PIANO_BASE;
@@ -458,7 +459,7 @@ void PianoView::mousePressEvent( QMouseEvent * _me )
 				( ( KEY_ORDER[key_num % KeysPerOctave] ==
 							Piano::WhiteKey ) ?
 				PW_WHITE_KEY_HEIGHT : PW_BLACK_KEY_HEIGHT ) *
-						(float) MidiMaxVelocity );
+						(float) m_piano->instrumentTrack()->midiPort()->baseVelocity() );
 			if( y_diff < 0 )
 			{
 				velocity = 0;
@@ -468,14 +469,11 @@ void PianoView::mousePressEvent( QMouseEvent * _me )
 							Piano::WhiteKey ) ?
 				PW_WHITE_KEY_HEIGHT : PW_BLACK_KEY_HEIGHT ) )
 			{
-				velocity = MidiMaxVelocity;
+				velocity = m_piano->instrumentTrack()->midiPort()->baseVelocity();
 			}
 			// set note on
-			m_piano->m_instrumentTrack->processInEvent(
-					midiEvent( MidiNoteOn, 0, key_num,
-							velocity ),
-								midiTime() );
-			m_piano->m_pressedKeys[key_num] = true;
+			m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiNoteOn, -1, key_num, velocity ) );
+			m_piano->setKeyState( key_num, true );
 			m_lastKey = key_num;
 
 			emit keyPressed( key_num );
@@ -485,17 +483,13 @@ void PianoView::mousePressEvent( QMouseEvent * _me )
 			if( _me->modifiers() & Qt::ControlModifier )
 			{
 				new stringPairDrag( "automatable_model",
-					QString::number( m_piano->
-						m_instrumentTrack->
-							baseNoteModel()->id() ),
+					QString::number( m_piano->instrumentTrack()->baseNoteModel()->id() ),
 					QPixmap(), this );
 				_me->accept();
 			}
 			else
 			{
-				m_piano->m_instrumentTrack->
-					baseNoteModel()->
-						setInitValue( (float) key_num );
+				m_piano->instrumentTrack()->baseNoteModel()->setInitValue( (float) key_num );
 
 				emit baseNoteChanged();
 			}
@@ -523,10 +517,8 @@ void PianoView::mouseReleaseEvent( QMouseEvent * )
 	{
 		if( m_piano != NULL )
 		{
-			m_piano->m_midiEvProc->processInEvent(
-				midiEvent( MidiNoteOff, 0, m_lastKey, 0 ),
-								midiTime() );
-			m_piano->m_pressedKeys[m_lastKey] = false;
+			m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiNoteOff, -1, m_lastKey, 0 ) );
+			m_piano->setKeyState( m_lastKey, false );
 		}
 
 		// and let the user see that he released a key... :)
@@ -565,7 +557,7 @@ void PianoView::mouseMoveEvent( QMouseEvent * _me )
 	int velocity = (int)( (float) y_diff /
 		( ( KEY_ORDER[key_num % KeysPerOctave] == Piano::WhiteKey ) ?
 			PW_WHITE_KEY_HEIGHT : PW_BLACK_KEY_HEIGHT ) *
-						(float) MidiMaxVelocity );
+						(float) m_piano->instrumentTrack()->midiPort()->baseVelocity() );
 	// maybe the user moved the mouse-cursor above or under the
 	// piano-widget while holding left button so check that and
 	// correct volume if necessary
@@ -577,7 +569,7 @@ void PianoView::mouseMoveEvent( QMouseEvent * _me )
 		( ( KEY_ORDER[key_num % KeysPerOctave] == Piano::WhiteKey ) ?
 				PW_WHITE_KEY_HEIGHT : PW_BLACK_KEY_HEIGHT ) )
 	{
-		velocity = MidiMaxVelocity;
+		velocity = m_piano->instrumentTrack()->midiPort()->baseVelocity();
 	}
 
 	// is the calculated key different from current key? (could be the
@@ -586,39 +578,29 @@ void PianoView::mouseMoveEvent( QMouseEvent * _me )
 	{
 		if( m_lastKey != -1 )
 		{
-			m_piano->m_midiEvProc->processInEvent(
-				midiEvent( MidiNoteOff, 0, m_lastKey, 0 ),
-								midiTime() );
-			m_piano->m_pressedKeys[m_lastKey] = false;
+			m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiNoteOff, -1, m_lastKey, 0 ) );
+			m_piano->setKeyState( m_lastKey, false );
 			m_lastKey = -1;
 		}
 		if( _me->buttons() & Qt::LeftButton )
 		{
 			if( _me->pos().y() > PIANO_BASE )
 			{
-				m_piano->m_midiEvProc->processInEvent(
-					midiEvent( MidiNoteOn, 0, key_num,
-							velocity ),
-								midiTime() );
-				m_piano->m_pressedKeys[key_num] = true;
+				m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiNoteOn, -1, key_num, velocity ) );
+				m_piano->setKeyState( key_num, true );
 				m_lastKey = key_num;
 			}
 			else
 			{
-				m_piano->m_instrumentTrack->
-					baseNoteModel()->
-						setInitValue( (float) key_num );
+				m_piano->instrumentTrack()->baseNoteModel()->setInitValue( (float) key_num );
 			}
 		}
 		// and let the user see that he pressed a key... :)
 		update();
 	}
-	else if( m_piano->m_pressedKeys[key_num] == true )
+	else if( m_piano->isKeyPressed( key_num ) )
 	{
-		m_piano->m_midiEvProc->processInEvent(
-				midiEvent( MidiKeyPressure, 0, key_num,
-							velocity ),
-								midiTime() );
+		m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiKeyPressure, -1, key_num, velocity ) );
 	}
 
 }
@@ -715,10 +697,8 @@ void PianoView::focusOutEvent( QFocusEvent * )
 	// hang otherwise
 	for( int i = 0; i < NumKeys; ++i )
 	{
-		m_piano->m_midiEvProc->processInEvent(
-					midiEvent( MidiNoteOff, 0, i, 0 ),
-								midiTime() );
-		m_piano->m_pressedKeys[i] = false;
+		m_piano->midiEventProcessor()->processInEvent( MidiEvent( MidiNoteOff, -1, i, 0 ) );
+		m_piano->setKeyState( i, false );
 	}
 	update();
 }
@@ -831,10 +811,13 @@ void PianoView::paintEvent( QPaintEvent * )
 	p.setPen( Qt::white );
 
 	const int base_key = ( m_piano != NULL ) ?
-		m_piano->m_instrumentTrack->baseNoteModel()->value() : 0;
-	g.setColorAt( 0, QColor( 0, 96, 0 ) );
-	g.setColorAt( 0.1, QColor( 64, 255, 64 ) );
-	g.setColorAt( 1, QColor( 0, 96, 0 ) );
+		m_piano->instrumentTrack()->baseNoteModel()->value() : 0;
+	g.setColorAt( 0, QApplication::palette().color( QPalette::Active,
+							QPalette::BrightText ).darker(220) );
+	g.setColorAt( 0.1, QApplication::palette().color( QPalette::Active,
+							QPalette::BrightText ) );
+	g.setColorAt( 1, QApplication::palette().color( QPalette::Active,
+							QPalette::BrightText ) );
 	if( KEY_ORDER[base_key % KeysPerOctave] == Piano::WhiteKey )
 	{
 		p.fillRect( QRect( getKeyX( base_key ), 1, PW_WHITE_KEY_WIDTH-1,
@@ -859,7 +842,7 @@ void PianoView::paintEvent( QPaintEvent * )
 
 		// draw pressed or not pressed key, depending on state of
 		// current key
-		if( m_piano && m_piano->m_pressedKeys[cur_key] == true )
+		if( m_piano && m_piano->isKeyPressed( cur_key ) )
 		{
 			p.drawPixmap( x, PIANO_BASE, *s_whiteKeyPressedPm );
 		}
@@ -886,19 +869,17 @@ void PianoView::paintEvent( QPaintEvent * )
 	cur_key = m_startKey;
 	int white_cnt = 0;
 
-	int s_key = m_startKey;
-	if( s_key > 0 &&
-		KEY_ORDER[(Keys)(--s_key) % KeysPerOctave] == Piano::BlackKey )
+	int startKey = m_startKey;
+	if( startKey > 0 &&
+		KEY_ORDER[(Keys)(--startKey) % KeysPerOctave] == Piano::BlackKey )
 	{
-		if( m_piano && m_piano->m_pressedKeys[s_key] == true )
+		if( m_piano && m_piano->isKeyPressed( startKey ) )
 		{
-			p.drawPixmap( 0 - PW_WHITE_KEY_WIDTH / 2, PIANO_BASE,
-							*s_blackKeyPressedPm );
+			p.drawPixmap( 0 - PW_WHITE_KEY_WIDTH / 2, PIANO_BASE, *s_blackKeyPressedPm );
 		}
 		else
 		{
-			p.drawPixmap( 0 - PW_WHITE_KEY_WIDTH / 2, PIANO_BASE,
-								*s_blackKeyPm );
+			p.drawPixmap( 0 - PW_WHITE_KEY_WIDTH / 2, PIANO_BASE, *s_blackKeyPm );
 		}
 	}
 
@@ -909,16 +890,13 @@ void PianoView::paintEvent( QPaintEvent * )
 		{
 			// draw pressed or not pressed key, depending on
 			// state of current key
-			if( m_piano && m_piano->m_pressedKeys[cur_key] == true )
+			if( m_piano && m_piano->isKeyPressed( cur_key ) )
 			{
-				p.drawPixmap( x + PW_WHITE_KEY_WIDTH / 2,
-								PIANO_BASE,
-							*s_blackKeyPressedPm );
+				p.drawPixmap( x + PW_WHITE_KEY_WIDTH / 2, PIANO_BASE, *s_blackKeyPressedPm );
 			}
 			else
 			{
-				p.drawPixmap( x + PW_WHITE_KEY_WIDTH / 2,
-						PIANO_BASE, *s_blackKeyPm );
+				p.drawPixmap( x + PW_WHITE_KEY_WIDTH / 2, PIANO_BASE, *s_blackKeyPm );
 			}
 			x += PW_WHITE_KEY_WIDTH;
 			white_cnt = 0;
