@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,38 +28,9 @@
 #include "embed.h"
 #include "engine.h"
 #include "MainWindow.h"
+#include "versioninfo.h"
 
 
-#ifdef __GNUC__
-#define GCC_VERSION "GCC "__VERSION__
-#else
-#define GCC_VERSION "unknown compiler"
-#endif
-
-#ifdef LMMS_HOST_X86
-#define MACHINE "i386"
-#endif
-
-#ifdef LMMS_HOST_X86_64
-#define MACHINE "x86_64"
-#endif
-
-#ifndef MACHINE
-#define MACHINE "unknown processor"
-#endif
-
-#ifdef LMMS_BUILD_LINUX
-#define PLATFORM "Linux"
-#endif
-
-#ifdef LMMS_BUILD_APPLE
-#define PLATFORM "OS X"
-#endif
-
-#ifdef LMMS_BUILD_WIN32
-#define PLATFORM "win32"
-#endif
-
 
 aboutDialog::aboutDialog() :
 	QDialog( engine::mainWindow() ),
@@ -67,7 +38,8 @@ aboutDialog::aboutDialog() :
 {
 	setupUi( this );
 
-	iconLabel->setPixmap( embed::getIconPixmap( "icon" ) );
+
+	iconLabel->setPixmap( embed::getIconPixmap( "icon", 64, 64 ) );
 
 	versionLabel->setText( versionLabel->text().
 					arg( LMMS_VERSION ).
@@ -79,7 +51,6 @@ aboutDialog::aboutDialog() :
 	authorLabel->setPlainText( embed::getText( "AUTHORS" ) );
 
 	licenseLabel->setPlainText( embed::getText( "COPYING" ) );
+
+	involvedLabel->setPlainText( embed::getText( "CONTRIBUTORS" ) );
 }
-
-
-
