@@ -1,9 +1,9 @@
 /*
  * setup_dialog.cpp - dialog for setting up LMMS
  *
- * Copyright (c) 2005-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -23,7 +23,6 @@
  */
 
 #include <QtGui/QComboBox>
-#include <QtGui/QFileDialog>
 #include <QtGui/QImageReader>
 #include <QtGui/QLabel>
 #include <QtGui/QLayout>
@@ -37,7 +36,7 @@
 #include "tab_button.h"
 #include "tab_widget.h"
 #include "gui_templates.h"
-#include "mixer.h"
+#include "Mixer.h"
 #include "ProjectJournal.h"
 #include "config_mgr.h"
 #include "embed.h"
@@ -45,7 +44,8 @@
 #include "debug.h"
 #include "tooltip.h"
 #include "led_checkbox.h"
-#include "lcd_spinbox.h"
+#include "LcdSpinBox.h"
+#include "FileDialog.h"
 
 
 // platform-specific audio-interface-classes
@@ -108,16 +108,20 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	m_stkDir( configManager::inst()->stkDir() ),
 #endif
 	m_backgroundArtwork( configManager::inst()->backgroundArtwork() ),
-	m_disableChActInd( configManager::inst()->value( "ui",
-				"disablechannelactivityindicators" ).toInt() ),
-	m_manualChPiano( configManager::inst()->value( "ui",
-					"manualchannelpiano" ).toInt() ),
 	m_smoothScroll( configManager::inst()->value( "ui", "smoothscroll" ).toInt() ),
 	m_enableAutoSave( configManager::inst()->value( "ui", "enableautosave" ).toInt() ),
 	m_oneInstrumentTrackWindow( configManager::inst()->value( "ui",
 					"oneinstrumenttrackwindow" ).toInt() ),
 	m_compactTrackButtons( configManager::inst()->value( "ui",
-					"compacttrackbuttons" ).toInt() )
+					"compacttrackbuttons" ).toInt() ),
+	m_syncVSTPlugins( configManager::inst()->value( "ui",
+							"syncvstplugins" ).toInt() ),
+	m_animateAFP(configManager::inst()->value( "ui",
+						   "animateafp").toInt() ),
+	m_printNoteLabels(configManager::inst()->value( "ui",
+						   "printnotelabels").toInt() ),
+	m_displayWaveform(configManager::inst()->value( "ui",
+						   "displaywaveform").toInt() )
 {
 	setWindowIcon( embed::getIconPixmap( "setup_general" ) );
 	setWindowTitle( tr( "Setup LMMS" ) );
@@ -138,7 +142,7 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	m_tabBar->setFixedWidth( 72 );
 
 	QWidget * ws = new QWidget( settings );
-	int wsHeight = 336;
+	int wsHeight = 370;
 #ifdef LMMS_HAVE_STK
 	wsHeight += 50;
 #endif
@@ -186,12 +190,17 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 
 
 	tabWidget * misc_tw = new tabWidget( tr( "MISC" ), general );
-	misc_tw->setFixedHeight( 156 );
+	const int XDelta = 10;
+	const int YDelta = 18;
+	const int HeaderSize = 30;
+	int labelNumber = 0;
+
 
 	ledCheckBox * enable_tooltips = new ledCheckBox(
 							tr( "Enable tooltips" ),
 								misc_tw );
-	enable_tooltips->move( 10, 18 );
+	labelNumber++;
+	enable_tooltips->move( XDelta, YDelta*labelNumber );
 	enable_tooltips->setChecked( m_toolTips );
 	connect( enable_tooltips, SIGNAL( toggled( bool ) ),
 					this, SLOT( toggleToolTips( bool ) ) );
@@ -200,7 +209,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	ledCheckBox * restart_msg = new ledCheckBox(
 			tr( "Show restart warning after changing settings" ),
 								misc_tw );
-	restart_msg->move( 10, 36 );
+	labelNumber++;
+	restart_msg->move( XDelta, YDelta*labelNumber );
 	restart_msg->setChecked( m_warnAfterSetup );
 	connect( restart_msg, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleWarnAfterSetup( bool ) ) );
@@ -208,7 +218,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 
 	ledCheckBox * dbv = new ledCheckBox( tr( "Display volume as dBV " ),
 								misc_tw );
-	dbv->move( 10, 54 );
+	labelNumber++;
+	dbv->move( XDelta, YDelta*labelNumber );
 	dbv->setChecked( m_displaydBV );
 	connect( dbv, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleDisplaydBV( bool ) ) );
@@ -217,7 +228,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	ledCheckBox * mmpz = new ledCheckBox(
 				tr( "Compress project files per default" ),
 								misc_tw );
-	mmpz->move( 10, 72 );
+	labelNumber++;
+	mmpz->move( XDelta, YDelta*labelNumber );
 	mmpz->setChecked( m_MMPZ );
 	connect( mmpz, SIGNAL( toggled( bool ) ),
 					this, SLOT( toggleMMPZ( bool ) ) );
@@ -225,7 +237,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	ledCheckBox * oneitw = new ledCheckBox(
 				tr( "One instrument track window mode" ),
 								misc_tw );
-	oneitw->move( 10, 90 );
+	labelNumber++;
+	oneitw->move( XDelta, YDelta*labelNumber );
 	oneitw->setChecked( m_oneInstrumentTrackWindow );
 	connect( oneitw, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleOneInstrumentTrackWindow( bool ) ) );
@@ -233,7 +246,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	ledCheckBox * hqaudio = new ledCheckBox(
 				tr( "HQ-mode for output audio-device" ),
 								misc_tw );
-	hqaudio->move( 10, 108 );
+	labelNumber++;
+	hqaudio->move( XDelta, YDelta*labelNumber );
 	hqaudio->setChecked( m_hqAudioDev );
 	connect( hqaudio, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleHQAudioDev( bool ) ) );
@@ -241,12 +255,42 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	ledCheckBox * compacttracks = new ledCheckBox(
 				tr( "Compact track buttons" ),
 								misc_tw );
-	compacttracks->move( 10, 126 );
+	labelNumber++;
+	compacttracks->move( XDelta, YDelta*labelNumber );
 	compacttracks->setChecked( m_compactTrackButtons );
 	connect( compacttracks, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleCompactTrackButtons( bool ) ) );
 
 
+	ledCheckBox * syncVST = new ledCheckBox(
+				tr( "Sync VST plugins to host playback" ),
+								misc_tw );
+	labelNumber++;
+	syncVST->move( XDelta, YDelta*labelNumber );
+	syncVST->setChecked( m_syncVSTPlugins );
+	connect( syncVST, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleSyncVSTPlugins( bool ) ) );
+
+	ledCheckBox * noteLabels = new ledCheckBox(
+				tr( "Enable note labels in piano roll" ),
+								misc_tw );
+	labelNumber++;
+	noteLabels->move( XDelta, YDelta*labelNumber );
+	noteLabels->setChecked( m_printNoteLabels );
+	connect( noteLabels, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleNoteLabels( bool ) ) );
+
+	ledCheckBox * displayWaveform = new ledCheckBox(
+				tr( "Enable waveform display by default" ),
+								misc_tw );
+	labelNumber++;
+	displayWaveform->move( XDelta, YDelta*labelNumber );
+	displayWaveform->setChecked( m_displayWaveform );
+	connect( displayWaveform, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleDisplayWaveform( bool ) ) );
+
+	misc_tw->setFixedHeight( YDelta*labelNumber + HeaderSize );
+
 
 	gen_layout->addWidget( bufsize_tw );
 	gen_layout->addSpacing( 10 );
@@ -256,7 +300,7 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 
 
 	QWidget * paths = new QWidget( ws );
-	int pathsHeight = 356;
+	int pathsHeight = 370;
 #ifdef LMMS_HAVE_STK
 	pathsHeight += 55;
 #endif
@@ -465,28 +509,11 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	tabWidget * ui_fx_tw = new tabWidget( tr( "UI effects vs. "
 						"performance" ).toUpper(),
 								performance );
-	ui_fx_tw->setFixedHeight( 100 );
-
-	ledCheckBox * disable_ch_act_ind = new ledCheckBox(
-				tr( "Disable channel activity indicators" ),
-								ui_fx_tw );
-	disable_ch_act_ind->move( 10, 20 );
-	disable_ch_act_ind->setChecked( m_disableChActInd );
-	connect( disable_ch_act_ind, SIGNAL( toggled( bool ) ),
-				this, SLOT( toggleDisableChActInd( bool ) ) );
-
-
-	ledCheckBox * manual_ch_piano = new ledCheckBox(
-			tr( "Only press keys on channel-piano manually" ),
-								ui_fx_tw );
-	manual_ch_piano->move( 10, 40 );
-	manual_ch_piano->setChecked( m_manualChPiano );
-	connect( manual_ch_piano, SIGNAL( toggled( bool ) ),
-				this, SLOT( toggleManualChPiano( bool ) ) );
+	ui_fx_tw->setFixedHeight( 80 );
 
 	ledCheckBox * smoothScroll = new ledCheckBox(
 			tr( "Smooth scroll in Song Editor" ), ui_fx_tw );
-	smoothScroll->move( 10, 60 );
+	smoothScroll->move( 10, 20 );
 	smoothScroll->setChecked( m_smoothScroll );
 	connect( smoothScroll, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleSmoothScroll( bool ) ) );
@@ -494,12 +521,21 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 
 	ledCheckBox * autoSave = new ledCheckBox(
 			tr( "Enable auto save feature" ), ui_fx_tw );
-	autoSave->move( 10, 80 );
+	autoSave->move( 10, 40 );
 	autoSave->setChecked( m_enableAutoSave );
 	connect( autoSave, SIGNAL( toggled( bool ) ),
 				this, SLOT( toggleAutoSave( bool ) ) );
 
 
+	ledCheckBox * animAFP = new ledCheckBox(
+				tr( "Show playback cursor in AudioFileProcessor" ),
+								ui_fx_tw );
+	animAFP->move( 10, 60 );
+	animAFP->setChecked( m_animateAFP );
+	connect( animAFP, SIGNAL( toggled( bool ) ),
+				this, SLOT( toggleAnimateAFP( bool ) ) );
+
+
 
 	perf_layout->addWidget( ui_fx_tw );
 	perf_layout->addStretch();
@@ -584,8 +620,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 		m_audioInterfaces->addItem( it.key() );
 	}
 	m_audioInterfaces->setCurrentIndex( m_audioInterfaces->findText(
-			tr( engine::getMixer()->audioDevName().toAscii() ) ) );
-	m_audioIfaceSetupWidgets[engine::getMixer()->audioDevName()]->show();
+			tr( engine::mixer()->audioDevName().toAscii() ) ) );
+	m_audioIfaceSetupWidgets[engine::mixer()->audioDevName()]->show();
 
 	connect( m_audioInterfaces, SIGNAL( activated( const QString & ) ),
 		this, SLOT( audioInterfaceChanged( const QString & ) ) );
@@ -665,8 +701,8 @@ setupDialog::setupDialog( ConfigTabs _tab_to_open ) :
 	}
 
 	m_midiInterfaces->setCurrentIndex( m_midiInterfaces->findText(
-		tr( engine::getMixer()->midiClientName().toAscii() ) ) );
-	m_midiIfaceSetupWidgets[engine::getMixer()->midiClientName()]->show();
+		tr( engine::mixer()->midiClientName().toAscii() ) ) );
+	m_midiIfaceSetupWidgets[engine::mixer()->midiClientName()]->show();
 
 	connect( m_midiInterfaces, SIGNAL( activated( const QString & ) ),
 		this, SLOT( midiInterfaceChanged( const QString & ) ) );
@@ -761,11 +797,6 @@ void setupDialog::accept()
 						QString::number( !m_MMPZ ) );
 	configManager::inst()->setValue( "mixer", "hqaudio",
 					QString::number( m_hqAudioDev ) );
-	configManager::inst()->setValue( "ui",
-					"disablechannelactivityindicators",
-					QString::number( m_disableChActInd ) );
-	configManager::inst()->setValue( "ui", "manualchannelpiano",
-					QString::number( m_manualChPiano ) );
 	configManager::inst()->setValue( "ui", "smoothscroll",
 					QString::number( m_smoothScroll ) );
 	configManager::inst()->setValue( "ui", "enableautosave",
@@ -774,6 +805,15 @@ void setupDialog::accept()
 					QString::number( m_oneInstrumentTrackWindow ) );
 	configManager::inst()->setValue( "ui", "compacttrackbuttons",
 					QString::number( m_compactTrackButtons ) );
+	configManager::inst()->setValue( "ui", "syncvstplugins",
+					QString::number( m_syncVSTPlugins ) );
+	configManager::inst()->setValue( "ui", "animateafp",
+					QString::number( m_animateAFP ) );
+	configManager::inst()->setValue( "ui", "printnotelabels",
+					QString::number( m_printNoteLabels ) );
+	configManager::inst()->setValue( "ui", "displaywaveform",
+					QString::number( m_displayWaveform ) );
+
 
 	configManager::inst()->setWorkingDir( m_workingDir );
 	configManager::inst()->setVSTDir( m_vstDir );
@@ -843,7 +883,7 @@ void setupDialog::setBufferSize( int _value )
 	m_bufSizeLbl->setText( tr( "Frames: %1\nLatency: %2 ms" ).arg(
 					m_bufferSize ).arg(
 						1000.0f * m_bufferSize /
-				engine::getMixer()->processingSampleRate(),
+				engine::mixer()->processingSampleRate(),
 						0, 'f', 1 ) );
 }
 
@@ -913,23 +953,6 @@ void setupDialog::toggleHQAudioDev( bool _enabled )
 
 
 
-void setupDialog::toggleDisableChActInd( bool _disabled )
-{
-	m_disableChActInd = _disabled;
-}
-
-
-
-
-void setupDialog::toggleManualChPiano( bool _enabled )
-{
-	m_manualChPiano = _enabled;
-}
-
-
-
-
-
 void setupDialog::toggleSmoothScroll( bool _enabled )
 {
 	m_smoothScroll = _enabled;
@@ -956,6 +979,29 @@ void setupDialog::toggleCompactTrackButtons( bool _enabled )
 
 
 
+void setupDialog::toggleSyncVSTPlugins( bool _enabled )
+{
+	m_syncVSTPlugins = _enabled;
+}
+
+void setupDialog::toggleAnimateAFP( bool _enabled )
+{
+	m_animateAFP = _enabled;
+}
+
+
+void setupDialog::toggleNoteLabels( bool en )
+{
+	m_printNoteLabels = en;
+}
+
+
+void setupDialog::toggleDisplayWaveform( bool en )
+{
+	m_displayWaveform = en;
+}
+
+
 void setupDialog::toggleOneInstrumentTrackWindow( bool _enabled )
 {
 	m_oneInstrumentTrackWindow = _enabled;
@@ -967,9 +1013,8 @@ void setupDialog::toggleOneInstrumentTrackWindow( bool _enabled )
 
 void setupDialog::openWorkingDir()
 {
-	QString new_dir = QFileDialog::getExistingDirectory( this,
-					tr( "Choose LMMS working directory" ),
-							m_workingDir );
+	QString new_dir = FileDialog::getExistingDirectory( this,
+					tr( "Choose LMMS working directory" ), m_workingDir );
 	if( new_dir != QString::null )
 	{
 		m_wdLineEdit->setText( new_dir );
@@ -989,7 +1034,7 @@ void setupDialog::setWorkingDir( const QString & _wd )
 
 void setupDialog::openVSTDir()
 {
-	QString new_dir = QFileDialog::getExistingDirectory( this,
+	QString new_dir = FileDialog::getExistingDirectory( this,
 				tr( "Choose your VST-plugin directory" ),
 							m_vstDir );
 	if( new_dir != QString::null )
@@ -1011,7 +1056,7 @@ void setupDialog::setVSTDir( const QString & _vd )
 
 void setupDialog::openArtworkDir()
 {
-	QString new_dir = QFileDialog::getExistingDirectory( this,
+	QString new_dir = FileDialog::getExistingDirectory( this,
 				tr( "Choose artwork-theme directory" ),
 							m_artworkDir );
 	if( new_dir != QString::null )
@@ -1033,7 +1078,7 @@ void setupDialog::setArtworkDir( const QString & _ad )
 
 void setupDialog::openFLDir()
 {
-	QString new_dir = QFileDialog::getExistingDirectory( this,
+	QString new_dir = FileDialog::getExistingDirectory( this,
 				tr( "Choose FL Studio installation directory" ),
 							m_flDir );
 	if( new_dir != QString::null )
@@ -1047,7 +1092,7 @@ void setupDialog::openFLDir()
 
 void setupDialog::openLADSPADir()
 {
-	QString new_dir = QFileDialog::getExistingDirectory( this,
+	QString new_dir = FileDialog::getExistingDirectory( this,
 				tr( "Choose LADSPA plugin directory" ),
 							m_ladDir );
 	if( new_dir != QString::null )
@@ -1070,7 +1115,7 @@ void setupDialog::openLADSPADir()
 void setupDialog::openSTKDir()
 {
 #ifdef LMMS_HAVE_STK
-	QString new_dir = QFileDialog::getExistingDirectory( this,
+	QString new_dir = FileDialog::getExistingDirectory( this,
 				tr( "Choose STK rawwave directory" ),
 							m_stkDir );
 	if( new_dir != QString::null )
@@ -1086,7 +1131,7 @@ void setupDialog::openSTKDir()
 void setupDialog::openDefaultSoundfont()
 {
 #ifdef LMMS_HAVE_FLUIDSYNTH
-	QString new_file = QFileDialog::getOpenFileName( this,
+	QString new_file = FileDialog::getOpenFileName( this,
 				tr( "Choose default SoundFont" ), m_defaultSoundfont, 
 				"SoundFont2 Files (*.sf2)" );
 	
@@ -1119,7 +1164,7 @@ void setupDialog::openBackgroundArtwork()
 	QString dir = ( m_backgroundArtwork.isEmpty() ) ?
 		m_artworkDir :
 		m_backgroundArtwork;
-	QString new_file = QFileDialog::getOpenFileName( this,
+	QString new_file = FileDialog::getOpenFileName( this,
 			tr( "Choose background artwork" ), dir, 
 			"Image Files (" + fileTypes + ")" );
 	
