@@ -2,8 +2,9 @@
  * ControllerRackView.cpp - view for song's controllers
  *
  * Copyright (c) 2008-2009 Paul Giblock <drfaygo/at/gmail.com>
+ * Copyright (c) 2010-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,7 +23,6 @@
  *
  */
 
-
 #include <QtGui/QApplication>
 #include <QtGui/QLayout>
 #include <QtGui/QMdiSubWindow>
@@ -30,6 +30,7 @@
 #include <QtGui/QScrollArea>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QMdiArea>
+#include <QMessageBox>
 
 #include "song.h"
 #include "embed.h"
@@ -41,8 +42,7 @@
 
 
 ControllerRackView::ControllerRackView( ) :
-	QWidget(),
-	m_lastY( 0 )
+	QWidget()
 {
 	setMinimumWidth( 250 );
 	setMaximumWidth( 250 );
@@ -82,9 +82,6 @@ ControllerRackView::ControllerRackView( ) :
 	flags &= ~Qt::WindowMaximizeButtonHint;
 	subWin->setWindowFlags( flags );
 	
-
-	subWin->layout()->setSizeConstraint( QLayout::SetMaximumSize );
-
 	parentWidget()->setAttribute( Qt::WA_DeleteOnClose, false );
 	parentWidget()->move( 880, 310 );
 }
@@ -120,8 +117,24 @@ void ControllerRackView::loadSettings( const QDomElement & _this )
 
 void ControllerRackView::deleteController( ControllerView * _view )
 {
-	
 	Controller * c = _view->getController();
+
+	int connectionCount = c->connectionCount();
+	if( connectionCount > 0 )
+	{
+		QMessageBox msgBox;
+		msgBox.setIcon( QMessageBox::Question );
+		msgBox.setWindowTitle( tr("Confirm Delete") );
+		msgBox.setText( tr("Confirm delete? There are existing connection(s) "
+				"associted with this controller. There is no way to undo.") );
+		msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
+		if( msgBox.exec() != QMessageBox::Ok )
+		{
+			return;
+		}
+	}
+
+
 	m_controllerViews.erase( qFind( m_controllerViews.begin(),
 				m_controllerViews.end(), _view ) );
 	delete _view;
@@ -173,6 +186,10 @@ void ControllerRackView::addController()
 
 	engine::getSong()->addController( new LfoController( engine::getSong() ) );
 	update();
+
+	// fix bug which always made ControllerRackView loose focus when adding
+	// new controller
+	setFocus();
 }
 
 
