@@ -2,9 +2,9 @@
  * EffectView.cpp - view-component for an effect
  *
  * Copyright (c) 2006-2007 Danny McRae <khjklujn/at/users.sourceforge.net>
- * Copyright (c) 2007-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2007-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,8 +28,10 @@
 #include <QtGui/QMdiArea>
 #include <QtGui/QMdiSubWindow>
 #include <QtGui/QPainter>
+#include <QtGui/QWhatsThis>
 
 #include "EffectView.h"
+#include "DummyEffect.h"
 #include "caption_menu.h"
 #include "EffectControls.h"
 #include "EffectControlDialog.h"
@@ -50,16 +52,21 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 	m_controlView( NULL )
 {
 	setFixedSize( 210, 60 );
-
-	m_bypass = new ledCheckBox( "", this );
+	
+	// Disable effects that are of type "DummyEffect"
+	bool isEnabled = !dynamic_cast<DummyEffect *>( effect() );
+	m_bypass = new ledCheckBox( this, "", isEnabled ? ledCheckBox::Green : ledCheckBox::Red );
 	m_bypass->move( 3, 3 );
+	m_bypass->setEnabled( isEnabled );
 	m_bypass->setWhatsThis( tr( "Toggles the effect on or off." ) );
+	
 	toolTip::add( m_bypass, tr( "On/Off" ) );
 
 
 	m_wetDry = new knob( knobBright_26, this );
 	m_wetDry->setLabel( tr( "W/D" ) );
 	m_wetDry->move( 27, 5 );
+	m_wetDry->setEnabled( isEnabled );
 	m_wetDry->setHintText( tr( "Wet Level:" ) + " ", "" );
 	m_wetDry->setWhatsThis( tr( "The Wet/Dry knob sets the ratio between "
 					"the input signal and the effect signal that "
@@ -69,8 +76,9 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 	m_autoQuit = new TempoSyncKnob( knobBright_26, this );
 	m_autoQuit->setLabel( tr( "DECAY" ) );
 	m_autoQuit->move( 60, 5 );
+	m_autoQuit->setEnabled( isEnabled );
 	m_autoQuit->setHintText( tr( "Time:" ) + " ", "ms" );
-	m_autoQuit->setWhatsThis( tr( 
+	m_autoQuit->setWhatsThis( tr(
 "The Decay knob controls how many buffers of silence must pass before the "
 "plugin stops processing.  Smaller values will reduce the CPU overhead but "
 "run the risk of clipping the tail on delay and reverb effects." ) );
@@ -79,21 +87,25 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 	m_gate = new knob( knobBright_26, this );
 	m_gate->setLabel( tr( "GATE" ) );
 	m_gate->move( 93, 5 );
+	m_gate->setEnabled( isEnabled );
 	m_gate->setHintText( tr( "Gate:" ) + " ", "" );
-	m_gate->setWhatsThis( tr( 
+	m_gate->setWhatsThis( tr(
 "The Gate knob controls the signal level that is considered to be 'silence' "
 "while deciding when to stop processing signals." ) );
 
 
+	setModel( _model );
+
 	if( effect()->controls()->controlCount() > 0 )
 	{
 		QPushButton * ctls_btn = new QPushButton( tr( "Controls" ),
 									this );
 		QFont f = ctls_btn->font();
-		ctls_btn->setFont( pointSize<7>( f ) );
+		ctls_btn->setFont( pointSize<8>( f ) );
 		ctls_btn->setGeometry( 140, 14, 50, 20 );
-		connect( ctls_btn, SIGNAL( clicked() ), 
+		connect( ctls_btn, SIGNAL( clicked() ),
 					this, SLOT( editControls() ) );
+
 		m_controlView = effect()->controls()->createView();
 		if( m_controlView )
 		{
@@ -112,7 +124,7 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 	}
 
 
-	setWhatsThis( tr( 
+	setWhatsThis( tr(
 "Effect plugins function as a chained series of effects where the signal will "
 "be processed from top to bottom.\n\n"
 
@@ -141,7 +153,8 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 "Right clicking will bring up a context menu where you can change the order "
 "in which the effects are processed or delete an effect altogether." ) );
 
-	setModel( _model );
+	//move above vst effect view creation
+	//setModel( _model );
 }
 
 
@@ -149,7 +162,18 @@ EffectView::EffectView( Effect * _model, QWidget * _parent ) :
 
 EffectView::~EffectView()
 {
+
+#ifdef LMMS_BUILD_LINUX
+
 	delete m_subWindow;
+#else
+	if( m_subWindow )
+	{
+		// otherwise on win32 build VST GUI can get lost
+		m_subWindow->hide();
+	}
+#endif
+
 }
 
 
@@ -159,7 +183,7 @@ void EffectView::editControls()
 {
 	if( m_subWindow )
 	{
-		if( !effect()->controls()->isViewVisible() )
+		if( !m_subWindow->isVisible() )
 		{
 			m_subWindow->show();
 			m_subWindow->raise();
@@ -221,7 +245,7 @@ void EffectView::closeEffects()
 
 void EffectView::contextMenuEvent( QContextMenuEvent * )
 {
-	QPointer<captionMenu> contextMenu = new captionMenu( model()->displayName() );
+	QPointer<captionMenu> contextMenu = new captionMenu( model()->displayName(), this );
 	contextMenu->addAction( embed::getIconPixmap( "arp_up" ),
 						tr( "Move &up" ),
 						this, SLOT( moveUp() ) );
@@ -233,9 +257,7 @@ void EffectView::contextMenuEvent( QContextMenuEvent * )
 						tr( "&Remove this plugin" ),
 						this, SLOT( deletePlugin() ) );
 	contextMenu->addSeparator();
-	contextMenu->addAction( embed::getIconPixmap( "help" ),
-						tr( "&Help" ),
-						this, SLOT( displayHelp() ) );
+	contextMenu->addHelpAction();
 	contextMenu->exec( QCursor::pos() );
 	delete contextMenu;
 }
@@ -252,7 +274,7 @@ void EffectView::paintEvent( QPaintEvent * )
 	f.setBold( true );
 	p.setFont( f );
 
-	p.setPen( QColor( 64, 64, 64 ) );
+	p.setPen( palette().shadow().color() );
 	p.drawText( 6, 55, model()->displayName() );
 	p.setPen( palette().text().color() );
 	p.drawText( 5, 54, model()->displayName() );
