@@ -2,9 +2,9 @@
  * EnvelopeAndLfoView.cpp - widget which is m_used by envelope/lfo/filter-
  *                          tab of instrument track window
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,8 +33,8 @@
 #include "gui_templates.h"
 #include "knob.h"
 #include "led_checkbox.h"
-#include "mixer.h"
-#include "mmp.h"
+#include "Mixer.h"
+#include "DataFile.h"
 #include "Oscillator.h"
 #include "pixmap_button.h"
 #include "string_pair_drag.h"
@@ -62,8 +62,7 @@ const int SUSTAIN_KNOB_X = DECAY_KNOB_X+KNOB_X_SPACING;
 const int RELEASE_KNOB_X = SUSTAIN_KNOB_X+KNOB_X_SPACING;
 const int AMOUNT_KNOB_X = RELEASE_KNOB_X+KNOB_X_SPACING;
 
-const float TIME_UNIT_WIDTH = 36.0;
-
+const int TIME_UNIT_WIDTH = 40;
 
 const int LFO_GRAPH_X = 6;
 const int LFO_GRAPH_Y = ENV_KNOBS_LBL_Y+14;
@@ -252,7 +251,7 @@ EnvelopeAndLfoView::EnvelopeAndLfoView( QWidget * _parent ) :
 		tr( "Click here for a square-wave." ) );
 
 	m_userLfoBtn = new pixmapButton( this, NULL );
-	m_userLfoBtn->move( LFO_SHAPES_X+60, LFO_SHAPES_Y );
+	m_userLfoBtn->move( LFO_SHAPES_X+75, LFO_SHAPES_Y );
 	m_userLfoBtn->setActiveGraphic( embed::getIconPixmap(
 							"usr_wave_active" ) );
 	m_userLfoBtn->setInactiveGraphic( embed::getIconPixmap(
@@ -265,16 +264,25 @@ EnvelopeAndLfoView::EnvelopeAndLfoView( QWidget * _parent ) :
 	connect( m_userLfoBtn, SIGNAL( toggled( bool ) ),
 				this, SLOT( lfoUserWaveChanged() ) );
 
+	pixmapButton * random_lfo_btn = new pixmapButton( this, NULL );
+	random_lfo_btn->move( LFO_SHAPES_X+60, LFO_SHAPES_Y );
+	random_lfo_btn->setActiveGraphic( embed::getIconPixmap(
+						"random_wave_active" ) );
+	random_lfo_btn->setInactiveGraphic( embed::getIconPixmap(
+						"random_wave_inactive" ) );
+	random_lfo_btn->setWhatsThis(
+		tr( "Click here for random wave." ) );
+
 	m_lfoWaveBtnGrp = new automatableButtonGroup( this );
 	m_lfoWaveBtnGrp->addButton( sin_lfo_btn );
 	m_lfoWaveBtnGrp->addButton( triangle_lfo_btn );
 	m_lfoWaveBtnGrp->addButton( saw_lfo_btn );
 	m_lfoWaveBtnGrp->addButton( sqr_lfo_btn );
 	m_lfoWaveBtnGrp->addButton( m_userLfoBtn );
-
+	m_lfoWaveBtnGrp->addButton( random_lfo_btn );
 
 	m_x100Cb = new ledCheckBox( tr( "FREQ x 100" ), this );
-	m_x100Cb->setFont( pointSize<6>( m_x100Cb->font() ) );
+	m_x100Cb->setFont( pointSizeF( m_x100Cb->font(), 6.5 ) );
 	m_x100Cb->move( LFO_PREDELAY_KNOB_X, LFO_GRAPH_Y + 36 );
 	m_x100Cb->setWhatsThis(
 		tr( "Click here if the frequency of this LFO should be "
@@ -285,8 +293,7 @@ EnvelopeAndLfoView::EnvelopeAndLfoView( QWidget * _parent ) :
 	m_controlEnvAmountCb = new ledCheckBox( tr( "MODULATE ENV-AMOUNT" ),
 			this );
 	m_controlEnvAmountCb->move( LFO_PREDELAY_KNOB_X, LFO_GRAPH_Y + 54 );
-	m_controlEnvAmountCb->setFont( pointSize<6>(
-					m_controlEnvAmountCb->font() ) );
+	m_controlEnvAmountCb->setFont( pointSizeF( m_controlEnvAmountCb->font(), 6.5 ) );
 	m_controlEnvAmountCb ->setWhatsThis(
 		tr( "Click here to make the envelope-amount controlled by this "
 								"LFO." ) );
@@ -341,25 +348,25 @@ void EnvelopeAndLfoView::mousePressEvent( QMouseEvent * _me )
 	if( QRect( ENV_GRAPH_X, ENV_GRAPH_Y, s_envGraph->width(),
 			s_envGraph->height() ).contains( _me->pos() ) == true )
 	{
-		if( m_amountKnob->value<float>() < 1.0f )
+		if( m_params->m_amountModel.value() < 1.0f )
 		{
-			m_amountKnob->setValue( 1.0f );
+			m_params->m_amountModel.setValue( 1.0f );
 		}
 		else
 		{
-			m_amountKnob->setValue( 0.0f );
+			m_params->m_amountModel.setValue( 0.0f );
 		}
 	}
 	else if( QRect( LFO_GRAPH_X, LFO_GRAPH_Y, s_lfoGraph->width(),
 			s_lfoGraph->height() ).contains( _me->pos() ) == true )
 	{
-		if( m_lfoAmountKnob->value<float>() < 1.0f )
+		if( m_params->m_lfoAmountModel.value() < 1.0f )
 		{
-			m_lfoAmountKnob->setValue( 1.0f );
+			m_params->m_lfoAmountModel.setValue( 1.0f );
 		}
 		else
 		{
-			m_lfoAmountKnob->setValue( 0.0f );
+			m_params->m_lfoAmountModel.setValue( 0.0f );
 		}
 	}
 }
@@ -390,10 +397,8 @@ void EnvelopeAndLfoView::dropEvent( QDropEvent * _de )
 	}
 	else if( type == QString( "tco_%1" ).arg( track::SampleTrack ) )
 	{
-		multimediaProject mmp( value.toUtf8() );
-		m_params->m_userWave.setAudioFile(
-				mmp.content().firstChild().toElement().
-							attribute( "src" ) );
+		DataFile dataFile( value.toUtf8() );
+		m_params->m_userWave.setAudioFile( dataFile.content().firstChild().toElement().  attribute( "src" ) );
 		m_userLfoBtn->model()->setValue( true );
 		_de->accept();
 	}
@@ -407,9 +412,6 @@ void EnvelopeAndLfoView::paintEvent( QPaintEvent * )
 	QPainter p( this );
 	p.setRenderHint( QPainter::Antialiasing );
 
-	// set smaller font
-	p.setFont( pointSize<6>( p.font() ) );
-
 	// draw envelope-graph
 	p.drawPixmap( ENV_GRAPH_X, ENV_GRAPH_Y, *s_envGraph );
 	// draw LFO-graph
@@ -425,54 +427,62 @@ void EnvelopeAndLfoView::paintEvent( QPaintEvent * )
 				static_cast<int>( 128 - 32 * gray_amount ) ),
 									2 ) );
 
-	const QColor end_points_color( 0xFF, 0xBF, 0x22 );
+	const QColor end_points_color( 0x99, 0xAF, 0xFF );
 	const QColor end_points_bg_color( 0, 0, 2 );
 
 	const int y_base = ENV_GRAPH_Y + s_envGraph->height() - 3;
 	const int avail_height = s_envGraph->height() - 6;
 	
-	int x1 = ENV_GRAPH_X + 2 + static_cast<int>( m_predelayKnob->value<float>() *
-							TIME_UNIT_WIDTH );
-	int x2 = x1 + static_cast<int>( m_attackKnob->value<float>() *
-							TIME_UNIT_WIDTH );
+	int x1 = static_cast<int>( m_predelayKnob->value<float>() * TIME_UNIT_WIDTH );
+	int x2 = x1 + static_cast<int>( m_attackKnob->value<float>() * TIME_UNIT_WIDTH );
+	int x3 = x2 + static_cast<int>( m_holdKnob->value<float>() * TIME_UNIT_WIDTH );
+	int x4 = x3 + static_cast<int>( ( m_decayKnob->value<float>() *
+						( 1 - m_sustainKnob->value<float>() ) ) * TIME_UNIT_WIDTH );
+	int x5 = x4 + static_cast<int>( m_releaseKnob->value<float>() * TIME_UNIT_WIDTH );
+
+	if( x5 > 174 )
+	{
+		x1 = ( x1 * 174 ) / x5;
+		x2 = ( x2 * 174 ) / x5;
+		x3 = ( x3 * 174 ) / x5;
+		x4 = ( x4 * 174 ) / x5;
+		x5 = ( x5 * 174 ) / x5;
+	}
+	x1 += ENV_GRAPH_X + 2;
+	x2 += ENV_GRAPH_X + 2;
+	x3 += ENV_GRAPH_X + 2;
+	x4 += ENV_GRAPH_X + 2;
+	x5 += ENV_GRAPH_X + 2;
 
 	p.drawLine( x1, y_base, x2, y_base - avail_height );
 	p.fillRect( x1 - 1, y_base - 2, 4, 4, end_points_bg_color );
 	p.fillRect( x1, y_base - 1, 2, 2, end_points_color );
-	x1 = x2;
-	x2 = x1 + static_cast<int>( m_holdKnob->value<float>() * TIME_UNIT_WIDTH );
 
-	p.drawLine( x1, y_base - avail_height, x2, y_base - avail_height );
-	p.fillRect( x1 - 1, y_base - 2 - avail_height, 4, 4,
+	p.drawLine( x2, y_base - avail_height, x3, y_base - avail_height );
+	p.fillRect( x2 - 1, y_base - 2 - avail_height, 4, 4,
 							end_points_bg_color );
-	p.fillRect( x1, y_base-1-avail_height, 2, 2, end_points_color );
-	x1 = x2;
-	x2 = x1 + static_cast<int>( ( m_decayKnob->value<float>() *
-						m_sustainKnob->value<float>() ) *
-							TIME_UNIT_WIDTH );
+	p.fillRect( x2, y_base - 1 - avail_height, 2, 2, end_points_color );
 
-	p.drawLine( x1, y_base-avail_height, x2, static_cast<int>( y_base -
+	p.drawLine( x3, y_base-avail_height, x4, static_cast<int>( y_base -
 								avail_height +
-				m_sustainKnob->value<float>() * avail_height ) );
-	p.fillRect( x1 - 1, y_base - 2 - avail_height, 4, 4,
+				( 1 - m_sustainKnob->value<float>() ) * avail_height ) );
+	p.fillRect( x3 - 1, y_base - 2 - avail_height, 4, 4,
 							end_points_bg_color );
-	p.fillRect( x1, y_base - 1 - avail_height, 2, 2, end_points_color );
-	x1 = x2;
-	x2 = x1 + static_cast<int>( m_releaseKnob->value<float>() * TIME_UNIT_WIDTH );
-
-	p.drawLine( x1, static_cast<int>( y_base - avail_height +
-						m_sustainKnob->value<float>() *
-						avail_height ), x2, y_base );
-	p.fillRect( x1-1, static_cast<int>( y_base - avail_height +
-						m_sustainKnob->value<float>() *
+	p.fillRect( x3, y_base - 1 - avail_height, 2, 2, end_points_color );
+	
+	p.drawLine( x4, static_cast<int>( y_base - avail_height +
+						( 1 - m_sustainKnob->value<float>() ) *
+						avail_height ), x5, y_base );
+	p.fillRect( x4 - 1, static_cast<int>( y_base - avail_height +
+						( 1 - m_sustainKnob->value<float>() ) *
 						avail_height ) - 2, 4, 4,
 							end_points_bg_color );
-	p.fillRect( x1, static_cast<int>( y_base - avail_height +
-						m_sustainKnob->value<float>() *
+	p.fillRect( x4, static_cast<int>( y_base - avail_height +
+						( 1 - m_sustainKnob->value<float>() ) *
 						avail_height ) - 1, 2, 2,
 							end_points_color );
-	p.fillRect( x2 - 1, y_base - 2, 4, 4, end_points_bg_color );
-	p.fillRect( x2, y_base - 1, 2, 2, end_points_color );
+	p.fillRect( x5 - 1, y_base - 2, 4, 4, end_points_bg_color );
+	p.fillRect( x5, y_base - 1, 2, 2, end_points_color );
 
 
 	int LFO_GRAPH_W = s_lfoGraph->width() - 6;	// substract border
@@ -481,7 +491,7 @@ void EnvelopeAndLfoView::paintEvent( QPaintEvent * )
 	int graph_y_base = LFO_GRAPH_Y + 3 + LFO_GRAPH_H / 2;
 
 	const float frames_for_graph = SECS_PER_LFO_OSCILLATION *
-				engine::getMixer()->baseSampleRate() / 10;
+				engine::mixer()->baseSampleRate() / 10;
 
 	const float lfo_gray_amount = 1.0f - fabsf( m_lfoAmountKnob->value<float>() );
 	p.setPen( QPen( QColor( static_cast<int>( 96 * lfo_gray_amount ),
@@ -524,9 +534,17 @@ void EnvelopeAndLfoView::paintEvent( QPaintEvent * )
 				case EnvelopeAndLfoParameters::SquareWave:
 					val = Oscillator::squareSample( phase );
 					break;
+				case EnvelopeAndLfoParameters::RandomWave:
+					if( x % (int)( 900 * m_lfoSpeedKnob->value<float>() + 1 ) == 0 )
+					{
+						m_randomGraph = Oscillator::noiseSample( 0.0f );
+					}
+					val = m_randomGraph;
+					break;
 				case EnvelopeAndLfoParameters::UserDefinedWave:
 					val = m_params->m_userWave.
 							userWaveSample( phase );
+					break;
 			}
 			if( static_cast<f_cnt_t>( cur_sample ) <=
 						m_params->m_lfoAttackFrames )
@@ -541,7 +559,7 @@ void EnvelopeAndLfoView::paintEvent( QPaintEvent * )
 		old_y = cur_y;
 	}
 
-	p.setPen( QColor( 255, 192, 0 ) );
+	p.setPen( QColor( 201, 201, 225 ) );
 	int ms_per_osc = static_cast<int>( SECS_PER_LFO_OSCILLATION *
 						m_lfoSpeedKnob->value<float>() *
 								1000.0f );
