@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2006-2011 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@
 #include "engine.h"
 #include "embed.h"
 #include "MainWindow.h"
-
+#include "string_pair_drag.h"
 
 
 
@@ -115,6 +115,7 @@ void automatableButton::mousePressEvent( QMouseEvent * _me )
 	if( _me->button() == Qt::LeftButton &&
 			! ( _me->modifiers() & Qt::ControlModifier ) )
 	{
+        // User simply clicked, toggle if needed
 		if( isCheckable() )
 		{
 			toggle();
@@ -123,8 +124,23 @@ void automatableButton::mousePressEvent( QMouseEvent * _me )
 	}
 	else
 	{
-		AutomatableModelView::mousePressEvent( _me );
-		QPushButton::mousePressEvent( _me );
+		// Ctrl-clicked, need to prepare drag-drop
+		if( m_group )
+		{
+			// A group, we must get process it instead
+			AutomatableModelView* groupView = (AutomatableModelView*)m_group;
+			new stringPairDrag( "automatable_model",
+					QString::number( groupView->modelUntyped()->id() ),
+					QPixmap(), widget() );
+			// TODO: ^^ Maybe use a predefined icon instead of the button they happened to select
+			_me->accept();
+		}
+		else
+		{
+			// Otherwise, drag the standalone button
+			AutomatableModelView::mousePressEvent( _me );
+			QPushButton::mousePressEvent( _me );
+		}
 	}
 }
 
