@@ -1,9 +1,9 @@
 /*
  * knob.cpp - powerful knob-widget
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,12 +29,13 @@
 #include <QtGui/QMouseEvent>
 #include <QtGui/QPainter>
 #include <QtGui/QPalette>
+#include <QtGui/QWhatsThis>
 
 #ifndef __USE_XOPEN
 #define __USE_XOPEN
 #endif
-#include <math.h>
 
+#include "lmms_math.h"
 #include "knob.h"
 #include "caption_menu.h"
 #include "config_mgr.h"
@@ -54,25 +55,58 @@ textFloat * knob::s_textFloat = NULL;
 
 
 
-knob::knob( int _knob_num, QWidget * _parent, const QString & _name ) :
-	QWidget( _parent ),
-	FloatModelView( new FloatModel( 0, 0, 0, 1, NULL, _name, true ), this ),
-	m_knobNum( _knob_num ),
-	m_label( "" ),
-	m_knobPixmap( NULL ),
-	m_volumeKnob( false ),
-	m_mouseOffset( 0.0f ),
-	m_buttonPressed( false ),
-	m_angle( -10 ),
-	m_outerColor( NULL )
+//! @todo: in C++11, we can use delegating ctors
+#define DEFAULT_KNOB_INITIALIZER_LIST \
+	QWidget( _parent ), \
+	FloatModelView( new FloatModel( 0, 0, 0, 1, NULL, _name, true ), this ), \
+	m_label( "" ), \
+	m_knobPixmap( NULL ), \
+	m_volumeKnob( false ), \
+	m_volumeRatio( 100.0, 0.0, 1000000.0 ), \
+	m_buttonPressed( false ), \
+	m_angle( -10 )
+
+knob::knob( knobTypes _knob_num, QWidget * _parent, const QString & _name ) :
+	DEFAULT_KNOB_INITIALIZER_LIST,
+	m_knobNum( _knob_num )
+{
+	initUi( _name );
+}
+
+knob::knob( QWidget * _parent, const QString & _name ) :
+	DEFAULT_KNOB_INITIALIZER_LIST,
+	m_knobNum( knobBright_26 )
+{
+	initUi( _name );
+}
+
+#undef DEFAULT_KNOB_INITIALIZER_LIST
+
+
+
+
+void knob::initUi( const QString & _name )
 {
 	if( s_textFloat == NULL )
 	{
 		s_textFloat = new textFloat;
 	}
 
-	setAccessibleName( _name );
-	
+	setWindowTitle( _name );
+
+	onKnobNumUpdated();
+	setTotalAngle( 270.0f );
+	setInnerRadius( 1.0f );
+	setOuterRadius( 10.0f );
+	setFocusPolicy( Qt::ClickFocus );
+	doConnections();
+}
+
+
+
+
+void knob::onKnobNumUpdated()
+{
 	if( m_knobNum != knobStyled )
 	{
 		m_knobPixmap = new QPixmap( embed::getIconPixmap( QString( "knob0" +
@@ -80,11 +114,6 @@ knob::knob( int _knob_num, QWidget * _parent, const QString & _name ) :
 
 		setFixedSize( m_knobPixmap->width(), m_knobPixmap->height() );
 	}
-	setTotalAngle( 270.0f );
-	setInnerRadius( 1.0f );
-	setOuterRadius( 10.0f );
-	setFocusPolicy( Qt::ClickFocus );
-	doConnections();
 }
 
 
@@ -107,8 +136,7 @@ void knob::setLabel( const QString & _txt )
 	if( m_knobPixmap )
 	{
 		setFixedSize( qMax<int>( m_knobPixmap->width(),
-					QFontMetrics( pointSizeF( font(), 6
-							) ).width( m_label ) ),
+					QFontMetrics( pointSizeF( font(), 6.5) ).width( m_label ) ),
 						m_knobPixmap->height() + 10 );
 	}
 	update();
@@ -162,6 +190,27 @@ void knob::setOuterRadius( float _r )
 
 
 
+
+knobTypes knob::knobNum() const
+{
+	return m_knobNum;
+}
+
+
+
+
+void knob::setknobNum( knobTypes _k )
+{
+	if( m_knobNum != _k )
+	{
+		m_knobNum = _k;
+		onKnobNumUpdated();
+	}
+}
+
+
+
+
 QPointF knob::centerPoint() const
 {
 	return m_centerPoint;
@@ -213,28 +262,42 @@ void knob::setLineWidth( float _w )
 
 QColor knob::outerColor() const
 {
-	if( m_outerColor )
-	{
-		return *m_outerColor;
-	}
-	else
-	{
-		return QColor();
-	}
+	return m_outerColor;
 }
 
 
 
 void knob::setOuterColor( const QColor & _c )
 {
-	if( m_outerColor )
-	{
-		*m_outerColor = _c;
-	}
-	else
-	{
-		m_outerColor = new QColor( _c );
-	}
+	m_outerColor = _c;
+}
+
+
+
+QColor knob::lineColor() const
+{
+	return m_lineColor;
+}
+
+
+
+void knob::setlineColor( const QColor & _c )
+{
+	m_lineColor = _c;
+}
+
+
+
+QColor knob::arcColor() const
+{
+	return m_arcColor;
+}
+
+
+
+void knob::setarcColor( const QColor & _c )
+{
+	m_arcColor = _c;
 }
 
 
@@ -242,7 +305,7 @@ void knob::setOuterColor( const QColor & _c )
 
 QLineF knob::calculateLine( const QPointF & _mid, float _radius, float _innerRadius ) const
 {
-	const float rarc = m_angle * M_PI / 180.0;
+	const float rarc = m_angle * F_PI / 180.0;
 	const float ca = cos( rarc );
 	const float sa = -sin( rarc );
 
@@ -257,11 +320,7 @@ bool knob::updateAngle()
 	int angle = 0;
 	if( model() && model()->maxValue() != model()->minValue() )
 	{
-		float a = ( model()->value() - 0.5 * ( model()->minValue() +
-						model()->maxValue() ) ) /
-				( model()->maxValue() - model()->minValue() ) *
-								m_totalAngle;
-		angle = static_cast<int>( a ) % 360;
+		angle = angleFromValue( model()->inverseScaledValue( model()->value() ), model()->minValue(), model()->maxValue(), m_totalAngle );
 	}
 	if( qAbs( angle - m_angle ) > 3 )
 	{
@@ -294,11 +353,11 @@ void knob::drawKnob( QPainter * _p )
 		p.setRenderHint( QPainter::Antialiasing );
 
 		// Perhaps this can move to setOuterRadius()
-		if( m_outerColor )
+		if( m_outerColor.isValid() )
 		{
 			QRadialGradient gradient( centerPoint(), outerRadius() );
-			gradient.setColorAt(0.4, _p->pen().brush().color() );
-			gradient.setColorAt(1, *m_outerColor );
+			gradient.setColorAt( 0.4, _p->pen().brush().color() );
+			gradient.setColorAt( 1, m_outerColor );
 
 			p.setPen( QPen( gradient, lineWidth(),
 						Qt::SolidLine, Qt::RoundCap ) );
@@ -307,7 +366,7 @@ void knob::drawKnob( QPainter * _p )
 			QPen pen = p.pen();
 			pen.setWidth( (int) lineWidth() );
 			pen.setCapStyle( Qt::RoundCap );
-			
+
 			p.setPen( pen );
 		}
 
@@ -323,27 +382,45 @@ void knob::drawKnob( QPainter * _p )
 	const float radius = m_knobPixmap->width() / 2.0f - 1;
 	mid = QPoint( width() / 2, m_knobPixmap->height() / 2 );
 
-	p.drawPixmap( static_cast<int>( 
+	p.drawPixmap( static_cast<int>(
 				width() / 2 - m_knobPixmap->width() / 2 ), 0,
 				*m_knobPixmap );
 
-	p.setPen( QPen( QColor( 200, 0, 0 ), 2 ) );
 	p.setRenderHint( QPainter::Antialiasing );
 
+	const int centerAngle = angleFromValue( model()->inverseScaledValue( model()->centerValue() ), model()->minValue(), model()->maxValue(), m_totalAngle );
+
+	const int arcLineWidth = 2;
+	const int arcRectSize = m_knobPixmap->width() - arcLineWidth;
+
+	QColor col;
+	if( m_knobNum == knobVintage_32 )
+	{	col = QApplication::palette().color( QPalette::Active, QPalette::Shadow ); }
+	else
+	{	col = QApplication::palette().color( QPalette::Active, QPalette::WindowText ); }
+	col.setAlpha( 70 );
+
+	p.setPen( QPen( col, 2 ) );
+	p.drawArc( mid.x() - arcRectSize/2, 1, arcRectSize, arcRectSize, 315*16, 16*m_totalAngle );
+
 	switch( m_knobNum )
 	{
 		case knobSmall_17:
 		{
-			p.drawLine( calculateLine( mid, radius ) );
+			p.setPen( QPen( QApplication::palette().color( QPalette::Active,
+							QPalette::WindowText ), 2 ) );
+			p.drawLine( calculateLine( mid, radius-2 ) );
 			break;
 		}
 		case knobBright_26:
 		{
+			p.setPen( QPen( QApplication::palette().color( QPalette::Active, QPalette::WindowText ), 2 ) );
 			p.drawLine( calculateLine( mid, radius-5 ) );
 			break;
 		}
 		case knobDark_28:
 		{
+			p.setPen( QPen( QApplication::palette().color( QPalette::Active, QPalette::WindowText ), 2 ) );
 			const float rb = qMax<float>( ( radius - 10 ) / 3.0,
 									0.0 );
 			const float re = qMax<float>( ( radius - 4 ), 0.0 );
@@ -354,25 +431,43 @@ void knob::drawKnob( QPainter * _p )
 		}
 		case knobGreen_17:
 		{
-			p.setPen( QPen( QColor( 0, 200, 0 ), 2 ) );
+			p.setPen( QPen( QApplication::palette().color( QPalette::Active,
+							QPalette::BrightText), 2 ) );
 			p.drawLine( calculateLine( mid, radius ) );
 			break;
 		}
+		case knobVintage_32:
+		{
+			p.setPen( QPen( QApplication::palette().color( QPalette::Active,
+							QPalette::Shadow), 2 ) );
+			p.drawLine( calculateLine( mid, radius-2, 2 ) );
+			break;
+		}
+		case knobStyled:
+			break;
 	}
+
+	p.drawArc( mid.x() - arcRectSize/2, 1, arcRectSize, arcRectSize, (90-centerAngle)*16, -16*(m_angle-centerAngle) );
+
 	p.end();
+
 	_p->drawImage( 0, 0, m_cache );
 }
 
-
-
-
 float knob::getValue( const QPoint & _p )
 {
-	if( engine::mainWindow()->isShiftPressed() )
+	float value;
+
+	// arcane mathemagicks for calculating knob movement 
+	value = ( ( _p.y() + _p.y() * qMin( qAbs( _p.y() / 2.5f ), 6.0f ) ) ) / 12.0f;
+	
+	// if shift pressed we want slower movement
+	if( engine::mainWindow()->isShiftPressed() )	
 	{
-		return( ( _p.y() - m_origMousePos.y() ) * model()->step<float>() );
-	}
-	return( ( _p.y() - m_origMousePos.y() ) * pageSize() );
+		value /= 4.0f;
+		value = qBound( -4.0f, value, 4.0f );
+	}		
+	return value * pageSize();
 }
 
 
@@ -386,15 +481,22 @@ void knob::contextMenuEvent( QContextMenuEvent * )
 	// an QApplication::restoreOverrideCursor()-call...
 	mouseReleaseEvent( NULL );
 
-	captionMenu contextMenu( model()->displayName() );
+	captionMenu contextMenu( model()->displayName(), this );
 	addDefaultActions( &contextMenu );
+	contextMenu.addAction( QPixmap(), 
+		model()->isScaleLogarithmic() ? tr( "Set linear" ) : tr( "Set logarithmic" ),
+		this, SLOT( toggleScale() ) );
 	contextMenu.addSeparator();
-	contextMenu.addAction( embed::getIconPixmap( "help" ), tr( "&Help" ),
-						this, SLOT( displayHelp() ) );
+	contextMenu.addHelpAction();
 	contextMenu.exec( QCursor::pos() );
 }
 
 
+void knob::toggleScale()
+{
+	model()->setScaleLogarithmic( ! model()->isScaleLogarithmic() );
+}
+
 
 
 void knob::dragEnterEvent( QDragEnterEvent * _dee )
@@ -437,10 +539,17 @@ void knob::mousePressEvent( QMouseEvent * _me )
 			! ( _me->modifiers() & Qt::ControlModifier ) &&
 			! ( _me->modifiers() & Qt::ShiftModifier ) )
 	{
-		model()->prepareJournalEntryFromOldVal();
+		AutomatableModel *thisModel = model();
+		if( thisModel )
+		{
+			thisModel->addJournalCheckPoint();
+			thisModel->saveJournallingState( false );
+		}
 
 		const QPoint & p = _me->pos();
 		m_origMousePos = p;
+		m_mouseOffset = QPoint(0, 0);
+		m_leftOver = 0.0f;
 
 		emit sliderPressed();
 
@@ -469,9 +578,10 @@ void knob::mousePressEvent( QMouseEvent * _me )
 
 void knob::mouseMoveEvent( QMouseEvent * _me )
 {
-	if( m_buttonPressed == true && _me->pos() != m_origMousePos )
+	if( m_buttonPressed && _me->pos() != m_origMousePos )
 	{
-		setPosition( _me->pos() );
+		m_mouseOffset = _me->pos() - m_origMousePos;
+		setPosition( m_mouseOffset );
 		emit sliderMoved( model()->value() );
 		QCursor::setPos( mapToGlobal( m_origMousePos ) );
 	}
@@ -482,13 +592,19 @@ void knob::mouseMoveEvent( QMouseEvent * _me )
 
 
 
-void knob::mouseReleaseEvent( QMouseEvent * /* _me*/ )
+void knob::mouseReleaseEvent( QMouseEvent* event )
 {
-	model()->addJournalEntryFromOldToCurVal();
+	if( event && event->button() == Qt::LeftButton )
+	{
+		AutomatableModel *thisModel = model();
+		if( thisModel )
+		{
+			thisModel->restoreJournallingState();
+		}
+	}
 
 	m_buttonPressed = false;
 
-	m_mouseOffset = 0;
 	emit sliderReleased();
 
 	QApplication::restoreOverrideCursor();
@@ -524,7 +640,7 @@ void knob::paintEvent( QPaintEvent * _me )
 	drawKnob( &p );
 	if( !m_label.isEmpty() )
 	{
-		p.setFont( pointSizeF( p.font(), 6 ) );
+		p.setFont( pointSizeF( p.font(), 6.5 ) );
 /*		p.setPen( QColor( 64, 64, 64 ) );
 		p.drawText( width() / 2 -
 			p.fontMetrics().width( m_label ) / 2 + 1,
@@ -558,7 +674,42 @@ void knob::wheelEvent( QWheelEvent * _we )
 
 void knob::setPosition( const QPoint & _p )
 {
-	model()->setValue( model()->value() - getValue( _p ) );
+	const float value = getValue( _p ) + m_leftOver;
+	const float step = model()->step<float>();
+	const float oldValue = model()->value();
+
+
+	if( model()->isScaleLogarithmic() ) // logarithmic code
+	{
+		const float pos = model()->minValue() < 0 
+			? oldValue / qMax( qAbs( model()->maxValue() ), qAbs( model()->minValue() ) )
+			: ( oldValue - model()->minValue() ) / model()->range();
+		const float ratio = 0.1f + qAbs( pos ) * 15.f;
+		float newValue = value * ratio;
+		if( qAbs( newValue ) >= step )
+		{
+			model()->setValue( oldValue - newValue );
+			m_leftOver = 0.0f;
+		}
+		else
+		{
+			m_leftOver = value;
+		}
+	}
+
+		
+	else // linear code
+	{
+		if( qAbs( value ) >= step )
+		{	
+			model()->setValue( oldValue - value );
+			m_leftOver = 0.0f;
+		}
+		else
+		{
+			m_leftOver = value;
+		}
+	}
 }
 
 
@@ -572,7 +723,7 @@ void knob::enterValue()
 		configManager::inst()->value( "app", "displaydbv" ).toInt() )
 	{
 		new_val = QInputDialog::getDouble(
-			this, accessibleName(),
+			this, windowTitle(),
 			tr( "Please enter a new value between "
 					"-96.0 dBV and 6.0 dBV:" ),
 				20.0 * log10( model()->value() / 100.0 ),
@@ -583,13 +734,13 @@ void knob::enterValue()
 		}
 		else
 		{
-			new_val = pow( 10.0, ( new_val / 20.0 ) ) * 100.0;
+			new_val = dbvToAmp( new_val ) * 100.0;
 		}
 	}
 	else
 	{
 		new_val = QInputDialog::getDouble(
-				this, accessibleName(),
+				this, windowTitle(),
 				tr( "Please enter a new value between "
 						"%1 and %2:" ).
 						arg( model()->minValue() ).
@@ -610,9 +761,8 @@ void knob::enterValue()
 
 void knob::friendlyUpdate()
 {
-	if( model()->getControllerConnection() == NULL ||
-		model()->getControllerConnection()->getController()->
-						frequentUpdates() == false ||
+	if( model()->controllerConnection() == NULL ||
+		model()->controllerConnection()->getController()->frequentUpdates() == false ||
 				Controller::runningFrames() % (256*4) == 0 )
 	{
 		update();
@@ -628,7 +778,7 @@ QString knob::displayValue() const
 		configManager::inst()->value( "app", "displaydbv" ).toInt() )
 	{
 		return m_description.trimmed() + QString( " %1 dBV" ).
-				arg( 20.0 * log10( model()->value() / 100.0 ),
+				arg( 20.0 * log10( model()->value() / volumeRatio() ),
 								3, 'f', 2 );
 	}
 	return m_description.trimmed() + QString( " %1" ).
