@@ -1,9 +1,9 @@
 /*
  * led_checkbox.cpp - class ledCheckBox, an improved QCheckBox
  *
- * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -38,30 +38,33 @@ static const QString names[ledCheckBox::NumColors] =
 
 
 
+
+//! @todo: in C++11, we can use delegating ctors
+#define DEFAULT_LEDCHECKBOX_INITIALIZER_LIST \
+	automatableButton( _parent, _name )
+
 ledCheckBox::ledCheckBox( const QString & _text, QWidget * _parent,
 				const QString & _name, LedColors _color ) :
-	automatableButton( _parent, _name ),
+	DEFAULT_LEDCHECKBOX_INITIALIZER_LIST,
 	m_text( _text )
 {
-	setCheckable( true );
-
-	if( _color >= NumColors || _color < Yellow )
-	{
-		_color = Yellow;
-	}
-	m_ledOnPixmap = new QPixmap( embed::getIconPixmap(
-					names[_color].toUtf8().constData() ) );
-	m_ledOffPixmap = new QPixmap( embed::getIconPixmap( "led_off" ) );
-
-	setFont( pointSize<7>( font() ) );
-	setFixedSize( m_ledOffPixmap->width() + 4 +
-					QFontMetrics( font() ).width( text() ),
-			m_ledOffPixmap->height() );
+	initUi( _color );
 }
 
 
 
 
+ledCheckBox::ledCheckBox( QWidget * _parent,
+				const QString & _name, LedColors _color ) :
+	DEFAULT_LEDCHECKBOX_INITIALIZER_LIST
+{
+	initUi( _color );
+}
+
+#undef DEFAULT_LEDCHECKBOX_INITIALIZER_LIST
+
+
+
 ledCheckBox::~ledCheckBox()
 {
 	delete m_ledOnPixmap;
@@ -71,14 +74,23 @@ ledCheckBox::~ledCheckBox()
 
 
 
+void ledCheckBox::setText( const QString &s )
+{
+	m_text = s;
+	onTextUpdated();
+}
+
+
+
+
 void ledCheckBox::paintEvent( QPaintEvent * )
 {
 	QPainter p( this );
 	p.setFont( pointSize<7>( font() ) );
 
 	if( model()->value() == true )
-	{
-		p.drawPixmap( 0, 0, *m_ledOnPixmap );
+		{
+			p.drawPixmap( 0, 0, *m_ledOnPixmap );
 	}
 	else
 	{
@@ -86,9 +98,36 @@ void ledCheckBox::paintEvent( QPaintEvent * )
 	}
 
 	p.setPen( QColor( 64, 64, 64 ) );
-	p.drawText( m_ledOffPixmap->width() + 3, 10, text() );
+	p.drawText( m_ledOffPixmap->width() + 4, 11, text() );
 	p.setPen( QColor( 255, 255, 255 ) );
-	p.drawText( m_ledOffPixmap->width() + 2, 9, text() );
+	p.drawText( m_ledOffPixmap->width() + 3, 10, text() );
+}
+
+
+
+
+void ledCheckBox::initUi( LedColors _color )
+{
+	setCheckable( true );
+
+	if( _color >= NumColors || _color < Yellow )
+	{
+		_color = Yellow;
+	}
+	m_ledOnPixmap = new QPixmap( embed::getIconPixmap(
+					names[_color].toUtf8().constData() ) );
+	m_ledOffPixmap = new QPixmap( embed::getIconPixmap( "led_off" ) );
+
+	setFont( pointSize<7>( font() ) );
+	setText( m_text );
+}
+
+
+
+
+void ledCheckBox::onTextUpdated()
+{
+	setFixedSize( m_ledOffPixmap->width() + 5 + QFontMetrics( font() ).width( text() ), m_ledOffPixmap->height() );
 }
 
 
