@@ -1,9 +1,9 @@
 /*
  * tab_widget.cpp - tabwidget for LMMS
  *
- * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -37,9 +37,10 @@
 tabWidget::tabWidget( const QString & _caption, QWidget * _parent ) :
 	QWidget( _parent ),
 	m_activeTab( 0 ),
-	m_caption( _caption )
+	m_caption( _caption ),
+	m_tabheight( _caption.isEmpty() ? 11: 10 )
 {
-	setFont( pointSize<7>( font() ) );
+	setFont( pointSize<8>( font() ) );
 
 	setAutoFillBackground( true );
 	QColor bg_color = QApplication::palette().color( QPalette::Active,
@@ -62,7 +63,7 @@ tabWidget::~tabWidget()
 
 void tabWidget::addTab( QWidget * _w, const QString & _name, int _idx )
 {
-	setFont( pointSize<7>( font() ) );
+	setFont( pointSize<8>( font() ) );
 	widgetDesc d = { _w, _name, fontMetrics().width( _name ) + 10 } ;
 	if( _idx < 0/* || m_widgets.contains( _idx ) == true*/ )
 	{
@@ -72,7 +73,7 @@ void tabWidget::addTab( QWidget * _w, const QString & _name, int _idx )
 	}
 	m_widgets[_idx] = d;
 	_w->setFixedSize( width() - 4, height() - 14 );
-	_w->move( 2, 12 );
+	_w->move( 2, 13 );
 	_w->hide();
 
 	if( m_widgets.contains( m_activeTab ) )
@@ -144,19 +145,18 @@ void tabWidget::resizeEvent( QResizeEvent * )
 
 void tabWidget::paintEvent( QPaintEvent * _pe )
 {
-	setFont( pointSize<7>( font() ) );
+	setFont( pointSize<8>( font() ) );
 	QPainter p( this );
 
 	QColor bg_color = QApplication::palette().color( QPalette::Active,
 							QPalette::Background );
-	QLinearGradient g( 0, 0, 0, 10 );
+	QLinearGradient g( 0, 0, 0, m_tabheight );
 	g.setColorAt( 0, bg_color.darker( 250 ) );
 	g.setColorAt( 0.1, bg_color.lighter( 120 ) );
 	g.setColorAt( 1, bg_color.darker( 250 ) );
 	p.fillRect( 0, 0, width() - 1, height() - 1, bg_color );
 
 	bool big_tab_captions = ( m_caption == "" );
-	int add = big_tab_captions ? 1 : 0;
 
 	p.setPen( bg_color.darker( 150 ) );
 	p.drawRect( 0, 0, width() - 1, height() - 1 );
@@ -168,27 +168,27 @@ void tabWidget::paintEvent( QPaintEvent * _pe )
 	p.setPen( QColor( 0, 0, 0 ) );
 	p.drawRect( 1, 1, width() - 3, height() - 3 );
 
-	p.fillRect( 2, 2, width() - 4, 9 + add, g );
-	p.drawLine( 2, 11 + add, width() - 3, 11 + add );
+	p.fillRect( 2, 2, width() - 4, m_tabheight, g );
+	p.drawLine( 2, m_tabheight + 2, width() - 3, m_tabheight + 2);
 
-	if( !big_tab_captions )
+	if( ! m_caption.isEmpty() )
 	{
 		p.setPen( QColor( 255, 255, 255 ) );
-		p.drawText( 5, 10, m_caption );
+		p.drawText( 5, 11, m_caption );
 	}
 
-	int cx = ( big_tab_captions ? 4 : 14 ) +
-					fontMetrics().width( m_caption );
+	// Calculate the tabs' x (tabs are painted next to the caption)
+	int tab_x_offset = m_caption.isEmpty() ? 4 : 14 + fontMetrics().width( m_caption );
 
 	QColor cap_col( 160, 160, 160 );
 	if( big_tab_captions )
 	{
-		p.setFont( pointSize<7>( p.font() ) );
+		p.setFont( pointSize<8>( p.font() ) );
 		cap_col = QColor( 224, 224, 224 );
 	}
 	else
 	{
-		p.setFont( pointSize<6>( p.font() ) );
+		p.setFont( pointSize<7>( p.font() ) );
 	}
 	p.setPen( cap_col );
 
@@ -199,11 +199,11 @@ void tabWidget::paintEvent( QPaintEvent * _pe )
 		if( it.key() == m_activeTab )
 		{
 			p.setPen( QColor( 32, 48, 64 ) );
-			p.fillRect( cx, 2, ( *it ).nwidth - 6, 9, cap_col );
+			p.fillRect( tab_x_offset, 2, ( *it ).nwidth - 6, 10, cap_col );
 		}
-		p.drawText( cx + 3, 9 + add, ( *it ).name );
+		p.drawText( tab_x_offset + 3, m_tabheight, ( *it ).name );
 		p.setPen( cap_col );
-		cx += ( *it ).nwidth;
+		tab_x_offset += ( *it ).nwidth;
 	}
 }
 
@@ -212,6 +212,9 @@ void tabWidget::paintEvent( QPaintEvent * _pe )
 
 void tabWidget::wheelEvent( QWheelEvent * _we )
 {
+	if (_we->y() > m_tabheight)
+		return;
+
 	_we->accept();
 	int dir = ( _we->delta() < 0 ) ? 1 : -1;
 	int tab = m_activeTab;
