@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ toolButton::toolButton( const QPixmap & _pixmap, const QString & _tooltip,
 	m_colorStandard( s_stdColor ),
 	m_colorHighlighted( s_hlColor )
 {
-	setAutoFillBackground( FALSE );
+	setAutoFillBackground( false );
 	QPalette pal = palette();
 	pal.setColor( backgroundRole(), m_colorStandard );
 	pal.setColor( QPalette::Window, m_colorStandard );
@@ -94,7 +94,7 @@ void toolButton::leaveEvent( QEvent * )
 
 void toolButton::toggledBool( bool _on )
 {
-	if( _on == TRUE )
+	if( _on == true )
 	{
 		emit( clicked() );
 	}
