@@ -1,11 +1,9 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * tooltip.cpp - namespace toolTip, a tooltip-wrapper for LMMS
  *
  * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -40,4 +38,3 @@ void toolTip::add( QWidget * _w, const QString & _txt )
 }
 
 
-#endif
