@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
- * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
+ * This file is part of LMMS - http://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -34,22 +34,25 @@
 #include "tooltip.h"
 #include "song.h"
 
+#include "config_mgr.h"
+
 
 
 visualizationWidget::visualizationWidget( const QPixmap & _bg, QWidget * _p,
 						visualizationTypes _vtype ) :
 	QWidget( _p ),
 	s_background( _bg ),
-	m_points( new QPointF[engine::getMixer()->framesPerPeriod()] ),
+	m_points( new QPointF[engine::mixer()->framesPerPeriod()] ),
 	m_active( false )
 {
 	setFixedSize( s_background.width(), s_background.height() );
 	setAttribute( Qt::WA_OpaquePaintEvent, true );
+	setActive( configManager::inst()->value( "ui", "displaywaveform").toInt() );
 
-	const fpp_t frames = engine::getMixer()->framesPerPeriod();
+	const fpp_t frames = engine::mixer()->framesPerPeriod();
 	m_buffer = new sampleFrame[frames];
 
-	engine::getMixer()->clearAudioBuffer( m_buffer, frames );
+	engine::mixer()->clearAudioBuffer( m_buffer, frames );
 
 
 	toolTip::add( this, tr( "click to enable/disable visualization of "
@@ -62,6 +65,7 @@ visualizationWidget::visualizationWidget( const QPixmap & _bg, QWidget * _p,
 visualizationWidget::~visualizationWidget()
 {
 	delete[] m_buffer;
+	delete[] m_points;
 }
 
 
@@ -71,12 +75,12 @@ void visualizationWidget::updateAudioBuffer()
 {
 	if( !engine::getSong()->isExporting() )
 	{
-		engine::getMixer()->lock();
-		const surroundSampleFrame * c = engine::getMixer()->
+		engine::mixer()->lock();
+		const surroundSampleFrame * c = engine::mixer()->
 							currentReadBuffer();
-		const fpp_t fpp = engine::getMixer()->framesPerPeriod();
+		const fpp_t fpp = engine::mixer()->framesPerPeriod();
 		memcpy( m_buffer, c, sizeof( surroundSampleFrame ) * fpp );
-		engine::getMixer()->unlock();
+		engine::mixer()->unlock();
 	}
 }
 
@@ -91,7 +95,7 @@ void visualizationWidget::setActive( bool _active )
 		connect( engine::mainWindow(),
 					SIGNAL( periodicUpdate() ),
 					this, SLOT( update() ) );
-		connect( engine::getMixer(),
+		connect( engine::mixer(),
 					SIGNAL( nextAudioBuffer() ),
 				this, SLOT( updateAudioBuffer() ) );
 	}
@@ -100,7 +104,7 @@ void visualizationWidget::setActive( bool _active )
 		disconnect( engine::mainWindow(),
 					SIGNAL( periodicUpdate() ),
 					this, SLOT( update() ) );
-		disconnect( engine::getMixer(),
+		disconnect( engine::mixer(),
 					SIGNAL( nextAudioBuffer() ),
 				this, SLOT( updateAudioBuffer() ) );
 		// we have to update (remove last waves),
@@ -120,7 +124,7 @@ void visualizationWidget::paintEvent( QPaintEvent * )
 
 	if( m_active && !engine::getSong()->isExporting() )
 	{
-		float master_output = engine::getMixer()->masterGain();
+		float master_output = engine::mixer()->masterGain();
 		int w = width()-4;
 		const float half_h = -( height() - 6 ) / 3.0 * master_output - 1;
 		int x_base = 2;
@@ -130,15 +134,15 @@ void visualizationWidget::paintEvent( QPaintEvent * )
 
 
 		const fpp_t frames =
-				engine::getMixer()->framesPerPeriod();
+				engine::mixer()->framesPerPeriod();
 		const float max_level = qMax<float>(
-				mixer::peakValueLeft( m_buffer, frames ),
-				mixer::peakValueRight( m_buffer, frames ) );
+				Mixer::peakValueLeft( m_buffer, frames ),
+				Mixer::peakValueRight( m_buffer, frames ) );
 
 		// and set color according to that...
 		if( max_level * master_output < 0.9 )
 		{
-			p.setPen( QColor( 128, 224, 128 ) );
+			p.setPen( QColor( 71, 253, 133 ) );
 		}
 		else if( max_level * master_output < 1.0 )
 		{
@@ -161,7 +165,7 @@ void visualizationWidget::paintEvent( QPaintEvent * )
 			{
 				m_points[frame] = QPointF(
 					x_base + (float) frame * xd,
-					y_base + ( mixer::clip(
+					y_base + ( Mixer::clip(
 						m_buffer[frame][ch] ) *
 								half_h ) );
 			}
